@@ -3,13 +3,9 @@
 //
 // Copyright 2003-2020 by Wilson Snyder. This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
-// Lesser General Public License Version 3 or the Perl Artistic License.
+// Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 ///
@@ -26,99 +22,100 @@
 ///
 //*************************************************************************
 
-
 #ifndef _VERILATEDOS_H_
 #define _VERILATEDOS_H_ 1  ///< Header Guard
 
+// Current clang-format versions botch #ifdef inclusion, so
+// clang-format off
 //=========================================================================
 // Compiler pragma abstraction
 
 #ifdef __GNUC__
-# define VL_ATTR_ALIGNED(alignment) __attribute__ ((aligned (alignment)))
-# define VL_ATTR_ALWINLINE __attribute__ ((always_inline))
-# define VL_ATTR_COLD __attribute__ ((cold))
-# define VL_ATTR_HOT __attribute__ ((hot))
-# define VL_ATTR_NORETURN __attribute__ ((noreturn))
-# define VL_ATTR_PRINTF(fmtArgNum) __attribute__ ((format (printf, (fmtArgNum), (fmtArgNum)+1)))
-# define VL_ATTR_PURE __attribute__ ((pure))
-# define VL_ATTR_UNUSED __attribute__ ((unused))
-# define VL_FUNC  __func__
+# define VL_ATTR_ALIGNED(alignment) __attribute__((aligned(alignment)))
+# define VL_ATTR_ALWINLINE __attribute__((always_inline))
+# define VL_ATTR_COLD __attribute__((cold))
+# define VL_ATTR_HOT __attribute__((hot))
+# define VL_ATTR_NORETURN __attribute__((noreturn))
+# define VL_ATTR_PRINTF(fmtArgNum) __attribute__((format(printf, (fmtArgNum), (fmtArgNum) + 1)))
+# define VL_ATTR_PURE __attribute__((pure))
+# define VL_ATTR_UNUSED __attribute__((unused))
+# define VL_FUNC __func__
 # if defined(__clang__) && defined(VL_THREADED)
-#  define VL_ACQUIRE(...) __attribute__ ((acquire_capability(__VA_ARGS__)))
-#  define VL_ACQUIRE_SHARED(...) __attribute__ ((acquire_shared_capability(__VA_ARGS__)))
-#  define VL_RELEASE(...) __attribute__ ((release_capability(__VA_ARGS__)))
-#  define VL_RELEASE_SHARED(...) __attribute__ ((release_shared_capability(__VA_ARGS__)))
-#  define VL_TRY_ACQUIRE(...) __attribute__ ((try_acquire_capability(__VA_ARGS__)))
-#  define VL_TRY_ACQUIRE_SHARED(...) __attribute__ ((try_acquire_shared_capability(__VA_ARGS__)))
-#  define VL_CAPABILITY(x) __attribute__ ((capability(x)))
-#  define VL_REQUIRES(x) __attribute__ ((requires_capability(x)))
-#  define VL_GUARDED_BY(x) __attribute__ ((guarded_by(x)))
-#  define VL_EXCLUDES(x) __attribute__ ((locks_excluded(x)))
-#  define VL_SCOPED_CAPABILITY __attribute__ ((scoped_lockable))
+#  define VL_ACQUIRE(...) __attribute__((acquire_capability(__VA_ARGS__)))
+#  define VL_ACQUIRE_SHARED(...) __attribute__((acquire_shared_capability(__VA_ARGS__)))
+#  define VL_RELEASE(...) __attribute__((release_capability(__VA_ARGS__)))
+#  define VL_RELEASE_SHARED(...) __attribute__((release_shared_capability(__VA_ARGS__)))
+#  define VL_TRY_ACQUIRE(...) __attribute__((try_acquire_capability(__VA_ARGS__)))
+#  define VL_TRY_ACQUIRE_SHARED(...) __attribute__((try_acquire_shared_capability(__VA_ARGS__)))
+#  define VL_CAPABILITY(x) __attribute__((capability(x)))
+#  define VL_REQUIRES(x) __attribute__((requires_capability(x)))
+#  define VL_GUARDED_BY(x) __attribute__((guarded_by(x)))
+#  define VL_EXCLUDES(x) __attribute__((locks_excluded(x)))
+#  define VL_SCOPED_CAPABILITY __attribute__((scoped_lockable))
 # endif
-# define VL_LIKELY(x)   __builtin_expect(!!(x), 1)
+# define VL_LIKELY(x) __builtin_expect(!!(x), 1)
 # define VL_UNLIKELY(x) __builtin_expect(!!(x), 0)
 # define VL_UNREACHABLE __builtin_unreachable();
-# define VL_PREFETCH_RD(p) __builtin_prefetch((p),0)
-# define VL_PREFETCH_RW(p) __builtin_prefetch((p),1)
+# define VL_PREFETCH_RD(p) __builtin_prefetch((p), 0)
+# define VL_PREFETCH_RW(p) __builtin_prefetch((p), 1)
 #elif defined(_MSC_VER)
-# define VL_FUNC  __FUNCTION__
+# define VL_FUNC __FUNCTION__
 #endif
 
 // Defaults for unsupported compiler features
 #ifndef VL_ATTR_ALIGNED
-# define VL_ATTR_ALIGNED(alignment)     ///< Align structure to specified byte alignment
+# define VL_ATTR_ALIGNED(alignment)  ///< Align structure to specified byte alignment
 #endif
 #ifndef VL_ATTR_ALWINLINE
-# define VL_ATTR_ALWINLINE              ///< Inline, even when not optimizing
+# define VL_ATTR_ALWINLINE  ///< Inline, even when not optimizing
 #endif
 #ifndef VL_ATTR_COLD
-# define VL_ATTR_COLD                   ///< Function is rarely executed
+# define VL_ATTR_COLD  ///< Function is rarely executed
 #endif
 #ifndef VL_ATTR_HOT
-# define VL_ATTR_HOT                    ///< Function is highly executed
+# define VL_ATTR_HOT  ///< Function is highly executed
 #endif
 #ifndef VL_ATTR_NORETURN
-# define VL_ATTR_NORETURN               ///< Function does not ever return
+# define VL_ATTR_NORETURN  ///< Function does not ever return
 #endif
 #ifndef VL_ATTR_PRINTF
-# define VL_ATTR_PRINTF(fmtArgNum)      ///< Function with printf format checking
+# define VL_ATTR_PRINTF(fmtArgNum)  ///< Function with printf format checking
 #endif
 #ifndef VL_ATTR_PURE
-# define VL_ATTR_PURE                   ///< Function is pure (and thus also VL_MT_SAFE)
+# define VL_ATTR_PURE  ///< Function is pure (and thus also VL_MT_SAFE)
 #endif
 #ifndef VL_ATTR_UNUSED
-# define VL_ATTR_UNUSED                 ///< Function that may be never used
+# define VL_ATTR_UNUSED  ///< Function that may be never used
 #endif
 #ifndef VL_FUNC
-# define VL_FUNC "__func__"             ///< Name of current function for error macros
+# define VL_FUNC "__func__"  ///< Name of current function for error macros
 #endif
 #ifndef VL_CAPABILITY
-# define VL_ACQUIRE(...)                ///< Function requires a capability/lock (-fthread-safety)
-# define VL_ACQUIRE_SHARED(...)         ///< Function aquires a shared capability/lock (-fthread-safety)
-# define VL_RELEASE(...)                ///< Function releases a capability/lock (-fthread-safety)
-# define VL_RELEASE_SHARED(...)         ///< Function releases a shared capability/lock (-fthread-safety)
-# define VL_TRY_ACQUIRE(...)            ///< Function returns bool if aquired a capability (-fthread-safety)
-# define VL_TRY_ACQUIRE_SHARED(...)     ///< Function returns bool if aquired a shared capability (-fthread-safety)
-# define VL_REQUIRES(x)                 ///< Function requires a capability inbound (-fthread-safety)
-# define VL_EXCLUDES(x)                 ///< Function requires not having a capability inbound (-fthread-safety)
-# define VL_CAPABILITY(x)               ///< Name of capability/lock (-fthread-safety)
-# define VL_GUARDED_BY(x)               ///< Name of mutex protecting this variable (-fthread-safety)
-# define VL_SCOPED_CAPABILITY           ///< Scoped threaded capability/lock (-fthread-safety)
+# define VL_ACQUIRE(...)  ///< Function requires a capability/lock (-fthread-safety)
+# define VL_ACQUIRE_SHARED(...)  ///< Function aquires a shared capability/lock (-fthread-safety)
+# define VL_RELEASE(...)  ///< Function releases a capability/lock (-fthread-safety)
+# define VL_RELEASE_SHARED(...)  ///< Function releases a shared capability/lock (-fthread-safety)
+# define VL_TRY_ACQUIRE(...)  ///< Function returns bool if aquired a capability (-fthread-safety)
+# define VL_TRY_ACQUIRE_SHARED(...)  ///< Function returns bool if aquired shared (-fthread-safety)
+# define VL_REQUIRES(x)  ///< Function requires a capability inbound (-fthread-safety)
+# define VL_EXCLUDES(x)  ///< Function requires not having a capability inbound (-fthread-safety)
+# define VL_CAPABILITY(x)  ///< Name of capability/lock (-fthread-safety)
+# define VL_GUARDED_BY(x)  ///< Name of mutex protecting this variable (-fthread-safety)
+# define VL_SCOPED_CAPABILITY  ///< Scoped threaded capability/lock (-fthread-safety)
 #endif
 #ifndef VL_LIKELY
-# define VL_LIKELY(x)   (!!(x))         ///< Boolean expression more often true than false
-# define VL_UNLIKELY(x) (!!(x))         ///< Boolean expression more often false than true
+# define VL_LIKELY(x) (!!(x))  ///< Boolean expression more often true than false
+# define VL_UNLIKELY(x) (!!(x))  ///< Boolean expression more often false than true
 #endif
-#define VL_UNCOVERABLE(x) VL_UNLIKELY(x)  ///< Boolean expression never hit by users (no coverage)
+# define VL_UNCOVERABLE(x) VL_UNLIKELY(x)  ///< Boolean expression never hit by users (no coverage)
 #ifndef VL_UNREACHABLE
-# define VL_UNREACHABLE                 ///< Point that may never be reached
+# define VL_UNREACHABLE  ///< Point that may never be reached
 #endif
 #ifndef VL_PREFETCH_RD
-# define VL_PREFETCH_RD(p)              ///< Prefetch data with read intent
+# define VL_PREFETCH_RD(p)  ///< Prefetch data with read intent
 #endif
 #ifndef VL_PREFETCH_RW
-# define VL_PREFETCH_RW(p)              ///< Prefetch data with read/write intent
+# define VL_PREFETCH_RW(p)  ///< Prefetch data with read/write intent
 #endif
 
 #ifdef VL_THREADED
@@ -126,46 +123,62 @@
 #  define VL_THREAD_LOCAL thread_local
 # elif defined(__GNUC__)
 #  if (__cplusplus < 201103L) && !defined(VL_THREADED_NO_C11_WARNING)
-#    error "VL_THREADED/--threads support requires C++-11 or newer only; use newer compiler"
+#   error "VL_THREADED/--threads support requires C++-11 or newer only; use newer compiler"
 #  endif
 # else
 #  error "Unsupported compiler for VL_THREADED: No thread-local declarator"
 # endif
-# define VL_THREAD_LOCAL thread_local   ///< Use new C++ static local thread
+# define VL_THREAD_LOCAL thread_local  ///< Use new C++ static local thread
 #else
-# define VL_THREAD_LOCAL                ///< Use new C++ static local thread
+# define VL_THREAD_LOCAL  ///< Use new C++ static local thread
 #endif
-#define VL_THREAD                       ///< Deprecated
-#define VL_STATIC_OR_THREAD static      ///< Deprecated
+
+#define VL_THREAD  ///< Deprecated
+#define VL_STATIC_OR_THREAD static  ///< Deprecated
 
 #define VL_PURE  ///< Comment tag that Function is pure (and thus also VL_MT_SAFE)
 #define VL_MT_SAFE  ///< Comment tag that function is threadsafe when VL_THREADED
-#define VL_MT_SAFE_POSTINIT  ///< Comment tag that function is threadsafe when VL_THREADED, only during normal operation (post-init)
+#define VL_MT_SAFE_POSTINIT  ///< Comment tag that function is threadsafe when VL_THREADED, only
+                             ///< during normal operation (post-init)
 #define VL_MT_UNSAFE  ///< Comment tag that function is not threadsafe when VL_THREADED
-#define VL_MT_UNSAFE_ONE  ///< Comment tag that function is not threadsafe when VL_THREADED, protected to make sure single-caller
+#define VL_MT_UNSAFE_ONE  ///< Comment tag that function is not threadsafe when VL_THREADED,
+                          ///< protected to make sure single-caller
 
-#ifdef _MSC_VER
-# define VL_ULL(c) (c##ui64)    ///< Add appropriate suffix to 64-bit constant
-#else
-# define VL_ULL(c) (c##ULL)     ///< Add appropriate suffix to 64-bit constant
-#endif
+#define VL_ULL(c) (c##ULL)  ///< Add appropriate suffix to 64-bit constant (deprecated)
 
 // This is not necessarily the same as #UL, depending on what the IData typedef is.
 #define VL_UL(c) (static_cast<IData>(c##UL))  ///< Add appropriate suffix to 32-bit constant
 
-#if defined(VL_CPPCHECK) || defined(__clang_analyzer__)
+#if defined(VL_CPPCHECK) || defined(__clang_analyzer__) || __cplusplus < 201103L
 # define VL_DANGLING(var)
 #else
-///< After e.g. delete, set variable to NULL to indicate must not use later
-# define VL_DANGLING(var) do { (var) = NULL; } while(0)
+/// After e.g. delete, set variable to NULL to indicate must not use later
+# define VL_DANGLING(var) \
+    do { \
+        *const_cast<const void**>(reinterpret_cast<const void* const*>(&var)) = NULL; \
+    } while (false)
 #endif
 
-///< Perform an e.g. delete, then set variable to NULL to indicate must not use later.
-///< Unlike VL_DO_CLEAR the setting of the variable is only for debug reasons.
-#define VL_DO_DANGLING(stmt, var) do { do { stmt; } while(0); VL_DANGLING(var); } while(0)
+/// Perform an e.g. delete, then set variable to NULL to indicate must not use later.
+/// Unlike VL_DO_CLEAR the setting of the variable is only for debug reasons.
+#define VL_DO_DANGLING(stmt, var) \
+    do { \
+        do { \
+            stmt; \
+        } while (false); \
+        VL_DANGLING(var); \
+    } while (false)
 
-///< Perform an e.g. delete, then set variable to NULL as a requirement
-#define VL_DO_CLEAR(stmt, stmt2) do { do { stmt; } while(0); do { stmt2; } while(0); } while(0)
+/// Perform an e.g. delete, then set variable to NULL as a requirement
+#define VL_DO_CLEAR(stmt, stmt2) \
+    do { \
+        do { \
+            stmt; \
+        } while (false); \
+        do { \
+            stmt2; \
+        } while (false); \
+    } while (false)
 
 //=========================================================================
 // C++-2011
@@ -185,6 +198,7 @@
 #  define VL_INCLUDE_UNORDERED_SET <unordered_set>
 # endif
 # define VL_FINAL final
+# define VL_MUTABLE mutable
 # define VL_OVERRIDE override
 #else
 # define VL_EQ_DELETE
@@ -192,6 +206,7 @@
 # define VL_INCLUDE_UNORDERED_MAP "verilated_unordered_set_map.h"
 # define VL_INCLUDE_UNORDERED_SET "verilated_unordered_set_map.h"
 # define VL_FINAL
+# define VL_MUTABLE
 # define VL_OVERRIDE
 #endif
 
@@ -202,6 +217,20 @@
 # define VL_INLINE_OPT  ///< "inline" if compiling all objects in single compiler run
 #endif
 
+//=========================================================================
+// Internal coverage
+
+#ifdef VL_GCOV
+extern "C" {
+void __gcov_flush();  // gcc sources gcc/gcov-io.h has the prototype
+}
+/// Flush internal code coverage data before e.g. abort()
+# define VL_GCOV_FLUSH() \
+    __gcov_flush()
+#else
+# define VL_GCOV_FLUSH()
+#endif
+
 //=========================================================================
 // Warning disabled
 
@@ -223,74 +252,79 @@
 
 #ifdef __MINGW32__
 # define __USE_MINGW_ANSI_STDIO 1  // Force old MinGW (GCC 5 and older) to use C99 formats
-# define __STDC_FORMAT_MACROS   1  // Otherwise MinGW doesn't get PRId64 for fstapi.c
 #endif
 
+// The inttypes supplied with some GCC & MINGW32 versions requires STDC_FORMAT_MACROS
+// to be declared in order to get the PRIxx macros used by fstapi.c
+#define __STDC_FORMAT_MACROS
+
 #if defined(__CYGWIN__)
 
 # include <stdint.h>
 # include <sys/types.h>  // __WORDSIZE
 # include <unistd.h>  // ssize_t
-typedef unsigned char           uint8_t;        ///< 8-bit unsigned type (backward compatibility)
-typedef unsigned short int      uint16_t;       ///< 16-bit unsigned type (backward compatibility)
-typedef unsigned char           vluint8_t;      ///< 8-bit unsigned type
-typedef unsigned short int      vluint16_t;     ///< 16-bit unsigned type
+typedef unsigned char uint8_t;  ///< 8-bit unsigned type (backward compatibility)
+typedef unsigned short int uint16_t;  ///< 16-bit unsigned type (backward compatibility)
+typedef char vlsint8_t;  ///< 8-bit signed type
+typedef unsigned char vluint8_t;  ///< 8-bit unsigned type
+typedef short int vlsint16_t;  ///< 16-bit signed type
+typedef unsigned short int vluint16_t;  ///< 16-bit unsigned type
 # if defined(__uint32_t_defined) || defined(___int32_t_defined)  // Newer Cygwin uint32_t in stdint.h as an unsigned int
-typedef int32_t                 vlsint32_t;     ///< 32-bit signed type
-typedef uint32_t                vluint32_t;     ///< 32-bit unsigned type
+typedef int32_t vlsint32_t;  ///< 32-bit signed type
+typedef uint32_t vluint32_t;  ///< 32-bit unsigned type
 # else  // Older Cygwin has long==uint32_t
-typedef unsigned long           uint32_t;       ///< 32-bit unsigned type (backward compatibility)
-typedef long                    vlsint32_t;     ///< 32-bit signed type
-typedef unsigned long           vluint32_t;     ///< 32-bit unsigned type
+typedef unsigned long uint32_t;  ///< 32-bit unsigned type (backward compatibility)
+typedef long vlsint32_t;  ///< 32-bit signed type
+typedef unsigned long vluint32_t;  ///< 32-bit unsigned type
 # endif
 # if defined(__WORDSIZE) && (__WORDSIZE == 64)
-typedef long                    vlsint64_t;     ///< 64-bit signed type
-typedef unsigned long           vluint64_t;     ///< 64-bit unsigned type
+typedef long vlsint64_t;  ///< 64-bit signed type
+typedef unsigned long vluint64_t;  ///< 64-bit unsigned type
 # else
-typedef long long               vlsint64_t;     ///< 64-bit signed type
-typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
+typedef long long vlsint64_t;  ///< 64-bit signed type
+typedef unsigned long long vluint64_t;  ///< 64-bit unsigned type
 # endif
 
 #elif defined(_WIN32) && defined(_MSC_VER)
 
-typedef unsigned __int8         uint8_t;        ///< 8-bit unsigned type (backward compatibility)
-typedef unsigned __int16        uint16_t;       ///< 16-bit unsigned type (backward compatibility)
-typedef unsigned __int32        uint32_t;       ///< 32-bit unsigned type (backward compatibility)
-typedef unsigned __int8         vluint8_t;      ///< 8-bit unsigned type
-typedef unsigned __int16        vluint16_t;     ///< 16-bit unsigned type
-typedef signed   __int32        vlsint32_t;     ///< 32-bit signed type
-typedef unsigned __int32        vluint32_t;     ///< 32-bit unsigned type
-typedef signed   __int64        vlsint64_t;     ///< 64-bit signed type
-typedef unsigned __int64        vluint64_t;     ///< 64-bit unsigned type
+typedef unsigned __int8 uint8_t;  ///< 8-bit unsigned type (backward compatibility)
+typedef unsigned __int16 uint16_t;  ///< 16-bit unsigned type (backward compatibility)
+typedef unsigned __int32 uint32_t;  ///< 32-bit unsigned type (backward compatibility)
+typedef signed __int8 vlsint8_t;  ///< 8-bit signed type
+typedef unsigned __int8 vluint8_t;  ///< 8-bit unsigned type
+typedef signed __int16 vlsint16_t;  ///< 16-bit signed type
+typedef unsigned __int16 vluint16_t;  ///< 16-bit unsigned type
+typedef signed __int32 vlsint32_t;  ///< 32-bit signed type
+typedef unsigned __int32 vluint32_t;  ///< 32-bit unsigned type
+typedef signed __int64 vlsint64_t;  ///< 64-bit signed type
+typedef unsigned __int64 vluint64_t;  ///< 64-bit unsigned type
 
 # ifndef _SSIZE_T_DEFINED
-#  ifdef  _WIN64
-typedef signed   __int64        ssize_t;        ///< signed size_t; returned from read()
+#  ifdef _WIN64
+typedef signed __int64 ssize_t;  ///< signed size_t; returned from read()
 #  else
-typedef signed   __int32        ssize_t;        ///< signed size_t; returned from read()
+typedef signed __int32 ssize_t;  ///< signed size_t; returned from read()
 #  endif
 # endif
 
 #else  // Linux or compliant Unix flavors, -m64
 
-// The inttypes supplied with some GCC versions requires STDC_FORMAT_MACROS
-// to be declared in order to get the PRIxx macros used by fstapi.c
-#define __STDC_FORMAT_MACROS
-
 # include <inttypes.h>  // Solaris
 # include <stdint.h>  // Linux and most flavors
 # include <sys/types.h>  // __WORDSIZE
 # include <unistd.h>  // ssize_t
-typedef uint8_t                 vluint8_t;      ///< 32-bit unsigned type
-typedef uint16_t                vluint16_t;     ///< 32-bit unsigned type
-typedef int                     vlsint32_t;     ///< 32-bit signed type
-typedef uint32_t                vluint32_t;     ///< 32-bit signed type
+typedef char vlsint8_t;  ///< 8-bit signed type
+typedef uint8_t vluint8_t;  ///< 8-bit unsigned type
+typedef short vlsint16_t;  ///< 16-bit signed type
+typedef uint16_t vluint16_t;  ///< 16-bit unsigned type
+typedef int vlsint32_t;  ///< 32-bit signed type
+typedef uint32_t vluint32_t;  ///< 32-bit unsigned type
 # if defined(__WORDSIZE) && (__WORDSIZE == 64)
-typedef long                    vlsint64_t;     ///< 64-bit signed type
-typedef unsigned long           vluint64_t;     ///< 64-bit unsigned type
+typedef long vlsint64_t;  ///< 64-bit signed type
+typedef unsigned long vluint64_t;  ///< 64-bit unsigned type
 # else
-typedef long long               vlsint64_t;     ///< 64-bit signed type
-typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
+typedef long long vlsint64_t;  ///< 64-bit signed type
+typedef unsigned long long vluint64_t;  ///< 64-bit unsigned type
 # endif
 #endif
 
@@ -333,14 +367,14 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 //=========================================================================
 // Integer size macros
 
-#define VL_BYTESIZE 8                   ///< Bits in a CData / byte
-#define VL_SHORTSIZE 16                 ///< Bits in a SData / short
-#define VL_IDATASIZE 32                 ///< Bits in a IData / word
-#define VL_WORDSIZE IDATASIZE           ///< Legacy define
-#define VL_QUADSIZE 64                  ///< Bits in a QData / quadword
-#define VL_EDATASIZE 32                 ///< Bits in a EData (WData entry)
-#define VL_EDATASIZE_LOG2 5             ///< log2(VL_EDATASIZE)
-#define VL_CACHE_LINE_BYTES 64          ///< Bytes in a cache line (for alignment)
+#define VL_BYTESIZE 8  ///< Bits in a CData / byte
+#define VL_SHORTSIZE 16  ///< Bits in a SData / short
+#define VL_IDATASIZE 32  ///< Bits in a IData / word
+#define VL_WORDSIZE VL_IDATASIZE  ///< Legacy define
+#define VL_QUADSIZE 64  ///< Bits in a QData / quadword
+#define VL_EDATASIZE 32  ///< Bits in a EData (WData entry)
+#define VL_EDATASIZE_LOG2 5  ///< log2(VL_EDATASIZE)
+#define VL_CACHE_LINE_BYTES 64  ///< Bytes in a cache line (for alignment)
 
 /// Bytes this number of bits needs (1 bit=1 byte)
 #define VL_BYTES_I(nbits) (((nbits) + (VL_BYTESIZE - 1)) / VL_BYTESIZE)
@@ -353,15 +387,15 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 // Class definition helpers
 
 // Used to declare a class as uncopyable; put after a private:
-#define VL_UNCOPYABLE(Type)  \
-    Type(const Type& other) VL_EQ_DELETE;  \
-    Type& operator= (const Type&) VL_EQ_DELETE
+#define VL_UNCOPYABLE(Type) \
+    Type(const Type& other) VL_EQ_DELETE; \
+    Type& operator=(const Type&) VL_EQ_DELETE
 
 //=========================================================================
 // Verilated function size macros
 
-#define VL_MULS_MAX_WORDS 16            ///< Max size in words of MULS operation
-#define VL_TO_STRING_MAX_WORDS 64       ///< Max size in words of String conversion operation
+#define VL_MULS_MAX_WORDS 16  ///< Max size in words of MULS operation
+#define VL_TO_STRING_MAX_WORDS 64  ///< Max size in words of String conversion operation
 
 //=========================================================================
 // Base macros
@@ -371,11 +405,10 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 #define VL_SIZEBITS_E (VL_EDATASIZE - 1)  ///< Bit mask for bits in a quad
 
 /// Mask for words with 1's where relevant bits are (0=all bits)
-#define VL_MASK_I(nbits)  (((nbits) & VL_SIZEBITS_I) \
-                         ? ((1U << ((nbits) & VL_SIZEBITS_I) )-1) : ~0)
+#define VL_MASK_I(nbits) (((nbits) & VL_SIZEBITS_I) ? ((1U << ((nbits) & VL_SIZEBITS_I)) - 1) : ~0)
 /// Mask for quads with 1's where relevant bits are (0=all bits)
-#define VL_MASK_Q(nbits)  (((nbits) & VL_SIZEBITS_Q) \
-                         ? ((VL_ULL(1) << ((nbits) & VL_SIZEBITS_Q) )-VL_ULL(1)) : VL_ULL(~0))
+#define VL_MASK_Q(nbits) \
+    (((nbits) & VL_SIZEBITS_Q) ? ((1ULL << ((nbits) & VL_SIZEBITS_Q)) - 1ULL) : ~0ULL)
 /// Mask for EData with 1's where relevant bits are (0=all bits)
 #define VL_MASK_E(nbits) VL_MASK_I(nbits)
 #define VL_EUL(n) VL_UL(n)  ///< Make constant number EData sized
@@ -391,8 +424,8 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 // #defines, to avoid requiring math.h on all compile runs
 
 #ifdef _MSC_VER
-# define VL_TRUNC(n) (((n)<0) ? ceil((n))     : floor((n)))
-# define VL_ROUND(n) (((n)<0) ? ceil((n)-0.5) : floor((n)+0.5))
+# define VL_TRUNC(n) (((n) < 0) ? ceil((n)) : floor((n)))
+# define VL_ROUND(n) (((n) < 0) ? ceil((n)-0.5) : floor((n) + 0.5))
 #else
 # define VL_TRUNC(n) trunc(n)
 # define VL_ROUND(n) round(n)
@@ -402,15 +435,16 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 // Performance counters
 
 /// The vluint64_t argument is loaded with a high-performance counter for profiling
-/// or 0x0 if not implemeted on this platform
+/// or 0x0 if not implemented on this platform
 #if defined(__i386__) || defined(__x86_64__)
-# define VL_RDTSC(val) {  \
-    vluint32_t hi, lo;  \
-    asm volatile("rdtsc" : "=a" (lo), "=d" (hi));  \
-    (val) = ((vluint64_t)lo) | (((vluint64_t)hi)<<32);  \
-}
+#define VL_RDTSC(val) \
+    { \
+        vluint32_t hi, lo; \
+        asm volatile("rdtsc" : "=a"(lo), "=d"(hi)); \
+        (val) = ((vluint64_t)lo) | (((vluint64_t)hi) << 32); \
+    }
 #elif defined(__aarch64__)
-# define VL_RDTSC(val) asm volatile("mrs %[rt],PMCCNTR_EL0" : [rt] "=r" (val));
+# define VL_RDTSC(val) asm volatile("mrs %[rt],PMCCNTR_EL0" : [rt] "=r"(val));
 #else
 // We just silently ignore unknown OSes, as only leads to missing statistics
 # define VL_RDTSC(val) (val) = 0;
@@ -449,6 +483,17 @@ typedef unsigned long long      vluint64_t;     ///< 64-bit unsigned type
 # define VL_STRCASECMP strcasecmp
 #endif
 
+//=========================================================================
+// Macros controlling target specific optimizations
+
+// Define VL_PORTABLE_ONLY to disable all target specific optimizations
+#ifndef VL_PORTABLE_ONLY
+# ifdef __x86_64__
+#  define VL_X86_64 1
+# endif
+#endif // VL_PORTABLE_ONLY
+// clang-format on
+
 //=========================================================================
 // Stringify macros
 
