@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2005-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2005-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 //  Pre steps:
@@ -27,9 +23,6 @@
 #include "V3Global.h"
 #include "V3AssertPre.h"
 
-#include <cstdarg>
-#include <iomanip>
-
 //######################################################################
 // Assert class functions
 
@@ -41,11 +34,11 @@ private:
     // NODE STATE/TYPES
     // STATE
     // Reset each module:
-    AstNodeSenItem* m_seniDefaultp;  // Default sensitivity (from AstDefClock)
+    AstSenItem* m_seniDefaultp;  // Default sensitivity (from AstDefClock)
     // Reset each assertion:
-    AstNodeSenItem* m_senip;  // Last sensitivity
+    AstSenItem* m_senip;  // Last sensitivity
     // Reset each always:
-    AstNodeSenItem* m_seniAlwaysp;  // Last sensitivity in always
+    AstSenItem* m_seniAlwaysp;  // Last sensitivity in always
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -54,25 +47,23 @@ private:
         // Create sentree based on clocked or default clock
         // Return NULL for always
         AstSenTree* newp = NULL;
-        AstNodeSenItem* senip = m_senip;
+        AstSenItem* senip = m_senip;
         if (!senip) senip = m_seniDefaultp;
         if (!senip) senip = m_seniAlwaysp;
         if (!senip) {
-            nodep->v3error("Unsupported: Unclocked assertion");
+            nodep->v3warn(E_UNSUPPORTED, "Unsupported: Unclocked assertion");
             newp = new AstSenTree(nodep->fileline(), NULL);
         } else {
             newp = new AstSenTree(nodep->fileline(), senip->cloneTree(true));
         }
         return newp;
     }
-    void clearAssertInfo() {
-        m_senip = NULL;
-    }
+    void clearAssertInfo() { m_senip = NULL; }
 
     // VISITORS
     //========== Statements
     virtual void visit(AstClocking* nodep) VL_OVERRIDE {
-        UINFO(8,"   CLOCKING"<<nodep<<endl);
+        UINFO(8, "   CLOCKING" << nodep << endl);
         // Store the new default clock, reset on new module
         m_seniDefaultp = nodep->sensesp();
         // Trash it, keeping children
@@ -85,9 +76,7 @@ private:
     }
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         iterateAndNextNull(nodep->sensesp());
-        if (nodep->sensesp()) {
-            m_seniAlwaysp = nodep->sensesp()->sensesp();
-        }
+        if (nodep->sensesp()) m_seniAlwaysp = nodep->sensesp()->sensesp();
         iterateAndNextNull(nodep->bodysp());
         m_seniAlwaysp = NULL;
     }
@@ -97,9 +86,7 @@ private:
         clearAssertInfo();
         // Find Clocking's buried under nodep->exprsp
         iterateChildren(nodep);
-        if (!nodep->immediate()) {
-            nodep->sentreep(newSenTree(nodep));
-        }
+        if (!nodep->immediate()) nodep->sentreep(newSenTree(nodep));
         clearAssertInfo();
     }
     virtual void visit(AstPast* nodep) VL_OVERRIDE {
@@ -110,21 +97,19 @@ private:
     virtual void visit(AstPropClocked* nodep) VL_OVERRIDE {
         // No need to iterate the body, once replace will get iterated
         iterateAndNextNull(nodep->sensesp());
-        if (m_senip) {
-            nodep->v3error("Unsupported: Only one PSL clock allowed per assertion");
-        }
+        if (m_senip)
+            nodep->v3warn(E_UNSUPPORTED, "Unsupported: Only one PSL clock allowed per assertion");
         // Block is the new expression to evaluate
         AstNode* blockp = nodep->propp()->unlinkFrBack();
         if (nodep->disablep()) {
             if (VN_IS(nodep->backp(), Cover)) {
-                blockp = new AstAnd(nodep->disablep()->fileline(),
-                                    new AstNot(nodep->disablep()->fileline(),
-                                               nodep->disablep()->unlinkFrBack()),
-                                    blockp);
+                blockp = new AstAnd(
+                    nodep->disablep()->fileline(),
+                    new AstNot(nodep->disablep()->fileline(), nodep->disablep()->unlinkFrBack()),
+                    blockp);
             } else {
                 blockp = new AstOr(nodep->disablep()->fileline(),
-                                   nodep->disablep()->unlinkFrBack(),
-                                   blockp);
+                                   nodep->disablep()->unlinkFrBack(), blockp);
             }
         }
         // Unlink and just keep a pointer to it, convert to sentree as needed
@@ -137,9 +122,7 @@ private:
         // Reset defaults
         m_seniDefaultp = NULL;
     }
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -157,9 +140,7 @@ public:
 // Top Assert class
 
 void V3AssertPre::assertPreAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        AssertPreVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { AssertPreVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("assertpre", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
