@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3CCtors's Transformations:
@@ -36,34 +32,30 @@
 #include "V3CCtors.h"
 
 #include <algorithm>
-#include <cmath>
-#include <cstdarg>
 #include <map>
-#include <vector>
 
 class V3CCtorsVisitor {
 private:
-    string              m_basename;
-    string              m_argsp;
-    string              m_callargsp;
-    AstNodeModule*      m_modp;         // Current module
-    AstCFunc*           m_tlFuncp;      // Top level function being built
-    AstCFunc*           m_funcp;        // Current function
-    int                 m_numStmts;     // Number of statements output
-    int                 m_funcNum;      // Function number being built
+    string m_basename;
+    string m_argsp;
+    string m_callargsp;
+    AstNodeModule* m_modp;  // Current module
+    AstCFunc* m_tlFuncp;  // Top level function being built
+    AstCFunc* m_funcp;  // Current function
+    int m_numStmts;  // Number of statements output
+    int m_funcNum;  // Function number being built
 
 public:
     void add(AstNode* nodep) {
-        if (v3Global.opt.outputSplitCFuncs()
-            && v3Global.opt.outputSplitCFuncs() < m_numStmts) {
+        if (v3Global.opt.outputSplitCFuncs() && v3Global.opt.outputSplitCFuncs() < m_numStmts) {
             m_funcp = NULL;
         }
         if (!m_funcp) {
-            m_funcp = new AstCFunc(m_modp->fileline(),
-                                   m_basename+"_"+cvtToStr(++m_funcNum), NULL, "void");
+            m_funcp = new AstCFunc(m_modp->fileline(), m_basename + "_" + cvtToStr(++m_funcNum),
+                                   NULL, "void");
             m_funcp->isStatic(false);
             m_funcp->declPrivate(true);
-            m_funcp->slow(true);
+            m_funcp->slow(!VN_IS(m_modp, Class));  // Only classes construct on fast path
             m_funcp->argTypes(m_argsp);
             m_modp->addStmtp(m_funcp);
 
@@ -78,9 +70,8 @@ public:
         m_numStmts += 1;
     }
 
-    V3CCtorsVisitor(AstNodeModule* nodep, const string& basename,
-                    const string& argsp="", const string& callargsp="",
-                    const string& stmt="") {
+    V3CCtorsVisitor(AstNodeModule* nodep, const string& basename, const string& argsp = "",
+                    const string& callargsp = "", const string& stmt = "") {
         m_basename = basename;
         m_argsp = argsp;
         m_callargsp = callargsp;
@@ -90,15 +81,14 @@ public:
         m_tlFuncp = new AstCFunc(nodep->fileline(), basename, NULL, "void");
         m_tlFuncp->declPrivate(true);
         m_tlFuncp->isStatic(false);
-        m_tlFuncp->slow(true);
+        m_tlFuncp->slow(!VN_IS(m_modp, Class));  // Only classes construct on fast path
         m_tlFuncp->argTypes(m_argsp);
-        if (stmt != "") {
-            m_tlFuncp->addStmtsp(new AstCStmt(nodep->fileline(), stmt));
-        }
+        if (stmt != "") { m_tlFuncp->addStmtsp(new AstCStmt(nodep->fileline(), stmt)); }
         m_funcp = m_tlFuncp;
         m_modp->addStmtp(m_tlFuncp);
     }
     ~V3CCtorsVisitor() {}
+
 private:
     VL_UNCOPYABLE(V3CCtorsVisitor);
 };
@@ -125,15 +115,16 @@ void V3CCtors::evalAsserts() {
                         if (varp->isWide()) {
                             newp = new AstWordSel(
                                 varp->fileline(), newp,
-                                new AstConst(varp->fileline(), varp->widthWords()-1));
+                                new AstConst(varp->fileline(), varp->widthWords() - 1));
                         }
                         uint64_t value = VL_MASK_Q(storedWidth) & ~VL_MASK_Q(lastWordWidth);
                         newp = new AstAnd(varp->fileline(), newp,
                                           new AstConst(varp->fileline(), AstConst::WidthedValue(),
                                                        storedWidth, value));
-                        AstNodeIf* ifp = new AstIf(varp->fileline(), newp,
-                                                   new AstCStmt(varp->fileline(),
-                                                                "Verilated::overWidthError(\""+varp->prettyName()+"\");"));
+                        AstNodeIf* ifp = new AstIf(
+                            varp->fileline(), newp,
+                            new AstCStmt(varp->fileline(), "Verilated::overWidthError(\""
+                                                               + varp->prettyName() + "\");"));
                         ifp->branchPred(VBranchPred::BP_UNLIKELY);
                         newp = ifp;
                         funcp->addStmtsp(newp);
@@ -145,17 +136,21 @@ void V3CCtors::evalAsserts() {
 }
 
 void V3CCtors::cctorsAll() {
-    UINFO(2,__FUNCTION__<<": "<<endl);
+    UINFO(2, __FUNCTION__ << ": " << endl);
     evalAsserts();
-    for (AstNodeModule* modp = v3Global.rootp()->modulesp();
-         modp; modp = VN_CAST(modp->nextp(), NodeModule)) {
+    for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp;
+         modp = VN_CAST(modp->nextp(), NodeModule)) {
         // Process each module in turn
         {
-            V3CCtorsVisitor var_reset (modp, "_ctor_var_reset");
+            V3CCtorsVisitor var_reset(
+                modp, "_ctor_var_reset",
+                (VN_IS(modp, Class) ? EmitCBaseVisitor::symClassVar() : ""),
+                (VN_IS(modp, Class) ? "vlSymsp" : ""),
+                (VN_IS(modp, Class) ? "if (false && vlSymsp) {}  // Prevent unused\n" : ""));
+
             for (AstNode* np = modp->stmtsp(); np; np = np->nextp()) {
                 if (AstVar* varp = VN_CAST(np, Var)) {
-                    if (!varp->isIfaceParent() && !varp->isIfaceRef()
-                        && !varp->noReset()) {
+                    if (!varp->isIfaceParent() && !varp->isIfaceRef() && !varp->noReset()) {
                         var_reset.add(new AstCReset(varp->fileline(),
                                                     new AstVarRef(varp->fileline(), varp, true)));
                     }
@@ -163,10 +158,9 @@ void V3CCtors::cctorsAll() {
             }
         }
         if (v3Global.opt.coverage()) {
-            V3CCtorsVisitor configure_coverage
-                (modp, "_configure_coverage",
-                 EmitCBaseVisitor::symClassVar()+ ", bool first", "vlSymsp, first",
-                 "if (0 && vlSymsp && first) {}  // Prevent unused\n");
+            V3CCtorsVisitor configure_coverage(
+                modp, "_configure_coverage", EmitCBaseVisitor::symClassVar() + ", bool first",
+                "vlSymsp, first", "if (false && vlSymsp && first) {}  // Prevent unused\n");
             for (AstNode* np = modp->stmtsp(); np; np = np->nextp()) {
                 if (AstCoverDecl* coverp = VN_CAST(np, CoverDecl)) {
                     AstNode* backp = coverp->backp();
@@ -176,5 +170,12 @@ void V3CCtors::cctorsAll() {
                 }
             }
         }
+        if (VN_IS(modp, Class)) {
+            AstCFunc* funcp = new AstCFunc(modp->fileline(), "~", NULL, "");
+            funcp->isDestructor(true);
+            funcp->isStatic(false);
+            funcp->slow(false);
+            modp->addStmtp(funcp);
+        }
     }
 }
