@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Clock's Transformations:
@@ -40,7 +36,6 @@
 #include "V3EmitCBase.h"
 
 #include <algorithm>
-#include <cstdarg>
 
 //######################################################################
 // Clock state, as a visitor of each AstNode
@@ -50,22 +45,19 @@ private:
     // NODE STATE
     // Cleared each Module:
     //  AstVarScope::user1p()   -> AstVarScope*.  Temporary signal that was created.
-    AstUser1InUse       m_inuser1;
-
-    // TYPES
-    enum { DOUBLE_OR_RATE = 10 };  // How many | per ||, Determined experimentally as best
+    AstUser1InUse m_inuser1;
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    AstTopScope*        m_topScopep;    // Current top scope
-    AstScope*           m_scopep;       // Current scope
-    AstCFunc*           m_evalFuncp;    // Top eval function we are creating
-    AstCFunc*           m_initFuncp;    // Top initial function we are creating
-    AstCFunc*           m_finalFuncp;   // Top final function we are creating
-    AstCFunc*           m_settleFuncp;  // Top settlement function we are creating
-    AstSenTree*         m_lastSenp;     // Last sensitivity match, so we can detect duplicates.
-    AstIf*              m_lastIfp;      // Last sensitivity if active to add more under
-    AstMTaskBody*       m_mtaskBodyp;   // Current mtask body
+    AstNodeModule* m_modp;  // Current module
+    AstTopScope* m_topScopep;  // Current top scope
+    AstScope* m_scopep;  // Current scope
+    AstCFunc* m_evalFuncp;  // Top eval function we are creating
+    AstCFunc* m_initFuncp;  // Top initial function we are creating
+    AstCFunc* m_finalFuncp;  // Top final function we are creating
+    AstCFunc* m_settleFuncp;  // Top settlement function we are creating
+    AstSenTree* m_lastSenp;  // Last sensitivity match, so we can detect duplicates.
+    AstIf* m_lastIfp;  // Last sensitivity if active to add more under
+    AstMTaskBody* m_mtaskBodyp;  // Current mtask body
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -73,12 +65,14 @@ private:
     AstVarScope* getCreateLastClk(AstVarScope* vscp) {
         if (vscp->user1p()) return static_cast<AstVarScope*>(vscp->user1p());
         AstVar* varp = vscp->varp();
-        if (!varp->width1()) varp->v3error("Unsupported: Clock edge on non-single bit signal: "
-                                           <<varp->prettyNameQ());
-        string newvarname = (string("__Vclklast__")
-                             +vscp->scopep()->nameDotless()+"__"+varp->name());
-        AstVar* newvarp = new AstVar(vscp->fileline(),
-                                     AstVarType::MODULETEMP, newvarname, VFlagLogicPacked(), 1);
+        if (!varp->width1()) {
+            varp->v3warn(E_UNSUPPORTED, "Unsupported: Clock edge on non-single bit signal: "
+                                            << varp->prettyNameQ());
+        }
+        string newvarname
+            = (string("__Vclklast__") + vscp->scopep()->nameDotless() + "__" + varp->name());
+        AstVar* newvarp = new AstVar(vscp->fileline(), AstVarType::MODULETEMP, newvarname,
+                                     VFlagLogicPacked(), 1);
         newvarp->noReset(true);  // Reset by below assign
         m_modp->addStmtp(newvarp);
         AstVarScope* newvscp = new AstVarScope(vscp->fileline(), m_scopep, newvarp);
@@ -87,18 +81,16 @@ private:
         // Add init
         AstNode* fromp = new AstVarRef(newvarp->fileline(), vscp, false);
         if (v3Global.opt.xInitialEdge()) fromp = new AstNot(fromp->fileline(), fromp);
-        AstNode* newinitp = new AstAssign(vscp->fileline(),
-                                          new AstVarRef(newvarp->fileline(), newvscp, true),
-                                          fromp);
+        AstNode* newinitp = new AstAssign(
+            vscp->fileline(), new AstVarRef(newvarp->fileline(), newvscp, true), fromp);
         addToInitial(newinitp);
         // At bottom, assign them
         AstAssign* finalp
-            = new AstAssign(vscp->fileline(),
-                            new AstVarRef(vscp->fileline(), newvscp, true),
+            = new AstAssign(vscp->fileline(), new AstVarRef(vscp->fileline(), newvscp, true),
                             new AstVarRef(vscp->fileline(), vscp, false));
         m_evalFuncp->addFinalsp(finalp);
         //
-        UINFO(4,"New Last: "<<newvscp<<endl);
+        UINFO(4, "New Last: " << newvscp << endl);
         return newvscp;
     }
     AstNode* createSenItemEquation(AstSenItem* nodep) {
@@ -110,64 +102,45 @@ private:
         // HIGHEDGE:  var
         // LOWEDGE:  ~var
         AstNode* newp = NULL;
-        if (nodep->edgeType()==VEdgeType::ET_ILLEGAL) {
-            if (!v3Global.opt.bboxUnsup()) {
-                nodep->v3error("Unsupported: Complicated event expression in sensitive activity list");
-            }
+        if (nodep->edgeType() == VEdgeType::ET_ILLEGAL) {
+            nodep->v3warn(E_UNSUPPORTED,
+                          "Unsupported: Complicated event expression in sensitive activity list");
             return NULL;
         }
         AstVarScope* clkvscp = nodep->varrefp()->varScopep();
         if (nodep->edgeType() == VEdgeType::ET_POSEDGE) {
             AstVarScope* lastVscp = getCreateLastClk(clkvscp);
-            newp = new AstAnd(nodep->fileline(),
-                              new AstVarRef(nodep->fileline(),
-                                            nodep->varrefp()->varScopep(), false),
-                              new AstNot(nodep->fileline(),
-                                         new AstVarRef(nodep->fileline(),
-                                                       lastVscp, false)));
+            newp = new AstAnd(
+                nodep->fileline(),
+                new AstVarRef(nodep->fileline(), nodep->varrefp()->varScopep(), false),
+                new AstNot(nodep->fileline(), new AstVarRef(nodep->fileline(), lastVscp, false)));
         } else if (nodep->edgeType() == VEdgeType::ET_NEGEDGE) {
             AstVarScope* lastVscp = getCreateLastClk(clkvscp);
-            newp = new AstAnd(nodep->fileline(),
-                              new AstNot(nodep->fileline(),
-                                         new AstVarRef(nodep->fileline(),
-                                                       nodep->varrefp()->varScopep(), false)),
-                              new AstVarRef(nodep->fileline(), lastVscp, false));
+            newp = new AstAnd(
+                nodep->fileline(),
+                new AstNot(nodep->fileline(),
+                           new AstVarRef(nodep->fileline(), nodep->varrefp()->varScopep(), false)),
+                new AstVarRef(nodep->fileline(), lastVscp, false));
         } else if (nodep->edgeType() == VEdgeType::ET_BOTHEDGE) {
             AstVarScope* lastVscp = getCreateLastClk(clkvscp);
-            newp = new AstXor(nodep->fileline(),
-                              new AstVarRef(nodep->fileline(),
-                                            nodep->varrefp()->varScopep(), false),
-                              new AstVarRef(nodep->fileline(), lastVscp, false));
+            newp = new AstXor(
+                nodep->fileline(),
+                new AstVarRef(nodep->fileline(), nodep->varrefp()->varScopep(), false),
+                new AstVarRef(nodep->fileline(), lastVscp, false));
         } else if (nodep->edgeType() == VEdgeType::ET_HIGHEDGE) {
-            newp = new AstVarRef(nodep->fileline(),
-                                 clkvscp, false);
+            newp = new AstVarRef(nodep->fileline(), clkvscp, false);
         } else if (nodep->edgeType() == VEdgeType::ET_LOWEDGE) {
-            newp = new AstNot(nodep->fileline(),
-                              new AstVarRef(nodep->fileline(),
-                                            clkvscp, false));
+            newp = new AstNot(nodep->fileline(), new AstVarRef(nodep->fileline(), clkvscp, false));
         } else {
             nodep->v3fatalSrc("Bad edge type");
         }
         return newp;
     }
-    AstNode* createSenGateEquation(AstSenGate* nodep) {
-        AstNode* newp = new AstAnd(nodep->fileline(),
-                                   createSenseEquation(nodep->sensesp()),
-                                   nodep->rhsp()->cloneTree(true));
-        return newp;
-    }
-    AstNode* createSenseEquation(AstNodeSenItem* nodesp) {
+    AstNode* createSenseEquation(AstSenItem* nodesp) {
         // Nodep may be a list of elements; we need to walk it
         AstNode* senEqnp = NULL;
-        for (AstNodeSenItem* senp = nodesp; senp; senp = VN_CAST(senp->nextp(), NodeSenItem)) {
-            AstNode* senOnep = NULL;
-            if (AstSenItem* itemp = VN_CAST(senp, SenItem)) {
-                senOnep = createSenItemEquation(itemp);
-            } else if (AstSenGate* itemp = VN_CAST(senp, SenGate)) {
-                senOnep = createSenGateEquation(itemp);
-            } else {
-                senp->v3fatalSrc("Strange node under sentree");
-            }
+        for (AstSenItem* senp = nodesp; senp; senp = VN_CAST(senp->nextp(), SenItem)) {
+            AstNode* const senOnep = createSenItemEquation(senp);
             if (senEqnp) {
                 // Add new OR to the sensitivity list equation
                 senEqnp = new AstOr(senp->fileline(), senEqnp, senOnep);
@@ -190,12 +163,12 @@ private:
 
     // VISITORS
     virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
-        UINFO(4," TOPSCOPE   "<<nodep<<endl);
+        UINFO(4, " TOPSCOPE   " << nodep << endl);
         m_topScopep = nodep;
         m_scopep = nodep->scopep();
         UASSERT_OBJ(m_scopep, nodep,
                     "No scope found on top level, perhaps you have no statements?");
-        //VV*****  We reset all user1p()
+        // VV*****  We reset all user1p()
         AstNode::user1ClearTree();
         // Make top functions
         {
@@ -227,11 +200,10 @@ private:
             funcp->isStatic(false);
             funcp->entryPoint(true);
             funcp->protect(false);
-            funcp->addInitsp(new AstCStmt
-                             (nodep->fileline(),
-                              EmitCBaseVisitor::symClassVar()+" = this->__VlSymsp;\n"));
-            funcp->addInitsp(new AstCStmt(nodep->fileline(),
-                                          EmitCBaseVisitor::symTopAssign()+"\n"));
+            funcp->addInitsp(new AstCStmt(nodep->fileline(), EmitCBaseVisitor::symClassVar()
+                                                                 + " = this->__VlSymsp;\n"));
+            funcp->addInitsp(
+                new AstCStmt(nodep->fileline(), EmitCBaseVisitor::symTopAssign() + "\n"));
             m_scopep->addActivep(funcp);
             m_finalFuncp = funcp;
         }
@@ -249,13 +221,13 @@ private:
         // Process the activates
         iterateChildren(nodep);
         // Done, clear so we can detect errors
-        UINFO(4," TOPSCOPEDONE "<<nodep<<endl);
+        UINFO(4, " TOPSCOPEDONE " << nodep << endl);
         clearLastSen();
         m_topScopep = NULL;
         m_scopep = NULL;
     }
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
-        //UINFO(4," MOD   "<<nodep<<endl);
+        // UINFO(4, " MOD   " << nodep << endl);
         AstNodeModule* origModp = m_modp;
         {
             m_modp = nodep;
@@ -264,7 +236,7 @@ private:
         m_modp = origModp;
     }
     virtual void visit(AstScope* nodep) VL_OVERRIDE {
-        //UINFO(4," SCOPE   "<<nodep<<endl);
+        // UINFO(4, " SCOPE   " << nodep << endl);
         m_scopep = nodep;
         iterateChildren(nodep);
         if (AstNode* movep = nodep->finalClksp()) {
@@ -293,24 +265,21 @@ private:
         VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
     virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
-        //nodep->dumpTree(cout, "ct:");
-        //COVERTOGGLE(INC, ORIG, CHANGE) ->
+        // nodep->dumpTree(cout, "ct:");
+        // COVERTOGGLE(INC, ORIG, CHANGE) ->
         //   IF(ORIG ^ CHANGE) { INC; CHANGE = ORIG; }
         AstNode* incp = nodep->incp()->unlinkFrBack();
         AstNode* origp = nodep->origp()->unlinkFrBack();
         AstNode* changep = nodep->changep()->unlinkFrBack();
-        AstIf* newp = new AstIf(nodep->fileline(),
-                                new AstXor(nodep->fileline(),
-                                           origp,
-                                           changep),
+        AstIf* newp = new AstIf(nodep->fileline(), new AstXor(nodep->fileline(), origp, changep),
                                 incp, NULL);
         // We could add another IF to detect posedges, and only increment if so.
         // It's another whole branch though versus a potential memory miss.
         // We'll go with the miss.
-        newp->addIfsp(new AstAssign(nodep->fileline(),
-                                    changep->cloneTree(false),
-                                    origp->cloneTree(false)));
-        nodep->replaceWith(newp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+        newp->addIfsp(
+            new AstAssign(nodep->fileline(), changep->cloneTree(false), origp->cloneTree(false)));
+        nodep->replaceWith(newp);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
     virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         AstNode* cmtp = new AstComment(nodep->fileline(), nodep->typeName(), true);
@@ -325,7 +294,7 @@ private:
         iterateChildren(nodep);
         // Link to global function
         if (nodep->formCallTree()) {
-            UINFO(4, "    formCallTree "<<nodep<<endl);
+            UINFO(4, "    formCallTree " << nodep << endl);
             AstCCall* callp = new AstCCall(nodep->fileline(), nodep);
             callp->argTypes("vlSymsp");
             m_finalFuncp->addStmtsp(callp);
@@ -337,13 +306,13 @@ private:
         pushDeletep(nodep);
     }
     void addToEvalLoop(AstNode* stmtsp) {
-       m_evalFuncp->addStmtsp(stmtsp);  // add to top level function
+        m_evalFuncp->addStmtsp(stmtsp);  // add to top level function
     }
     void addToSettleLoop(AstNode* stmtsp) {
-       m_settleFuncp->addStmtsp(stmtsp);  // add to top level function
+        m_settleFuncp->addStmtsp(stmtsp);  // add to top level function
     }
     void addToInitial(AstNode* stmtsp) {
-       m_initFuncp->addStmtsp(stmtsp);  // add to top level function
+        m_initFuncp->addStmtsp(stmtsp);  // add to top level function
     }
     virtual void visit(AstActive* nodep) VL_OVERRIDE {
         // Careful if adding variables here, ACTIVES can be under other ACTIVES
@@ -354,13 +323,13 @@ private:
             UASSERT_OBJ(!nodep->stmtsp(), nodep, "Non-empty lower active");
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
         } else if (m_mtaskBodyp) {
-            UINFO(4,"  TR ACTIVE  "<<nodep<<endl);
+            UINFO(4, "  TR ACTIVE  " << nodep << endl);
             AstNode* stmtsp = nodep->stmtsp()->unlinkFrBackWithNext();
             if (nodep->hasClocked()) {
                 UASSERT_OBJ(!nodep->hasInitial(), nodep,
                             "Initial block should not have clock sensitivity");
                 if (m_lastSenp && nodep->sensesp()->sameTree(m_lastSenp)) {
-                    UINFO(4,"    sameSenseTree\n");
+                    UINFO(4, "    sameSenseTree\n");
                 } else {
                     clearLastSen();
                     m_lastSenp = nodep->sensesp();
@@ -379,14 +348,14 @@ private:
             }
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
         } else {
-            UINFO(4,"  ACTIVE  "<<nodep<<endl);
+            UINFO(4, "  ACTIVE  " << nodep << endl);
             AstNode* stmtsp = nodep->stmtsp()->unlinkFrBackWithNext();
             if (nodep->hasClocked()) {
                 // Remember the latest sensitivity so we can compare it next time
                 UASSERT_OBJ(!nodep->hasInitial(), nodep,
                             "Initial block should not have clock sensitivity");
                 if (m_lastSenp && nodep->sensesp()->sameTree(m_lastSenp)) {
-                    UINFO(4,"    sameSenseTree\n");
+                    UINFO(4, "    sameSenseTree\n");
                 } else {
                     clearLastSen();
                     m_lastSenp = nodep->sensesp();
@@ -414,8 +383,7 @@ private:
         }
     }
     virtual void visit(AstExecGraph* nodep) VL_OVERRIDE {
-        for (m_mtaskBodyp = VN_CAST(nodep->op1p(), MTaskBody);
-             m_mtaskBodyp;
+        for (m_mtaskBodyp = VN_CAST(nodep->op1p(), MTaskBody); m_mtaskBodyp;
              m_mtaskBodyp = VN_CAST(m_mtaskBodyp->nextp(), MTaskBody)) {
             clearLastSen();
             iterate(m_mtaskBodyp);
@@ -429,10 +397,7 @@ private:
     }
 
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -460,9 +425,7 @@ public:
 // Clock class functions
 
 void V3Clock::clockAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        ClockVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { ClockVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("clock", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
