@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Depth's Transformations:
@@ -35,7 +31,6 @@
 #include "V3Ast.h"
 
 #include <algorithm>
-#include <cstdarg>
 
 //######################################################################
 
@@ -44,20 +39,20 @@ private:
     // NODE STATE
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    AstCFunc*           m_funcp;        // Current block
-    AstNode*            m_stmtp;        // Current statement
-    int                 m_depth;        // How deep in an expression
-    int                 m_maxdepth;     // Maximum depth in an expression
+    AstNodeModule* m_modp;  // Current module
+    AstCFunc* m_funcp;  // Current block
+    AstNode* m_stmtp;  // Current statement
+    int m_depth;  // How deep in an expression
+    int m_maxdepth;  // Maximum depth in an expression
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     void createDeepTemp(AstNode* nodep) {
-        UINFO(6,"  Deep  "<<nodep<<endl);
-        //if (debug()>=9) nodep->dumpTree(cout, "deep:");
+        UINFO(6, "  Deep  " << nodep << endl);
+        // if (debug() >= 9) nodep->dumpTree(cout, "deep:");
 
-        string newvarname = (string("__Vdeeptemp")+cvtToStr(m_modp->varNumGetInc()));
+        string newvarname = (string("__Vdeeptemp") + cvtToStr(m_modp->varNumGetInc()));
         AstVar* varp = new AstVar(nodep->fileline(), AstVarType::STMTTEMP, newvarname,
                                   // Width, not widthMin, as we may be in
                                   // middle of BITSEL expression which though
@@ -73,8 +68,7 @@ private:
         nodep->replaceWith(newp);
         // Put assignment before the referencing statement
         AstAssign* assp = new AstAssign(nodep->fileline(),
-                                        new AstVarRef(nodep->fileline(), varp, true),
-                                        nodep);
+                                        new AstVarRef(nodep->fileline(), varp, true), nodep);
         AstNRelinker linker2;
         m_stmtp->unlinkFrBack(&linker2);
         assp->addNext(m_stmtp);
@@ -83,7 +77,7 @@ private:
 
     // VISITORS
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
-        UINFO(4," MOD   "<<nodep<<endl);
+        UINFO(4, " MOD   " << nodep << endl);
         AstNodeModule* origModp = m_modp;
         {
             m_modp = nodep;
@@ -114,20 +108,18 @@ private:
         }
     }
     // Operators
-    virtual void visit(AstNodeTermop* nodep) VL_OVERRIDE {
-    }
+    virtual void visit(AstNodeTermop* nodep) VL_OVERRIDE {}
     virtual void visit(AstNodeMath* nodep) VL_OVERRIDE {
         // We have some operator defines that use 2 parens, so += 2.
         m_depth += 2;
-        if (m_depth>m_maxdepth) m_maxdepth = m_depth;
+        if (m_depth > m_maxdepth) m_maxdepth = m_depth;
         iterateChildren(nodep);
         m_depth -= 2;
 
-        if (m_stmtp
-            && (v3Global.opt.compLimitParens() >= 1)  // Else compiler doesn't need it
-            && (m_maxdepth-m_depth) > v3Global.opt.compLimitParens()
+        if (m_stmtp && (v3Global.opt.compLimitParens() >= 1)  // Else compiler doesn't need it
+            && (m_maxdepth - m_depth) > v3Global.opt.compLimitParens()
             && !VN_IS(nodep->backp(), NodeStmt)  // Not much point if we're about to use it
-            ) {
+        ) {
             m_maxdepth = m_depth;
             createDeepTemp(nodep);
         }
@@ -139,7 +131,7 @@ private:
     void needNonStaticFunc(AstNode* nodep) {
         UASSERT_OBJ(m_funcp, nodep, "Non-static accessor not under a function");
         if (m_funcp->isStatic().trueUnknown()) {
-            UINFO(5,"Mark non-public due to "<<nodep<<endl);
+            UINFO(5, "Mark non-public due to " << nodep << endl);
             m_funcp->isStatic(false);
         }
     }
@@ -154,10 +146,8 @@ private:
 
     //--------------------
     // Default: Just iterate
-    virtual void visit(AstVar* nodep) VL_OVERRIDE {}  // Don't hit varrefs under vars
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Don't hit varrefs under vars
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -177,9 +167,7 @@ public:
 // Depth class functions
 
 void V3Depth::depthAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DepthVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DepthVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("depth", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 6);
 }
