@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3DepthBlock's Transformations:
@@ -33,7 +29,6 @@
 #include "V3EmitCBase.h"
 
 #include <algorithm>
-#include <cstdarg>
 
 //######################################################################
 
@@ -42,10 +37,10 @@ private:
     // NODE STATE
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    AstCFunc*           m_funcp;        // Current function
-    int                 m_depth;        // How deep in an expression
-    int                 m_deepNum;      // How many functions made
+    AstNodeModule* m_modp;  // Current module
+    AstCFunc* m_funcp;  // Current function
+    int m_depth;  // How deep in an expression
+    int m_deepNum;  // How many functions made
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -54,7 +49,7 @@ private:
         AstNRelinker relinkHandle;
         nodep->unlinkFrBack(&relinkHandle);
         // Create function
-        string name = m_funcp->name()+"__deep"+cvtToStr(++m_deepNum);
+        string name = m_funcp->name() + "__deep" + cvtToStr(++m_deepNum);
         AstCFunc* funcp = new AstCFunc(nodep->fileline(), name, NULL);
         funcp->argTypes(EmitCBaseVisitor::symClassVar());
         funcp->symProlog(true);
@@ -64,7 +59,7 @@ private:
         // Call it at the point where the body was removed from
         AstCCall* callp = new AstCCall(nodep->fileline(), funcp);
         callp->argTypes("vlSymsp");
-        UINFO(6,"      New "<<callp<<endl);
+        UINFO(6, "      New " << callp << endl);
         //
         relinkHandle.relink(callp);
         return funcp;
@@ -72,7 +67,7 @@ private:
 
     // VISITORS
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
-        UINFO(4," MOD   "<<nodep<<endl);
+        UINFO(4, " MOD   " << nodep << endl);
         AstNodeModule* origModp = m_modp;
         {
             m_modp = nodep;
@@ -96,14 +91,14 @@ private:
     void visitStmt(AstNodeStmt* nodep) {
         m_depth++;
         if (m_depth > v3Global.opt.compLimitBlocks()
-            && !VN_IS(nodep, CCall)) {  // Already done
-            UINFO(4, "DeepBlocks "<<m_depth<<" "<<nodep<<endl);
+            && !VN_IS(nodep, NodeCCall)) {  // Already done
+            UINFO(4, "DeepBlocks " << m_depth << " " << nodep << endl);
             AstNode* backp = nodep->backp();  // Only for debug
-            if (debug()>=9) backp->dumpTree(cout, "-   pre : ");
+            if (debug() >= 9) backp->dumpTree(cout, "-   pre : ");
             AstCFunc* funcp = createDeepFunc(nodep);
             iterate(funcp);
-            if (debug()>=9) backp->dumpTree(cout, "-   post: ");
-            if (debug()>=9) funcp->dumpTree(cout, "-   func: ");
+            if (debug() >= 9) backp->dumpTree(cout, "-   post: ");
+            if (debug() >= 9) funcp->dumpTree(cout, "-   func: ");
         } else {
             iterateChildren(nodep);
         }
@@ -117,13 +112,10 @@ private:
         }
     }
 
-    virtual void visit(AstNodeMath* nodep) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstVar* nodep) VL_OVERRIDE {}  // Don't hit varrefs under vars
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Don't hit varrefs under vars
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -142,9 +134,7 @@ public:
 // DepthBlock class functions
 
 void V3DepthBlock::depthBlockAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DepthBlockVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DepthBlockVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("deepblock", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
