@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -43,23 +39,32 @@ public:
     V3OutCFile* ofp() const { return m_ofp; }
     void puts(const string& str) { ofp()->puts(str); }
     void putbs(const string& str) { ofp()->putbs(str); }
-    void putsDecoration(const string& str) { if (v3Global.opt.decoration()) puts(str); }
+    void putsDecoration(const string& str) {
+        if (v3Global.opt.decoration()) puts(str);
+    }
     void putsQuoted(const string& str) { ofp()->putsQuoted(str); }
     bool optSystemC() { return v3Global.opt.systemC(); }
     static string protect(const string& name) { return VIdProtect::protectIf(name, true); }
     static string protectIf(const string& name, bool doIt) {
-        return VIdProtect::protectIf(name, doIt); }
+        return VIdProtect::protectIf(name, doIt);
+    }
     static string protectWordsIf(const string& name, bool doIt) {
-        return VIdProtect::protectWordsIf(name, doIt); }
+        return VIdProtect::protectWordsIf(name, doIt);
+    }
     static string ifNoProtect(const string& in) { return v3Global.opt.protectIds() ? "" : in; }
-    static string symClassName() { return v3Global.opt.prefix()+"_"+protect("_Syms"); }
-    static string symClassVar()  { return symClassName()+"* __restrict vlSymsp"; }
+    static string symClassName() { return v3Global.opt.prefix() + "_" + protect("_Syms"); }
+    static string symClassVar() { return symClassName() + "* __restrict vlSymsp"; }
     static string symTopAssign() {
-        return v3Global.opt.prefix()+"* __restrict vlTOPp VL_ATTR_UNUSED = vlSymsp->TOPp;"; }
+        return v3Global.opt.prefix() + "* const __restrict vlTOPp VL_ATTR_UNUSED = vlSymsp->TOPp;";
+    }
     static string funcNameProtect(const AstCFunc* nodep, const AstNodeModule* modp) {
-        if (nodep->isConstructor()) return prefixNameProtect(modp);
-        else if (nodep->isDestructor()) return string("~") + prefixNameProtect(modp);
-        else return nodep->nameProtect();
+        if (nodep->isConstructor()) {
+            return prefixNameProtect(modp);
+        } else if (nodep->isDestructor()) {
+            return string("~") + prefixNameProtect(modp);
+        } else {
+            return nodep->nameProtect();
+        }
     }
     static string prefixNameProtect(const AstNode* nodep) {  // C++ name with prefix
         const AstNodeModule* modp = VN_CAST_CONST(nodep, NodeModule);
@@ -83,15 +88,17 @@ public:
         // Return argument list for given C function
         string args = nodep->argTypes();
         // Might be a user function with argument list.
-        for (const AstNode* stmtp = nodep->argsp(); stmtp; stmtp=stmtp->nextp()) {
+        for (const AstNode* stmtp = nodep->argsp(); stmtp; stmtp = stmtp->nextp()) {
             if (const AstVar* portp = VN_CAST_CONST(stmtp, Var)) {
                 if (portp->isIO() && !portp->isFuncReturn()) {
-                    if (args != "") args+= ", ";
-                    if (nodep->dpiImport() || nodep->dpiExportWrapper())
+                    if (args != "") args += ", ";
+                    if (nodep->dpiImport() || nodep->dpiExportWrapper()) {
                         args += portp->dpiArgType(true, false);
-                    else if (nodep->funcPublic())
+                    } else if (nodep->funcPublic()) {
                         args += portp->cPubArgType(true, false);
-                    else args += portp->vlArgType(true, false, true);
+                    } else {
+                        args += portp->vlArgType(true, false, true);
+                    }
                 }
             }
         }
@@ -118,6 +125,7 @@ private:
         m_count++;
         iterateChildren(nodep);
     }
+
 public:
     // CONSTRUCTORS
     explicit EmitCBaseCounterVisitor(AstNode* nodep) {
