@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2004-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2004-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -26,8 +22,6 @@
 #include "V3EmitCBase.h"
 
 #include <algorithm>
-#include <cmath>
-#include <cstdarg>
 #include <map>
 #include <vector>
 
@@ -36,7 +30,7 @@
 
 class EmitVBaseVisitor : public EmitCBaseVisitor {
     // MEMBERS
-    bool        m_suppressSemi;
+    bool m_suppressSemi;
     AstSenTree* m_sensesp;
 
     // METHODS
@@ -57,37 +51,41 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE { iterateChildren(nodep); }
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         putfs(nodep, nodep->verilogKwd() + " " + prefixNameProtect(nodep) + ";\n");
         iterateChildren(nodep);
         putqs(nodep, "end" + nodep->verilogKwd() + "\n");
     }
     virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
-        putfs(nodep, nodep->isFunction() ? "function":"task");
+        putfs(nodep, nodep->isFunction() ? "function" : "task");
         puts(" ");
         puts(nodep->prettyName());
         puts(";\n");
-        putqs(nodep, "begin\n");  // Only putfs the first time for each visitor; later for same node is putqs
+        // Only putfs the first time for each visitor; later for same node is putqs
+        putqs(nodep, "begin\n");
         iterateAndNextNull(nodep->stmtsp());
         putqs(nodep, "end\n");
     }
 
     virtual void visit(AstBegin* nodep) VL_OVERRIDE {
-        if (nodep->unnamed()) {
+        if (nodep->name() == "") {
             putbs("begin\n");
         } else {
-            putbs("begin : "+nodep->name()+"\n");
+            putbs("begin : " + nodep->name() + "\n");
         }
         iterateChildren(nodep);
         puts("end\n");
     }
-    virtual void visit(AstGenerate* nodep) VL_OVERRIDE {
-        putfs(nodep, "generate\n");
+    virtual void visit(AstFork* nodep) VL_OVERRIDE {
+        if (nodep->name() == "") {
+            putbs("fork\n");
+        } else {
+            putbs("fork : " + nodep->name() + "\n");
+        }
         iterateChildren(nodep);
-        putqs(nodep, "end\n");
+        puts(nodep->joinType().verilogKwd());
+        puts("\n");
     }
     virtual void visit(AstFinal* nodep) VL_OVERRIDE {
         putfs(nodep, "final begin\n");
@@ -101,23 +99,31 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         putfs(nodep, "always ");
-        if (m_sensesp) iterateAndNextNull(m_sensesp);  // In active
-        else iterateAndNextNull(nodep->sensesp());
+        if (m_sensesp) {
+            iterateAndNextNull(m_sensesp);
+        }  // In active
+        else {
+            iterateAndNextNull(nodep->sensesp());
+        }
         putbs(" begin\n");
         iterateAndNextNull(nodep->bodysp());
         putqs(nodep, "end\n");
     }
     virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
         putfs(nodep, "/*verilator public_flat_rw ");
-        if (m_sensesp) iterateAndNextNull(m_sensesp);  // In active
-        else iterateAndNextNull(nodep->sensesp());
+        if (m_sensesp) {
+            iterateAndNextNull(m_sensesp);
+        }  // In active
+        else {
+            iterateAndNextNull(nodep->sensesp());
+        }
         putqs(nodep, " ");
         iterateAndNextNull(nodep->bodysp());
         putqs(nodep, "*/\n");
     }
     virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         iterateAndNextNull(nodep->lhsp());
-        putfs(nodep, " "+nodep->verilogKwd()+" ");
+        putfs(nodep, " " + nodep->verilogKwd() + " ");
         iterateAndNextNull(nodep->rhsp());
         if (!m_suppressSemi) puts(";\n");
     }
@@ -148,15 +154,12 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     virtual void visit(AstSenTree* nodep) VL_OVERRIDE {
         // AstSenItem is called for dumping in isolation by V3Order
         putfs(nodep, "@(");
-        for (AstNode* expp=nodep->sensesp(); expp; expp = expp->nextp()) {
+        for (AstNode* expp = nodep->sensesp(); expp; expp = expp->nextp()) {
             iterate(expp);
             if (expp->nextp()) putqs(expp->nextp(), " or ");
         }
         puts(")");
     }
-    virtual void visit(AstSenGate* nodep) VL_OVERRIDE {
-        emitVerilogFormat(nodep, nodep->emitVerilog(), nodep->sensesp(), nodep->rhsp());
-    }
     virtual void visit(AstSenItem* nodep) VL_OVERRIDE {
         putfs(nodep, "");
         puts(nodep->edgeType().verilogKwd());
@@ -187,13 +190,15 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     virtual void visit(AstCaseItem* nodep) VL_OVERRIDE {
         if (nodep->condsp()) {
             iterateAndNextNull(nodep->condsp());
-        } else putbs("default");
+        } else {
+            putbs("default");
+        }
         putfs(nodep, ": begin ");
         iterateAndNextNull(nodep->bodysp());
         putqs(nodep, "end\n");
     }
     virtual void visit(AstComment* nodep) VL_OVERRIDE {
-        puts(string("// ")+nodep->name()+"\n");
+        puts(string("// ") + nodep->name() + "\n");
         iterateChildren(nodep);
     }
     virtual void visit(AstContinue* nodep) VL_OVERRIDE {
@@ -204,20 +209,23 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     virtual void visit(AstCoverInc*) VL_OVERRIDE {}  // N/A
     virtual void visit(AstCoverToggle*) VL_OVERRIDE {}  // N/A
 
-    void visitNodeDisplay(AstNode* nodep, AstNode* fileOrStrgp,
-                          const string& text, AstNode* exprsp) {
+    void visitNodeDisplay(AstNode* nodep, AstNode* fileOrStrgp, const string& text,
+                          AstNode* exprsp) {
         putfs(nodep, nodep->verilogKwd());
         putbs(" (");
-        if (fileOrStrgp) { iterateAndNextNull(fileOrStrgp); putbs(","); }
+        if (fileOrStrgp) {
+            iterateAndNextNull(fileOrStrgp);
+            putbs(",");
+        }
         putsQuoted(text);
-        for (AstNode* expp=exprsp; expp; expp = expp->nextp()) {
+        for (AstNode* expp = exprsp; expp; expp = expp->nextp()) {
             puts(",");
             iterateAndNextNull(expp);
         }
         puts(");\n");
     }
     virtual void visit(AstDisable* nodep) VL_OVERRIDE {
-        putbs("disable "+nodep->name()+";\n");
+        putbs("disable " + nodep->name() + ";\n");
     }
     virtual void visit(AstDisplay* nodep) VL_OVERRIDE {
         visitNodeDisplay(nodep, nodep->filep(), nodep->fmtp()->text(), nodep->fmtp()->exprsp());
@@ -239,12 +247,16 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
     virtual void visit(AstFOpen* nodep) VL_OVERRIDE {
         putfs(nodep, nodep->verilogKwd());
-        putbs(" (");
-        if (nodep->filep()) iterateAndNextNull(nodep->filep());
+        putbs("(");
+        iterateAndNextNull(nodep->filenamep());
         putbs(",");
-        if (nodep->filenamep()) iterateAndNextNull(nodep->filenamep());
-        putbs(",");
-        if (nodep->modep()) iterateAndNextNull(nodep->modep());
+        iterateAndNextNull(nodep->modep());
+        puts(");\n");
+    }
+    virtual void visit(AstFOpenMcd* nodep) VL_OVERRIDE {
+        putfs(nodep, nodep->verilogKwd());
+        putbs("(");
+        iterateAndNextNull(nodep->filenamep());
         puts(");\n");
     }
     virtual void visit(AstFClose* nodep) VL_OVERRIDE {
@@ -259,22 +271,31 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         if (nodep->filep()) iterateAndNextNull(nodep->filep());
         puts(");\n");
     }
-    virtual void visit(AstJumpGo* nodep) VL_OVERRIDE {
-        putbs("disable "+cvtToHex(nodep->labelp())+";\n");
-    }
-    virtual void visit(AstJumpLabel* nodep) VL_OVERRIDE {
-        putbs("begin : "+cvtToHex(nodep)+"\n");
+    virtual void visit(AstJumpBlock* nodep) VL_OVERRIDE {
+        putbs("begin : label" + cvtToStr(nodep->labelNum()) + "\n");
         if (nodep->stmtsp()) iterateAndNextNull(nodep->stmtsp());
         puts("end\n");
     }
+    virtual void visit(AstJumpGo* nodep) VL_OVERRIDE {
+        putbs("disable label" + cvtToStr(nodep->labelp()->blockp()->labelNum()) + ";\n");
+    }
+    virtual void visit(AstJumpLabel* nodep) VL_OVERRIDE {
+        putbs("// " + cvtToStr(nodep->blockp()) + ":\n");
+    }
     virtual void visit(AstNodeReadWriteMem* nodep) VL_OVERRIDE {
         putfs(nodep, nodep->verilogKwd());
         putbs(" (");
         if (nodep->filenamep()) iterateAndNextNull(nodep->filenamep());
         putbs(",");
         if (nodep->memp()) iterateAndNextNull(nodep->memp());
-        if (nodep->lsbp()) { putbs(","); iterateAndNextNull(nodep->lsbp()); }
-        if (nodep->msbp()) { putbs(","); iterateAndNextNull(nodep->msbp()); }
+        if (nodep->lsbp()) {
+            putbs(",");
+            iterateAndNextNull(nodep->lsbp());
+        }
+        if (nodep->msbp()) {
+            putbs(",");
+            iterateAndNextNull(nodep->msbp());
+        }
         puts(");\n");
     }
     virtual void visit(AstSysFuncAsTask* nodep) VL_OVERRIDE {
@@ -349,12 +370,8 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         iterateAndNextNull(nodep->lhsp());
         puts(";\n");
     }
-    virtual void visit(AstStop* nodep) VL_OVERRIDE {
-        putfs(nodep, "$stop;\n");
-    }
-    virtual void visit(AstFinish* nodep) VL_OVERRIDE {
-        putfs(nodep, "$finish;\n");
-    }
+    virtual void visit(AstStop* nodep) VL_OVERRIDE { putfs(nodep, "$stop;\n"); }
+    virtual void visit(AstFinish* nodep) VL_OVERRIDE { putfs(nodep, "$finish;\n"); }
     virtual void visit(AstNodeSimpleText* nodep) VL_OVERRIDE {
         if (nodep->tracking() || m_trackText) {
             puts(nodep->text());
@@ -369,8 +386,7 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
             if (nodep->commas() && childp->nextp()) puts(", ");
         }
     }
-    virtual void visit(AstScopeName* nodep) VL_OVERRIDE {
-    }
+    virtual void visit(AstScopeName* nodep) VL_OVERRIDE {}
     virtual void visit(AstCStmt* nodep) VL_OVERRIDE {
         putfs(nodep, "$_CSTMT(");
         iterateAndNextNull(nodep->bodysp());
@@ -393,29 +409,33 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
 
     // Operators
-    virtual void emitVerilogFormat(AstNode* nodep, const string& format,
-                                   AstNode* lhsp=NULL, AstNode* rhsp=NULL, AstNode* thsp=NULL) {
+    virtual void emitVerilogFormat(AstNode* nodep, const string& format, AstNode* lhsp = NULL,
+                                   AstNode* rhsp = NULL, AstNode* thsp = NULL,
+                                   AstNode* fhsp = NULL) {
         // Look at emitVerilog() format for term/uni/dual/triops,
         // and write out appropriate text.
         //      %f      Potential fileline-if-change and line break
         //      %l      lhsp - if appropriate
         //      %r      rhsp - if appropriate
         //      %t      thsp - if appropriate
+        //      %o      fhsp - if appropriate
         //      %d      dtypep - if appropriate
         //      %k      Potential line break
         bool inPct = false;
         putbs("");
         for (string::const_iterator pos = format.begin(); pos != format.end(); ++pos) {
-            if (pos[0]=='%') {
+            if (pos[0] == '%') {
                 inPct = true;
             } else if (!inPct) {  // Normal text
-                string s; s+=pos[0]; puts(s);
+                string s;
+                s += pos[0];
+                puts(s);
             } else {  // Format character
                 inPct = false;
                 switch (*pos) {
-                case '%': puts("%");  break;
-                case 'f': putfs(nodep, "");  break;
-                case 'k': putbs("");  break;
+                case '%': puts("%"); break;
+                case 'f': putfs(nodep, ""); break;
+                case 'k': putbs(""); break;
                 case 'l': {
                     UASSERT_OBJ(lhsp, nodep, "emitVerilog() references undef node");
                     iterateAndNextNull(lhsp);
@@ -431,14 +451,17 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
                     iterateAndNextNull(thsp);
                     break;
                 }
+                case 'o': {
+                    UASSERT_OBJ(thsp, nodep, "emitVerilog() references undef node");
+                    iterateAndNextNull(fhsp);
+                    break;
+                }
                 case 'd': {
                     UASSERT_OBJ(nodep->dtypep(), nodep, "emitVerilog() references undef node");
                     iterateAndNextNull(nodep->dtypep());
                     break;
                 }
-                default:
-                    nodep->v3fatalSrc("Unknown emitVerilog format code: %"<<pos[0]);
-                    break;
+                default: nodep->v3fatalSrc("Unknown emitVerilog format code: %" << pos[0]); break;
                 }
             }
         }
@@ -454,7 +477,8 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         emitVerilogFormat(nodep, nodep->emitVerilog(), nodep->lhsp(), nodep->rhsp());
     }
     virtual void visit(AstNodeTriop* nodep) VL_OVERRIDE {
-        emitVerilogFormat(nodep, nodep->emitVerilog(), nodep->lhsp(), nodep->rhsp(), nodep->thsp());
+        emitVerilogFormat(nodep, nodep->emitVerilog(), nodep->lhsp(), nodep->rhsp(),
+                          nodep->thsp());
     }
     virtual void visit(AstAttrOf* nodep) VL_OVERRIDE {
         putfs(nodep, "$_ATTROF(");
@@ -469,8 +493,7 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         putfs(nodep, "`{");
         int comma = 0;
         const AstInitArray::KeyItemMap& mapr = nodep->map();
-        for (AstInitArray::KeyItemMap::const_iterator it = mapr.begin();
-             it != mapr.end(); ++it) {
+        for (AstInitArray::KeyItemMap::const_iterator it = mapr.begin(); it != mapr.end(); ++it) {
             if (comma++) putbs(", ");
             puts(cvtToStr(it->first));
             puts(":");
@@ -481,23 +504,31 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
     virtual void visit(AstNodeCond* nodep) VL_OVERRIDE {
         putbs("(");
-        iterateAndNextNull(nodep->condp()); putfs(nodep, " ? ");
-        iterateAndNextNull(nodep->expr1p()); putbs(" : ");
-        iterateAndNextNull(nodep->expr2p()); puts(")");
+        iterateAndNextNull(nodep->condp());
+        putfs(nodep, " ? ");
+        iterateAndNextNull(nodep->expr1p());
+        putbs(" : ");
+        iterateAndNextNull(nodep->expr2p());
+        puts(")");
     }
     virtual void visit(AstRange* nodep) VL_OVERRIDE {
         puts("[");
         if (VN_IS(nodep->msbp(), Const) && VN_IS(nodep->lsbp(), Const)) {
             // Looks nicer if we print [1:0] rather than [32'sh1:32sh0]
-            puts(cvtToStr(VN_CAST(nodep->leftp(), Const)->toSInt())); puts(":");
-            puts(cvtToStr(VN_CAST(nodep->rightp(), Const)->toSInt())); puts("]");
+            puts(cvtToStr(VN_CAST(nodep->leftp(), Const)->toSInt()));
+            puts(":");
+            puts(cvtToStr(VN_CAST(nodep->rightp(), Const)->toSInt()));
+            puts("]");
         } else {
-            iterateAndNextNull(nodep->leftp()); puts(":");
-            iterateAndNextNull(nodep->rightp()); puts("]");
+            iterateAndNextNull(nodep->leftp());
+            puts(":");
+            iterateAndNextNull(nodep->rightp());
+            puts("]");
         }
     }
     virtual void visit(AstSel* nodep) VL_OVERRIDE {
-        iterateAndNextNull(nodep->fromp()); puts("[");
+        iterateAndNextNull(nodep->fromp());
+        puts("[");
         if (VN_IS(nodep->lsbp(), Const)) {
             if (nodep->widthp()->isOne()) {
                 if (VN_IS(nodep->lsbp(), Const)) {
@@ -507,14 +538,15 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
                 }
             } else {
                 puts(cvtToStr(VN_CAST(nodep->lsbp(), Const)->toSInt()
-                              + VN_CAST(nodep->widthp(), Const)->toSInt()
-                              - 1));
+                              + VN_CAST(nodep->widthp(), Const)->toSInt() - 1));
                 puts(":");
                 puts(cvtToStr(VN_CAST(nodep->lsbp(), Const)->toSInt()));
             }
         } else {
-            iterateAndNextNull(nodep->lsbp()); putfs(nodep, "+:");
-            iterateAndNextNull(nodep->widthp()); puts("]");
+            iterateAndNextNull(nodep->lsbp());
+            putfs(nodep, "+:");
+            iterateAndNextNull(nodep->widthp());
+            puts("]");
         }
         puts("]");
     }
@@ -524,15 +556,23 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
     virtual void visit(AstTypedef* nodep) VL_OVERRIDE {
         putfs(nodep, "typedef ");
-        iterateAndNextNull(nodep->dtypep()); puts(" ");
+        iterateAndNextNull(nodep->dtypep());
+        puts(" ");
         puts(nodep->prettyName());
         puts(";\n");
     }
     virtual void visit(AstBasicDType* nodep) VL_OVERRIDE {
         if (nodep->isSigned()) putfs(nodep, "signed ");
         putfs(nodep, nodep->prettyName());
-        if (nodep->rangep()) { puts(" "); iterateAndNextNull(nodep->rangep()); puts(" "); }
-        else if (nodep->isRanged()) { puts(" ["); puts(cvtToStr(nodep->msb())); puts(":0] "); }
+        if (nodep->rangep()) {
+            puts(" ");
+            iterateAndNextNull(nodep->rangep());
+            puts(" ");
+        } else if (nodep->isRanged()) {
+            puts(" [");
+            puts(cvtToStr(nodep->msb()));
+            puts(":0] ");
+        }
     }
     virtual void visit(AstConstDType* nodep) VL_OVERRIDE {
         putfs(nodep, "const ");
@@ -543,7 +583,7 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         iterateAndNextNull(nodep->rangep());
     }
     virtual void visit(AstNodeUOrStructDType* nodep) VL_OVERRIDE {
-        puts(nodep->verilogKwd()+" ");
+        puts(nodep->verilogKwd() + " ");
         if (nodep->packed()) puts("packed ");
         puts("\n");
         iterateAndNextNull(nodep->membersp());
@@ -556,16 +596,18 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
         puts("}");
     }
     virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
-        if (nodep->dotted()!="") {
-            putfs(nodep, nodep->dotted()); puts("."); puts(nodep->prettyName());
-        } else { putfs(nodep, nodep->prettyName()); }
+        if (nodep->dotted() != "") {
+            putfs(nodep, nodep->dotted());
+            puts(".");
+            puts(nodep->prettyName());
+        } else {
+            putfs(nodep, nodep->prettyName());
+        }
         puts("(");
         iterateAndNextNull(nodep->pinsp());
         puts(")");
     }
-    virtual void visit(AstArg* nodep) VL_OVERRIDE {
-        iterateAndNextNull(nodep->exprp());
-    }
+    virtual void visit(AstArg* nodep) VL_OVERRIDE { iterateAndNextNull(nodep->exprp()); }
     // Terminals
     virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->varScopep()) {
@@ -585,18 +627,19 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     }
 
     // Just iterate
-    virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
-    virtual void visit(AstScope* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstTopScope* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+    virtual void visit(AstScope* nodep) VL_OVERRIDE { iterateChildren(nodep); }
     virtual void visit(AstVar* nodep) VL_OVERRIDE {
         putfs(nodep, nodep->verilogKwd());
         puts(" ");
-        iterate(nodep->dtypep()); puts(" ");
+        iterate(nodep->dtypep());
+        puts(" ");
         puts(nodep->prettyName());
-        if (!m_suppressVarSemi) puts(";\n"); else puts("\n");
+        if (!m_suppressVarSemi) {
+            puts(";\n");
+        } else {
+            puts("\n");
+        }
     }
     virtual void visit(AstActive* nodep) VL_OVERRIDE {
         m_sensesp = nodep->sensesp();
@@ -612,15 +655,15 @@ class EmitVBaseVisitor : public EmitCBaseVisitor {
     virtual void visit(AstCell*) VL_OVERRIDE {}  // Handled outside the Visit class
     // Default
     virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        puts(string("\n???? // ")+nodep->prettyTypeName()+"\n");
+        puts(string("\n???? // ") + nodep->prettyTypeName() + "\n");
         iterateChildren(nodep);
         // Not v3fatalSrc so we keep processing
-        nodep->v3error("Internal: Unknown node type reached emitter: "<<nodep->prettyTypeName());
+        nodep->v3error("Internal: Unknown node type reached emitter: " << nodep->prettyTypeName());
     }
 
 public:
-    bool        m_suppressVarSemi;  // Suppress emitting semicolon for AstVars
-    explicit EmitVBaseVisitor(AstSenTree* domainp=NULL) {
+    bool m_suppressVarSemi;  // Suppress emitting semicolon for AstVars
+    explicit EmitVBaseVisitor(AstSenTree* domainp = NULL) {
         // Domain for printing one a ALWAYS under a ACTIVE
         m_suppressSemi = false;
         m_suppressVarSemi = false;
@@ -634,17 +677,18 @@ public:
 
 class EmitVFileVisitor : public EmitVBaseVisitor {
     // MEMBERS
-    V3OutFile*  m_ofp;
+    V3OutFile* m_ofp;
     // METHODS
-    V3OutFile*  ofp() const { return m_ofp; }
+    V3OutFile* ofp() const { return m_ofp; }
     virtual void puts(const string& str) { ofp()->puts(str); }
     virtual void putbs(const string& str) { ofp()->putbs(str); }
     virtual void putfs(AstNode*, const string& str) { putbs(str); }
     virtual void putqs(AstNode*, const string& str) { putbs(str); }
     virtual void putsNoTracking(const string& str) { ofp()->putsNoTracking(str); }
+
 public:
-    EmitVFileVisitor(AstNode* nodep, V3OutFile* ofp, bool trackText=false,
-                     bool suppressVarSemi=false) {
+    EmitVFileVisitor(AstNode* nodep, V3OutFile* ofp, bool trackText = false,
+                     bool suppressVarSemi = false) {
         m_ofp = ofp;
         m_trackText = trackText;
         m_suppressVarSemi = suppressVarSemi;
@@ -658,13 +702,14 @@ public:
 
 class EmitVStreamVisitor : public EmitVBaseVisitor {
     // MEMBERS
-    std::ostream&       m_os;
+    std::ostream& m_os;
     // METHODS
-    virtual void putsNoTracking(const string& str) { m_os<<str; }
+    virtual void putsNoTracking(const string& str) { m_os << str; }
     virtual void puts(const string& str) { putsNoTracking(str); }
     virtual void putbs(const string& str) { puts(str); }
     virtual void putfs(AstNode*, const string& str) { putbs(str); }
     virtual void putqs(AstNode*, const string& str) { putbs(str); }
+
 public:
     EmitVStreamVisitor(AstNode* nodep, std::ostream& os)
         : m_os(os) {
@@ -677,37 +722,41 @@ public:
 // Emit to a stream (perhaps stringstream)
 
 class EmitVPrefixedFormatter : public V3OutFormatter {
-    std::ostream&       m_os;
-    string      m_prefix;       // What to print at beginning of each line
-    int         m_flWidth;      // Padding of fileline
-    int         m_column;       // Rough location; need just zero or non-zero
-    FileLine*   m_prefixFl;
+    std::ostream& m_os;
+    string m_prefix;  // What to print at beginning of each line
+    int m_flWidth;  // Padding of fileline
+    int m_column;  // Rough location; need just zero or non-zero
+    FileLine* m_prefixFl;
     // METHODS
     virtual void putcOutput(char chr) {
         if (chr == '\n') {
             m_column = 0;
-            m_os<<chr;
+            m_os << chr;
         } else {
             if (m_column == 0) {
                 m_column = 10;
-                m_os<<m_prefixFl->ascii()+":";
-                m_os<<V3OutFile::indentSpaces(m_flWidth-(m_prefixFl->ascii().length()+1));
-                m_os<<" ";
-                m_os<<m_prefix;
+                m_os << m_prefixFl->ascii() + ":";
+                m_os << V3OutFile::indentSpaces(m_flWidth - (m_prefixFl->ascii().length() + 1));
+                m_os << " ";
+                m_os << m_prefix;
             }
             m_column++;
-            m_os<<chr;
+            m_os << chr;
         }
     }
+
 public:
     void prefixFl(FileLine* fl) { m_prefixFl = fl; }
     FileLine* prefixFl() const { return m_prefixFl; }
     int column() const { return m_column; }
     EmitVPrefixedFormatter(std::ostream& os, const string& prefix, int flWidth)
         : V3OutFormatter("__STREAM", V3OutFormatter::LA_VERILOG)
-        , m_os(os), m_prefix(prefix), m_flWidth(flWidth) {
+        , m_os(os)
+        , m_prefix(prefix)
+        , m_flWidth(flWidth) {
         m_column = 0;
-        m_prefixFl = v3Global.rootp()->fileline();  // NETLIST's fileline instead of NULL to avoid NULL checks
+        m_prefixFl = v3Global.rootp()
+                         ->fileline();  // NETLIST's fileline instead of NULL to avoid NULL checks
     }
     virtual ~EmitVPrefixedFormatter() {
         if (m_column) puts("\n");
@@ -716,7 +765,8 @@ public:
 
 class EmitVPrefixedVisitor : public EmitVBaseVisitor {
     // MEMBERS
-    EmitVPrefixedFormatter m_formatter;  // Special verilog formatter (Way down the inheritance is another unused V3OutFormatter)
+    EmitVPrefixedFormatter m_formatter;  // Special verilog formatter (Way down the
+                                         // inheritance is another unused V3OutFormatter)
     // METHODS
     virtual void putsNoTracking(const string& str) { m_formatter.putsNoTracking(str); }
     virtual void puts(const string& str) { m_formatter.puts(str); }
@@ -737,7 +787,8 @@ class EmitVPrefixedVisitor : public EmitVBaseVisitor {
 public:
     EmitVPrefixedVisitor(AstNode* nodep, std::ostream& os, const string& prefix, int flWidth,
                          AstSenTree* domainp, bool user3mark)
-        : EmitVBaseVisitor(domainp), m_formatter(os, prefix, flWidth) {
+        : EmitVBaseVisitor(domainp)
+        , m_formatter(os, prefix, flWidth) {
         if (user3mark) { AstUser3InUse::check(); }
         iterate(nodep);
     }
@@ -747,44 +798,22 @@ public:
 //######################################################################
 // EmitV class functions
 
-void V3EmitV::emitv() {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    if (1) {
-        // All-in-one file
-        V3OutVFile of (v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"__Vout.v");
-        of.putsHeader();
-        of.puts("# DESCR" "IPTION: Verilator output: Verilog representation of internal tree for debug\n");
-        EmitVFileVisitor visitor (v3Global.rootp(), &of);
-    } else {
-        // Process each module in turn
-        for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp;
-             modp = VN_CAST(modp->nextp(), NodeModule)) {
-            V3OutVFile of(v3Global.opt.makeDir() + "/" + EmitCBaseVisitor::prefixNameProtect(modp)
-                          + "__Vout.v");
-            of.putsHeader();
-            EmitVFileVisitor visitor(modp, &of);
-        }
-    }
-}
+void V3EmitV::verilogForTree(AstNode* nodep, std::ostream& os) { EmitVStreamVisitor(nodep, os); }
 
-void V3EmitV::verilogForTree(AstNode* nodep, std::ostream& os) {
-    EmitVStreamVisitor(nodep, os);
-}
-
-void V3EmitV::verilogPrefixedTree(AstNode* nodep, std::ostream& os,
-                                  const string& prefix, int flWidth,
-                                  AstSenTree* domainp, bool user3mark) {
+void V3EmitV::verilogPrefixedTree(AstNode* nodep, std::ostream& os, const string& prefix,
+                                  int flWidth, AstSenTree* domainp, bool user3mark) {
     EmitVPrefixedVisitor(nodep, os, prefix, flWidth, domainp, user3mark);
 }
 
 void V3EmitV::emitvFiles() {
-    UINFO(2,__FUNCTION__<<": "<<endl);
+    UINFO(2, __FUNCTION__ << ": " << endl);
     for (AstNodeFile* filep = v3Global.rootp()->filesp(); filep;
          filep = VN_CAST(filep->nextp(), NodeFile)) {
         AstVFile* vfilep = VN_CAST(filep, VFile);
         if (vfilep && vfilep->tblockp()) {
             V3OutVFile of(vfilep->name());
-            of.puts("// DESCR" "IPTION: Verilator generated Verilog\n");
+            of.puts("// DESCR"
+                    "IPTION: Verilator generated Verilog\n");
             EmitVFileVisitor visitor(vfilep->tblockp(), &of, true, true);
         }
     }
