@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -31,11 +27,9 @@
 
 class V3EmitV {
 public:
-    static void emitv();
-    static void verilogForTree(AstNode* nodep, std::ostream& os=std::cout);
-    static void verilogPrefixedTree(AstNode* nodep, std::ostream& os,
-                                    const string& prefix, int flWidth,
-                                    AstSenTree* domainp, bool user3mark);
+    static void verilogForTree(AstNode* nodep, std::ostream& os = std::cout);
+    static void verilogPrefixedTree(AstNode* nodep, std::ostream& os, const string& prefix,
+                                    int flWidth, AstSenTree* domainp, bool user3mark);
     static void emitvFiles();
 };
 
