@@ -2,22 +2,18 @@
 //*************************************************************************
 // DESCRIPTION: Verilator: File stream wrapper that understands indentation
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
-
+
 #ifndef _V3FILE_H_
 #define _V3FILE_H_ 1
 
@@ -29,6 +25,7 @@
 #include <stack>
 #include <set>
 #include <list>
+#include <vector>
 #include <fstream>
 
 //============================================================================
@@ -43,12 +40,12 @@ public:
     static std::ifstream* new_ifstream_nodepend(const string& filename) {
         return new std::ifstream(filename.c_str());
     }
-    static std::ofstream* new_ofstream(const string& filename, bool append=false) {
+    static std::ofstream* new_ofstream(const string& filename, bool append = false) {
         addTgtDepend(filename);
         return new_ofstream_nodepend(filename, append);
     }
-    static std::ofstream* new_ofstream_nodepend(const string& filename, bool append=false) {
-        if (filename != VL_DEV_NULL) createMakeDir();
+    static std::ofstream* new_ofstream_nodepend(const string& filename, bool append = false) {
+        createMakeDirFor(filename);
         if (append) {
             return new std::ofstream(filename.c_str(), std::ios::app);
         } else {
@@ -56,7 +53,7 @@ public:
         }
     }
     static FILE* new_fopen_w(const string& filename) {
-        if (filename != VL_DEV_NULL) createMakeDir();
+        createMakeDirFor(filename);
         addTgtDepend(filename);
         return fopen(filename.c_str(), "w");
     }
@@ -65,31 +62,34 @@ public:
     static void addSrcDepend(const string& filename);
     static void addTgtDepend(const string& filename);
     static void writeDepend(const string& filename);
+    static std::vector<string> getAllDeps();
     static void writeTimes(const string& filename, const string& cmdlineIn);
     static bool checkTimes(const string& filename, const string& cmdlineIn);
 
     // Directory utilities
+    static void createMakeDirFor(const string& filename);
     static void createMakeDir();
 };
 
 //============================================================================
-// V3InFilter: Read a input file, possibly filtering it, and caching contents
+// VInFilter: Read a input file, possibly filtering it, and caching contents
 
-class V3InFilterImp;
+class VInFilterImp;
 
-class V3InFilter {
+class VInFilter {
 public:
     // TYPES
     typedef std::list<string> StrList;
 
 private:
-    V3InFilterImp* m_impp;
+    VInFilterImp* m_impp;
 
     // CONSTRUCTORS
-    VL_UNCOPYABLE(V3InFilter);
+    VL_UNCOPYABLE(VInFilter);
+
 public:
-    explicit V3InFilter(const string& command);
-    ~V3InFilter();
+    explicit VInFilter(const string& command);
+    ~VInFilter();
 
     // METHODS
     // Read file contents and return it.  Return true on success.
@@ -101,12 +101,9 @@ public:
 
 class V3OutFormatter {
     // TYPES
-    enum MiscConsts {
-        MAXSPACE = 80};  // After this indent, stop indenting more
+    enum MiscConsts { MAXSPACE = 80 };  // After this indent, stop indenting more
 public:
-    enum AlignClass {
-        AL_AUTO = 0,
-        AL_STATIC = 1};
+    enum AlignClass { AL_AUTO = 0, AL_STATIC = 1 };
     enum Language {
         LA_C = 0,
         LA_VERILOG = 1,
@@ -116,26 +113,26 @@ public:
 
 private:
     // MEMBERS
-    string      m_filename;
-    Language    m_lang;         // Indenting Verilog code
-    int         m_blockIndent;  // Characters per block indent
-    int         m_commaWidth;   // Width after which to break at ,'s
-    int         m_lineno;
-    int         m_column;
-    int         m_nobreak;      // Basic operator or begin paren, don't break next
-    bool        m_prependIndent;
-    int         m_indentLevel;  // Current {} indentation
+    string m_filename;
+    Language m_lang;  // Indenting Verilog code
+    int m_blockIndent;  // Characters per block indent
+    int m_commaWidth;  // Width after which to break at ,'s
+    int m_lineno;
+    int m_column;
+    int m_nobreak;  // Basic operator or begin paren, don't break next
+    bool m_prependIndent;
+    int m_indentLevel;  // Current {} indentation
     std::stack<int> m_parenVec;  // Stack of columns where last ( was
-    int         m_bracketLevel;  // Intenting = { block, indicates number of {'s seen.
+    int m_bracketLevel;  // Intenting = { block, indicates number of {'s seen.
 
     int endLevels(const char* strg);
-    const char* indentStr(int num);
     void putcNoTracking(char chr);
 
 public:
     V3OutFormatter(const string& filename, Language lang);
     virtual ~V3OutFormatter() {}
     // ACCESSORS
+    string filename() const { return m_filename; }
     int column() const { return m_column; }
     int blockIndent() const { return m_blockIndent; }
     void blockIndent(int flag) { m_blockIndent = flag; }
@@ -147,20 +144,28 @@ public:
     void putsQuoted(const string& strg);
     void putBreak();  // Print linebreak if line is too wide
     void putBreakExpr();  // Print linebreak in expression if line is too wide
-    void putbs(const char* strg) { putBreakExpr(); puts(strg); }
-    void putbs(const string& strg) {  putBreakExpr(); puts(strg); }
+    void putbs(const char* strg) {
+        putBreakExpr();
+        puts(strg);
+    }
+    void putbs(const string& strg) {
+        putBreakExpr();
+        puts(strg);
+    }
     bool exceededWidth() const { return m_column > m_commaWidth; }
     bool tokenStart(const char* cp, const char* cmp);
     bool tokenEnd(const char* cp);
     void indentInc() { m_indentLevel += m_blockIndent; }
     void indentDec() {
         m_indentLevel -= m_blockIndent;
-        UASSERT(m_indentLevel>=0, ": "<<m_filename<<": Underflow of indentation");
+        UASSERT(m_indentLevel >= 0, ": " << m_filename << ": Underflow of indentation");
     }
     void blockInc() { m_parenVec.push(m_indentLevel + m_blockIndent); }
-    void blockDec() { if (!m_parenVec.empty()) m_parenVec.pop(); }
+    void blockDec() {
+        if (!m_parenVec.empty()) m_parenVec.pop();
+    }
     // STATIC METHODS
-    static const string indentSpaces(int num);
+    static string indentSpaces(int num);
     // Add escaped characters to strings
     static string quoteNameControls(const string& namein, Language lang = LA_C);
 
@@ -173,41 +178,41 @@ public:
 
 class V3OutFile : public V3OutFormatter {
     // MEMBERS
-    FILE*       m_fp;
+    FILE* m_fp;
+
 public:
     V3OutFile(const string& filename, V3OutFormatter::Language lang);
     virtual ~V3OutFile();
     void putsForceIncs();
+
 private:
     // CALLBACKS
     virtual void putcOutput(char chr) { fputc(chr, m_fp); }
 };
 
-//######################################################################
-// V3OutCFile: A class for abstracting out SystemC/C++ details
-
 class V3OutCFile : public V3OutFile {
-    int         m_private;
+    int m_guard;  // Created header guard
+    int m_private;  // 1 = Most recently emitted private:, 2 = public:
 public:
-    explicit V3OutCFile(const string& filename) : V3OutFile(filename, V3OutFormatter::LA_C) {
+    explicit V3OutCFile(const string& filename)
+        : V3OutFile(filename, V3OutFormatter::LA_C)
+        , m_guard(false) {
         resetPrivate();
     }
     virtual ~V3OutCFile() {}
-    virtual void putsCellDecl(const string& classname, const string& cellname) {
-        string classStar = classname + "*";
-        this->printf("%-19s\t%s;\n", classStar.c_str(), cellname.c_str());
-    }
     virtual void putsHeader() { puts("// Verilated -*- C++ -*-\n"); }
-    virtual void putsIntTopInclude() {
-        putsForceIncs();
+    virtual void putsIntTopInclude() { putsForceIncs(); }
+    virtual void putsGuard();
+    virtual void putsEndGuard() {
+        if (m_guard) puts("\n#endif  // guard\n");
     }
     // Print out public/privates
     void resetPrivate() { m_private = 0; }
     void putsPrivate(bool setPrivate) {
-        if (setPrivate && m_private!=1) {
+        if (setPrivate && m_private != 1) {
             puts("private:\n");
             m_private = 1;
-        } else if (!setPrivate && m_private!=2) {
+        } else if (!setPrivate && m_private != 2) {
             puts("public:\n");
             m_private = 2;
         }
@@ -216,7 +221,8 @@ public:
 
 class V3OutScFile : public V3OutCFile {
 public:
-    explicit V3OutScFile(const string& filename) : V3OutCFile(filename) {}
+    explicit V3OutScFile(const string& filename)
+        : V3OutCFile(filename) {}
     virtual ~V3OutScFile() {}
     virtual void putsHeader() { puts("// Verilated -*- SystemC -*-\n"); }
     virtual void putsIntTopInclude() {
@@ -255,4 +261,21 @@ public:
     void puts(const string& strg) { putsNoTracking(strg); }
 };
 
+//============================================================================
+// VIdProtect: Hash identifier names in output files to protect them
+
+class VIdProtectImp;
+
+class VIdProtect {
+public:
+    // METHODS
+    // Rename to a new encoded string (unless earlier passthru'ed)
+    static string protect(const string& old) { return protectIf(old, true); }
+    static string protectIf(const string& old, bool doIt = true);
+    // Rename words to a new encoded string
+    static string protectWordsIf(const string& old, bool doIt = true);
+    // Write map of renames to output file
+    static void writeMapFile(const string& filename);
+};
+
 #endif  // Guard
