@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2004-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2004-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -40,10 +36,6 @@ AstNetlist* V3Global::makeNetlist() {
 
 void V3Global::checkTree() { rootp()->checkTree(); }
 
-void V3Global::clear() {
-    if (m_rootp) VL_DO_CLEAR(m_rootp->deleteTree(), m_rootp = NULL);
-}
-
 void V3Global::readFiles() {
     // NODE STATE
     //   AstNode::user4p()      // VSymEnt*    Package and typedef symbol names
@@ -80,7 +72,24 @@ void V3Global::readFiles() {
 }
 
 void V3Global::dumpCheckGlobalTree(const string& stagename, int newNumber, bool doDump) {
-    v3Global.rootp()->dumpTreeFile(v3Global.debugFilename(stagename + ".tree", newNumber),
-                                   false, doDump);
+    v3Global.rootp()->dumpTreeFile(v3Global.debugFilename(stagename + ".tree", newNumber), false,
+                                   doDump);
     if (v3Global.opt.stats()) V3Stats::statsStage(stagename);
 }
+
+const std::string& V3Global::ptrToId(const void* p) {
+    PtrToIdMap::iterator it = m_ptrToId.find(p);
+    if (it == m_ptrToId.end()) {
+        std::ostringstream os;
+        if (p) {
+            os << "(";
+            unsigned id = m_ptrToId.size();
+            do { os << static_cast<char>('A' + id % 26); } while (id /= 26);
+            os << ")";
+        } else {
+            os << "0";
+        }
+        it = m_ptrToId.insert(std::make_pair(p, os.str())).first;
+    }
+    return it->second;
+}
