@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -25,7 +21,6 @@
 #include "V3Graph.h"
 
 #include <algorithm>
-#include <cstdarg>
 #include <list>
 #include <vector>
 
@@ -36,19 +31,20 @@
 
 class GraphAcycVertex : public V3GraphVertex {
     // user() is used for various sub-algorithm pieces
-    V3GraphVertex*      m_origVertexp;          // Pointer to first vertex this represents
+    V3GraphVertex* m_origVertexp;  // Pointer to first vertex this represents
 protected:
     friend class GraphAcyc;
-    V3ListEnt<GraphAcycVertex*> m_work;         // List of vertices with optimization work left
-    uint32_t            m_storedRank;           // Rank held until commit to edge placement
-    bool                m_onWorkList;           // True if already on list of work to do
-    bool                m_deleted;              // True if deleted
+    V3ListEnt<GraphAcycVertex*> m_work;  // List of vertices with optimization work left
+    uint32_t m_storedRank;  // Rank held until commit to edge placement
+    bool m_onWorkList;  // True if already on list of work to do
+    bool m_deleted;  // True if deleted
 public:
-
     GraphAcycVertex(V3Graph* graphp, V3GraphVertex* origVertexp)
-        : V3GraphVertex(graphp), m_origVertexp(origVertexp)
-        , m_storedRank(0), m_onWorkList(false), m_deleted(false) {
-    }
+        : V3GraphVertex(graphp)
+        , m_origVertexp(origVertexp)
+        , m_storedRank(0)
+        , m_onWorkList(false)
+        , m_deleted(false) {}
     virtual ~GraphAcycVertex() {}
     V3GraphVertex* origVertexp() const { return m_origVertexp; }
     void setDelete() { m_deleted = true; }
@@ -64,28 +60,28 @@ class GraphAcycEdge : public V3GraphEdge {
     // userp() is always used to point to the head original graph edge
 private:
     typedef std::list<V3GraphEdge*> OrigEdgeList;  // List of orig edges, see also GraphAcyc's decl
-    V3GraphEdge*        origEdgep() const {
+    V3GraphEdge* origEdgep() const {
         OrigEdgeList* oEListp = static_cast<OrigEdgeList*>(userp());
-        if (!oEListp) v3fatalSrc("No original edge associated with acyc edge "<<this<<endl);
+        if (!oEListp) v3fatalSrc("No original edge associated with acyc edge " << this << endl);
         return (oEListp->front());
     }
+
 public:
-    GraphAcycEdge(V3Graph* graphp, V3GraphVertex* fromp, V3GraphVertex* top,
-                  int weight, bool cutable=false)
-        : V3GraphEdge(graphp, fromp, top, weight, cutable) {
-    }
+    GraphAcycEdge(V3Graph* graphp, V3GraphVertex* fromp, V3GraphVertex* top, int weight,
+                  bool cutable = false)
+        : V3GraphEdge(graphp, fromp, top, weight, cutable) {}
     virtual ~GraphAcycEdge() {}
     // yellow=we might still cut it, else oldEdge: yellowGreen=made uncutable, red=uncutable
-    virtual string dotColor() const { return (cutable()?"yellow":origEdgep()->dotColor()); }
+    virtual string dotColor() const { return (cutable() ? "yellow" : origEdgep()->dotColor()); }
 };
 
 //--------------------------------------------------------------------
 
 struct GraphAcycEdgeCmp {
-    inline bool operator() (const V3GraphEdge* lhsp, const V3GraphEdge* rhsp) const {
-        if (lhsp->weight() > rhsp->weight()) return 1;  // LHS goes first
-        if (lhsp->weight() < rhsp->weight()) return 0;  // RHS goes first
-        return 0;
+    inline bool operator()(const V3GraphEdge* lhsp, const V3GraphEdge* rhsp) const {
+        if (lhsp->weight() > rhsp->weight()) return true;  // LHS goes first
+        if (lhsp->weight() < rhsp->weight()) return false;  // RHS goes first
+        return false;
     }
 };
 
@@ -94,7 +90,8 @@ struct GraphAcycEdgeCmp {
 // CLASSES
 class GraphAcyc {
 private:
-    typedef std::list<V3GraphEdge*> OrigEdgeList;  // List of orig edges, see also GraphAcycEdge's decl
+    typedef std::list<V3GraphEdge*>
+        OrigEdgeList;  // List of orig edges, see also GraphAcycEdge's decl
     // GRAPH USERS
     //  origGraph
     //    GraphVertex::user()   GraphAycVerted* New graph node
@@ -102,12 +99,12 @@ private:
     //    GraphEdge::user()     OrigEdgeList*   Old graph edges
     //    GraphVertex::user     bool            Detection of loops in simplifyDupIterate
     // MEMBERS
-    V3Graph*            m_origGraphp;           // Original graph
-    V3Graph             m_breakGraph;           // Graph with only breakable edges represented
-    V3List<GraphAcycVertex*>    m_work;         // List of vertices with optimization work left
+    V3Graph* m_origGraphp;  // Original graph
+    V3Graph m_breakGraph;  // Graph with only breakable edges represented
+    V3List<GraphAcycVertex*> m_work;  // List of vertices with optimization work left
     std::vector<OrigEdgeList*> m_origEdgeDelp;  // List of deletions to do when done
-    V3EdgeFuncP         m_origEdgeFuncp;        // Function that says we follow this edge (in original graph)
-    uint32_t            m_placeStep;            // Number that user() must be equal to to indicate processing
+    V3EdgeFuncP m_origEdgeFuncp;  // Function that says we follow this edge (in original graph)
+    uint32_t m_placeStep;  // Number that user() must be equal to to indicate processing
 
     static int debug() { return V3Graph::debug(); }
 
@@ -131,8 +128,8 @@ private:
     }
     V3GraphEdge* edgeFromEdge(V3GraphEdge* oldedgep, V3GraphVertex* fromp, V3GraphVertex* top) {
         // Make new breakGraph edge, with old edge as a template
-        GraphAcycEdge* newEdgep = new GraphAcycEdge(&m_breakGraph, fromp, top,
-                                                    oldedgep->weight(), oldedgep->cutable());
+        GraphAcycEdge* newEdgep = new GraphAcycEdge(&m_breakGraph, fromp, top, oldedgep->weight(),
+                                                    oldedgep->cutable());
         newEdgep->userp(oldedgep->userp());  // Keep pointer to OrigEdgeList
         return newEdgep;
     }
@@ -157,16 +154,18 @@ private:
     }
     void cutOrigEdge(V3GraphEdge* breakEdgep, const char* why) {
         // From the break edge, cut edges in original graph it represents
-        UINFO(8,why<<" CUT "<<breakEdgep->fromp()<<endl);
+        UINFO(8, why << " CUT " << breakEdgep->fromp() << endl);
         breakEdgep->cut();
         OrigEdgeList* oEListp = static_cast<OrigEdgeList*>(breakEdgep->userp());
-        if (!oEListp) v3fatalSrc("No original edge associated with cutting edge "
-                                 <<breakEdgep<<endl);
+        if (!oEListp) {
+            v3fatalSrc("No original edge associated with cutting edge " << breakEdgep << endl);
+        }
         // The breakGraph edge may represent multiple real edges; cut them all
         for (OrigEdgeList::iterator it = oEListp->begin(); it != oEListp->end(); ++it) {
             V3GraphEdge* origEdgep = *it;
             origEdgep->cut();
-            UINFO(8,"  "<<why<<"   "<<origEdgep->fromp()<<" ->"<<origEdgep->top()<<endl);
+            UINFO(8,
+                  "  " << why << "   " << origEdgep->fromp() << " ->" << origEdgep->top() << endl);
         }
     }
     // Work Queue
@@ -182,7 +181,9 @@ private:
     void workPop() {
         GraphAcycVertex* avertexp = workBeginp();
         avertexp->m_onWorkList = false;
-        avertexp->m_work.unlink(m_work, avertexp); }
+        avertexp->m_work.unlink(m_work, avertexp);
+    }
+
 public:
     // CONSTRUCTORS
     GraphAcyc(V3Graph* origGraphp, V3EdgeFuncP edgeFuncp) {
@@ -209,8 +210,8 @@ void GraphAcyc::buildGraph(V3Graph* origGraphp) {
     // For each old node, make a new graph node for optimization
     origGraphp->userClearVertices();
     origGraphp->userClearEdges();
-    for (V3GraphVertex* overtexp = origGraphp->verticesBeginp();
-         overtexp; overtexp = overtexp->verticesNextp()) {
+    for (V3GraphVertex* overtexp = origGraphp->verticesBeginp(); overtexp;
+         overtexp = overtexp->verticesNextp()) {
         if (overtexp->color()) {
             GraphAcycVertex* avertexp = new GraphAcycVertex(&m_breakGraph, overtexp);
             overtexp->userp(avertexp);  // Stash so can look up later
@@ -218,8 +219,8 @@ void GraphAcyc::buildGraph(V3Graph* origGraphp) {
     }
 
     // Build edges between logic vertices
-    for (V3GraphVertex* overtexp = origGraphp->verticesBeginp();
-         overtexp; overtexp = overtexp->verticesNextp()) {
+    for (V3GraphVertex* overtexp = origGraphp->verticesBeginp(); overtexp;
+         overtexp = overtexp->verticesNextp()) {
         if (overtexp->color()) {
             GraphAcycVertex* avertexp = static_cast<GraphAcycVertex*>(overtexp->userp());
             buildGraphIterate(overtexp, avertexp);
@@ -229,15 +230,15 @@ void GraphAcyc::buildGraph(V3Graph* origGraphp) {
 
 void GraphAcyc::buildGraphIterate(V3GraphVertex* overtexp, GraphAcycVertex* avertexp) {
     // Make new edges
-    for (V3GraphEdge* edgep = overtexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
+    for (V3GraphEdge* edgep = overtexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
         if (origFollowEdge(edgep)) {  // not cut
             V3GraphVertex* toVertexp = edgep->top();
             if (toVertexp->color()) {
                 GraphAcycVertex* toAVertexp = static_cast<GraphAcycVertex*>(toVertexp->userp());
                 // Replicate the old edge into the new graph
                 // There may be multiple edges between same pairs of vertices
-                V3GraphEdge* breakEdgep = new GraphAcycEdge
-                    (&m_breakGraph, avertexp, toAVertexp, edgep->weight(), edgep->cutable());
+                V3GraphEdge* breakEdgep = new GraphAcycEdge(&m_breakGraph, avertexp, toAVertexp,
+                                                            edgep->weight(), edgep->cutable());
                 addOrigEdgep(breakEdgep, edgep);  // So can find original edge
             }
         }
@@ -246,8 +247,8 @@ void GraphAcyc::buildGraphIterate(V3GraphVertex* overtexp, GraphAcycVertex* aver
 
 void GraphAcyc::simplify(bool allowCut) {
     // Add all nodes to list of work to do
-    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp();
-         vertexp; vertexp = vertexp->verticesNextp()) {
+    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp(); vertexp;
+         vertexp = vertexp->verticesNextp()) {
         workPush(vertexp);
     }
     // Optimize till everything finished
@@ -271,7 +272,8 @@ void GraphAcyc::simplify(bool allowCut) {
 
 void GraphAcyc::deleteMarked() {
     // Delete nodes marked for removal
-    for (V3GraphVertex* nextp, *vertexp = m_breakGraph.verticesBeginp(); vertexp; vertexp=nextp) {
+    for (V3GraphVertex *nextp, *vertexp = m_breakGraph.verticesBeginp(); vertexp;
+         vertexp = nextp) {
         nextp = vertexp->verticesNextp();
         GraphAcycVertex* avertexp = static_cast<GraphAcycVertex*>(vertexp);
         if (avertexp->isDelete()) {
@@ -285,18 +287,18 @@ void GraphAcyc::simplifyNone(GraphAcycVertex* avertexp) {
     // Likewise, vertices with no outputs
     if (avertexp->isDelete()) return;
     if (avertexp->inEmpty() || avertexp->outEmpty()) {
-        UINFO(9,"  SimplifyNoneRemove "<<avertexp<<endl);
+        UINFO(9, "  SimplifyNoneRemove " << avertexp << endl);
         avertexp->setDelete();  // Mark so we won't delete it twice
         // Remove edges
         while (V3GraphEdge* edgep = avertexp->outBeginp()) {
             V3GraphVertex* otherVertexp = edgep->top();
-            //UINFO(9,"  out "<<otherVertexp<<endl);
+            // UINFO(9, "  out " << otherVertexp << endl);
             VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
             workPush(otherVertexp);
         }
         while (V3GraphEdge* edgep = avertexp->inBeginp()) {
             V3GraphVertex* otherVertexp = edgep->fromp();
-            //UINFO(9,"  in  "<<otherVertexp<<endl);
+            // UINFO(9, "  in  " << otherVertexp << endl);
             VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
             workPush(otherVertexp);
         }
@@ -313,23 +315,25 @@ void GraphAcyc::simplifyOne(GraphAcycVertex* avertexp) {
         V3GraphVertex* outVertexp = outEdgep->top();
         // The in and out may be the same node; we'll make a loop
         // The in OR out may be THIS node; we can't delete it then.
-        if (inVertexp!=avertexp && outVertexp!=avertexp) {
-            UINFO(9,"  SimplifyOneRemove "<<avertexp<<endl);
+        if (inVertexp != avertexp && outVertexp != avertexp) {
+            UINFO(9, "  SimplifyOneRemove " << avertexp << endl);
             avertexp->setDelete();  // Mark so we won't delete it twice
             // Make a new edge connecting the two vertices directly
             // If both are breakable, we pick the one with less weight, else it's arbitrary
             // We can forget about the origEdge list for the "non-selected" set of edges,
             // as we need to break only one set or the other set of edges, not both.
             // (This is why we must give preference to the cutable set.)
-            V3GraphEdge* templateEdgep = ( (inEdgep->cutable()
-                                            && (!outEdgep->cutable()
-                                                || inEdgep->weight()<outEdgep->weight() ))
-                                           ? inEdgep : outEdgep);
+            V3GraphEdge* templateEdgep
+                = ((inEdgep->cutable()
+                    && (!outEdgep->cutable() || inEdgep->weight() < outEdgep->weight()))
+                       ? inEdgep
+                       : outEdgep);
             // cppcheck-suppress leakReturnValNotUsed
             edgeFromEdge(templateEdgep, inVertexp, outVertexp);
             // Remove old edge
             VL_DO_DANGLING(inEdgep->unlinkDelete(), inEdgep);
-            VL_DO_DANGLING(outEdgep->unlinkDelete(), outEdgep); VL_DANGLING(templateEdgep);
+            VL_DO_DANGLING(outEdgep->unlinkDelete(), outEdgep);
+            VL_DANGLING(templateEdgep);
             workPush(inVertexp);
             workPush(outVertexp);
         }
@@ -344,16 +348,17 @@ void GraphAcyc::simplifyOut(GraphAcycVertex* avertexp) {
         V3GraphEdge* outEdgep = avertexp->outBeginp();
         if (!outEdgep->cutable()) {
             V3GraphVertex* outVertexp = outEdgep->top();
-            UINFO(9,"  SimplifyOutRemove "<<avertexp<<endl);
+            UINFO(9, "  SimplifyOutRemove " << avertexp << endl);
             avertexp->setDelete();  // Mark so we won't delete it twice
-            for (V3GraphEdge* nextp, *inEdgep = avertexp->inBeginp(); inEdgep; inEdgep=nextp) {
+            for (V3GraphEdge *nextp, *inEdgep = avertexp->inBeginp(); inEdgep; inEdgep = nextp) {
                 nextp = inEdgep->inNextp();
                 V3GraphVertex* inVertexp = inEdgep->fromp();
                 if (inVertexp == avertexp) {
-                    if (debug()) v3error("Non-cutable edge forms a loop, vertex="<<avertexp);
+                    if (debug()) v3error("Non-cutable edge forms a loop, vertex=" << avertexp);
                     v3error("Circular logic when ordering code (non-cutable edge loop)");
-                    m_origGraphp->reportLoops(&V3GraphEdge::followNotCutable,
-                                              avertexp->origVertexp());  // calls OrderGraph::loopsVertexCb
+                    m_origGraphp->reportLoops(
+                        &V3GraphEdge::followNotCutable,
+                        avertexp->origVertexp());  // calls OrderGraph::loopsVertexCb
                     // Things are unlikely to end well at this point,
                     // but we'll try something to get to further errors...
                     inEdgep->cutable(true);
@@ -376,11 +381,11 @@ void GraphAcyc::simplifyDup(GraphAcycVertex* avertexp) {
     // Remove redundant edges
     if (avertexp->isDelete()) return;
     // Clear marks
-    for (V3GraphEdge* edgep = avertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
+    for (V3GraphEdge* edgep = avertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
         edgep->top()->userp(NULL);
     }
     // Mark edges and detect duplications
-    for (V3GraphEdge* nextp, *edgep = avertexp->outBeginp(); edgep; edgep=nextp) {
+    for (V3GraphEdge *nextp, *edgep = avertexp->outBeginp(); edgep; edgep = nextp) {
         nextp = edgep->outNextp();
         V3GraphVertex* outVertexp = edgep->top();
         V3GraphEdge* prevEdgep = static_cast<V3GraphEdge*>(outVertexp->userp());
@@ -388,16 +393,16 @@ void GraphAcyc::simplifyDup(GraphAcycVertex* avertexp) {
             if (!prevEdgep->cutable()) {
                 // !cutable duplicates prev !cutable: we can ignore it, redundant
                 //  cutable duplicates prev !cutable: know it's not a relevant loop, ignore it
-                UINFO(8,"    DelDupEdge "<<avertexp<<" -> "<<edgep->top()<<endl);
+                UINFO(8, "    DelDupEdge " << avertexp << " -> " << edgep->top() << endl);
                 VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
             } else if (!edgep->cutable()) {
                 // !cutable duplicates prev  cutable: delete the earlier cutable
-                UINFO(8,"    DelDupPrev "<<avertexp<<" -> "<<prevEdgep->top()<<endl);
+                UINFO(8, "    DelDupPrev " << avertexp << " -> " << prevEdgep->top() << endl);
                 VL_DO_DANGLING(prevEdgep->unlinkDelete(), prevEdgep);
                 outVertexp->userp(edgep);
             } else {
                 //  cutable duplicates prev  cutable: combine weights
-                UINFO(8,"    DelDupComb "<<avertexp<<" -> "<<edgep->top()<<endl);
+                UINFO(8, "    DelDupComb " << avertexp << " -> " << edgep->top() << endl);
                 prevEdgep->weight(prevEdgep->weight() + edgep->weight());
                 addOrigEdgep(prevEdgep, edgep);
                 VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
@@ -414,9 +419,9 @@ void GraphAcyc::simplifyDup(GraphAcycVertex* avertexp) {
 void GraphAcyc::cutBasic(GraphAcycVertex* avertexp) {
     // Detect and cleanup any loops from node to itself
     if (avertexp->isDelete()) return;
-    for (V3GraphEdge* nextp, *edgep = avertexp->outBeginp(); edgep; edgep=nextp) {
+    for (V3GraphEdge *nextp, *edgep = avertexp->outBeginp(); edgep; edgep = nextp) {
         nextp = edgep->outNextp();
-        if (edgep->cutable() && edgep->top()==avertexp) {
+        if (edgep->cutable() && edgep->top() == avertexp) {
             cutOrigEdge(edgep, "  Cut Basic");
             VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
             workPush(avertexp);
@@ -428,14 +433,14 @@ void GraphAcyc::cutBackward(GraphAcycVertex* avertexp) {
     // If a cutable edge is from A->B, and there's a non-cutable edge B->A, then must cut!
     if (avertexp->isDelete()) return;
     // Clear marks
-    for (V3GraphEdge* edgep = avertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
+    for (V3GraphEdge* edgep = avertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
         edgep->top()->user(false);
     }
-    for (V3GraphEdge* edgep = avertexp->inBeginp(); edgep; edgep=edgep->inNextp()) {
+    for (V3GraphEdge* edgep = avertexp->inBeginp(); edgep; edgep = edgep->inNextp()) {
         if (!edgep->cutable()) edgep->fromp()->user(true);
     }
     // Detect duplications
-    for (V3GraphEdge* nextp, *edgep = avertexp->outBeginp(); edgep; edgep=nextp) {
+    for (V3GraphEdge *nextp, *edgep = avertexp->outBeginp(); edgep; edgep = nextp) {
         nextp = edgep->outNextp();
         if (edgep->cutable() && edgep->top()->user()) {
             cutOrigEdge(edgep, "  Cut A->B->A");
@@ -450,25 +455,22 @@ void GraphAcyc::place() {
 
     // Make a list of all cutable edges in the graph
     int numEdges = 0;
-    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp();
-         vertexp; vertexp = vertexp->verticesNextp()) {
-        for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
-            if (edgep->weight() && edgep->cutable()) {
-                numEdges++;
-            }
+    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp(); vertexp;
+         vertexp = vertexp->verticesNextp()) {
+        for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
+            if (edgep->weight() && edgep->cutable()) ++numEdges;
         }
     }
-    UINFO(4, "    Cutable edges = "<<numEdges<<endl);
+    UINFO(4, "    Cutable edges = " << numEdges << endl);
 
     std::vector<V3GraphEdge*> edges;  // List of all edges to be processed
-    edges.reserve(numEdges+1);  // Make the vector properly sized right off the bat -- faster than reallocating
-    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp();
-         vertexp; vertexp = vertexp->verticesNextp()) {
+    // Make the vector properly sized right off the bat -- faster than reallocating
+    edges.reserve(numEdges + 1);
+    for (V3GraphVertex* vertexp = m_breakGraph.verticesBeginp(); vertexp;
+         vertexp = vertexp->verticesNextp()) {
         vertexp->user(0);  // Clear in prep of next step
-        for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
-            if (edgep->weight() && edgep->cutable()) {
-                edges.push_back(edgep);
-            }
+        for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
+            if (edgep->weight() && edgep->cutable()) edges.push_back(edgep);
         }
     }
 
@@ -477,7 +479,7 @@ void GraphAcyc::place() {
 
     // Process each edge in weighted order
     m_placeStep = 10;
-    for (std::vector<V3GraphEdge*>::iterator it = edges.begin(); it!=edges.end(); ++it) {
+    for (std::vector<V3GraphEdge*>::iterator it = edges.begin(); it != edges.end(); ++it) {
         V3GraphEdge* edgep = (*it);
         placeTryEdge(edgep);
     }
@@ -486,22 +488,21 @@ void GraphAcyc::place() {
 void GraphAcyc::placeTryEdge(V3GraphEdge* edgep) {
     // Try to make this edge uncutable
     m_placeStep++;
-    UINFO(8, "    PlaceEdge s"<<m_placeStep<<" w"<<edgep->weight()<<" "<<edgep->fromp()<<endl);
+    UINFO(8, "    PlaceEdge s" << m_placeStep << " w" << edgep->weight() << " " << edgep->fromp()
+                               << endl);
     // Make the edge uncutable so we detect it in placement
     edgep->cutable(false);
     // Vertex::m_user begin: number indicates this edge was completed
     // Try to assign ranks, presuming this edge is in place
     // If we come across user()==placestep, we've detected a loop and must back out
-    bool loop = placeIterate(static_cast<GraphAcycVertex*>(edgep->top()),
-                             edgep->fromp()->rank()+1);
+    bool loop
+        = placeIterate(static_cast<GraphAcycVertex*>(edgep->top()), edgep->fromp()->rank() + 1);
     if (!loop) {
         // No loop, we can keep it as uncutable
         // Commit the new ranks we calculated
         // Just cleanup the list.  If this is slow, we can add another set of
         // user counters to avoid cleaning up the list.
-        while (workBeginp()) {
-            workPop();
-        }
+        while (workBeginp()) workPop();
     } else {
         // Adding this edge would cause a loop, kill it
         edgep->cutable(true);  // So graph still looks pretty
@@ -530,9 +531,9 @@ bool GraphAcyc::placeIterate(GraphAcycVertex* vertexp, uint32_t currentRank) {
     }
     vertexp->rank(currentRank);
     // Follow all edges and increase their ranks
-    for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep=edgep->outNextp()) {
+    for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
         if (edgep->weight() && !edgep->cutable()) {
-            if (placeIterate(static_cast<GraphAcycVertex*>(edgep->top()), currentRank+1)) {
+            if (placeIterate(static_cast<GraphAcycVertex*>(edgep->top()), currentRank + 1)) {
                 // We don't need to reset user(); we'll use a different placeStep for the next edge
                 return true;  // Loop detected
             }
@@ -555,33 +556,33 @@ void GraphAcyc::main() {
     // edges (and thus can't represent loops - if we did the unbreakable
     // marking right, anyways)
     buildGraph(m_origGraphp);
-    if (debug()>=6) m_breakGraph.dumpDotFilePrefixed("acyc_pre");
+    if (debug() >= 6) m_breakGraph.dumpDotFilePrefixed("acyc_pre");
 
     // Perform simple optimizations before any cuttings
     simplify(false);
-    if (debug()>=5) m_breakGraph.dumpDotFilePrefixed("acyc_simp");
+    if (debug() >= 5) m_breakGraph.dumpDotFilePrefixed("acyc_simp");
 
     UINFO(4, " Cutting trivial loops\n");
     simplify(true);
-    if (debug()>=6) m_breakGraph.dumpDotFilePrefixed("acyc_mid");
+    if (debug() >= 6) m_breakGraph.dumpDotFilePrefixed("acyc_mid");
 
     UINFO(4, " Ranking\n");
     m_breakGraph.rank(&V3GraphEdge::followNotCutable);
-    if (debug()>=6) m_breakGraph.dumpDotFilePrefixed("acyc_rank");
+    if (debug() >= 6) m_breakGraph.dumpDotFilePrefixed("acyc_rank");
 
     UINFO(4, " Placement\n");
     place();
-    if (debug()>=6) m_breakGraph.dumpDotFilePrefixed("acyc_place");
+    if (debug() >= 6) m_breakGraph.dumpDotFilePrefixed("acyc_place");
 
     UINFO(4, " Final Ranking\n");
     // Only needed to assert there are no loops in completed graph
     m_breakGraph.rank(&V3GraphEdge::followAlwaysTrue);
-    if (debug()>=6) m_breakGraph.dumpDotFilePrefixed("acyc_done");
+    if (debug() >= 6) m_breakGraph.dumpDotFilePrefixed("acyc_done");
 }
 
 void V3Graph::acyclic(V3EdgeFuncP edgeFuncp) {
     UINFO(4, "Acyclic\n");
-    GraphAcyc acyc (this, edgeFuncp);
+    GraphAcyc acyc(this, edgeFuncp);
     acyc.main();
     UINFO(4, "Acyclic done\n");
 }
