@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -47,30 +43,26 @@ public:
         _ENUM_END
     };
     const char* ascii() const {
-        const char* const names[] = {
-            // These must match the `begin_keywords values.
-            " ERROR",
-            "1364-1995",
-            "1364-2001",
-            "1364-2005",
-            "1800-2005",
-            "1800-2009",
-            "1800-2012",
-            "1800-2017"
-        };
+        const char* const names[] = {// These must match the `begin_keywords values.
+                                     " ERROR",    "1364-1995", "1364-2001", "1364-2005",
+                                     "1800-2005", "1800-2009", "1800-2012", "1800-2017"};
         return names[m_e];
     }
     static V3LangCode mostRecent() { return V3LangCode(L1800_2017); }
-    bool systemVerilog() const { return m_e == L1800_2005 || m_e == L1800_2009
-            || m_e == L1800_2012 || m_e == L1800_2017; }
+    bool systemVerilog() const {
+        return m_e == L1800_2005 || m_e == L1800_2009 || m_e == L1800_2012 || m_e == L1800_2017;
+    }
     bool legal() const { return m_e != L_ERROR; }
     //
     enum en m_e;
-    inline V3LangCode() : m_e(L_ERROR) {}
+    inline V3LangCode()
+        : m_e(L_ERROR) {}
     // cppcheck-suppress noExplicitConstructor
-    inline V3LangCode(en _e) : m_e(_e) {}
+    inline V3LangCode(en _e)
+        : m_e(_e) {}
     explicit V3LangCode(const char* textp);
-    explicit inline V3LangCode(int _e) : m_e(static_cast<en>(_e)) {}
+    explicit inline V3LangCode(int _e)
+        : m_e(static_cast<en>(_e)) {}
     operator en() const { return m_e; }
 };
 
