@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // LinkLValue TRANSFORMATIONS:
@@ -29,10 +25,7 @@
 #include "V3LinkLValue.h"
 #include "V3Ast.h"
 
-#include <algorithm>
-#include <cstdarg>
 #include <map>
-#include <vector>
 
 //######################################################################
 // Link state, as a visitor of each AstNode
@@ -42,8 +35,8 @@ private:
     // NODE STATE
 
     // STATE
-    bool        m_setRefLvalue;  // Set VarRefs to lvalues for pin assignments
-    AstNodeFTask* m_ftaskp;      // Function or task we're inside
+    bool m_setRefLvalue;  // Set VarRefs to lvalues for pin assignments
+    AstNodeFTask* m_ftaskp;  // Function or task we're inside
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -52,14 +45,11 @@ private:
     // Result handing
     virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         // VarRef: LValue its reference
-        if (m_setRefLvalue) {
-            nodep->lvalue(true);
-        }
+        if (m_setRefLvalue) nodep->lvalue(true);
         if (nodep->varp()) {
-            if (nodep->lvalue() && !m_ftaskp
-                && nodep->varp()->isReadOnly()) {
-                nodep->v3warn(ASSIGNIN, "Assigning to input/const variable: "
-                              <<nodep->prettyNameQ());
+            if (nodep->lvalue() && !m_ftaskp && nodep->varp()->isReadOnly()) {
+                nodep->v3warn(ASSIGNIN,
+                              "Assigning to input/const variable: " << nodep->prettyNameQ());
             }
         }
         iterateChildren(nodep);
@@ -98,6 +88,16 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
+    virtual void visit(AstFOpenMcd* nodep) VL_OVERRIDE {
+        bool last_setRefLvalue = m_setRefLvalue;
+        {
+            m_setRefLvalue = true;
+            iterateAndNextNull(nodep->filep());
+            m_setRefLvalue = false;
+            iterateAndNextNull(nodep->filenamep());
+        }
+        m_setRefLvalue = last_setRefLvalue;
+    }
     virtual void visit(AstFClose* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
@@ -106,6 +106,15 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
+    virtual void visit(AstFError* nodep) VL_OVERRIDE {
+        bool last_setRefLvalue = m_setRefLvalue;
+        {
+            m_setRefLvalue = true;
+            iterateAndNextNull(nodep->filep());
+            iterateAndNextNull(nodep->strp());
+        }
+        m_setRefLvalue = last_setRefLvalue;
+    }
     virtual void visit(AstFFlush* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
@@ -203,6 +212,21 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
+    void prepost_visit(AstNodeTriop* nodep) {
+        bool last_setRefLvalue = m_setRefLvalue;
+        {
+            m_setRefLvalue = false;
+            iterateAndNextNull(nodep->lhsp());
+            iterateAndNextNull(nodep->rhsp());
+            m_setRefLvalue = true;
+            iterateAndNextNull(nodep->thsp());
+        }
+        m_setRefLvalue = last_setRefLvalue;
+    }
+    virtual void visit(AstPreAdd* nodep) VL_OVERRIDE { prepost_visit(nodep); }
+    virtual void visit(AstPostAdd* nodep) VL_OVERRIDE { prepost_visit(nodep); }
+    virtual void visit(AstPreSub* nodep) VL_OVERRIDE { prepost_visit(nodep); }
+    virtual void visit(AstPostSub* nodep) VL_OVERRIDE { prepost_visit(nodep); }
 
     // Nodes that change LValue state
     virtual void visit(AstSel* nodep) VL_OVERRIDE {
@@ -218,7 +242,7 @@ private:
     }
     virtual void visit(AstNodeSel* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
-        {   // Only set lvalues on the from
+        {  // Only set lvalues on the from
             iterateAndNextNull(nodep->lhsp());
             m_setRefLvalue = false;
             iterateAndNextNull(nodep->rhsp());
@@ -227,7 +251,7 @@ private:
     }
     virtual void visit(AstCellArrayRef* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
-        {   // selp is not an lvalue
+        {  // selp is not an lvalue
             m_setRefLvalue = false;
             iterateAndNextNull(nodep->selp());
         }
@@ -235,7 +259,7 @@ private:
     }
     virtual void visit(AstNodePreSel* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
-        {   // Only set lvalues on the from
+        {  // Only set lvalues on the from
             iterateAndNextNull(nodep->lhsp());
             m_setRefLvalue = false;
             iterateAndNextNull(nodep->rhsp());
@@ -253,7 +277,7 @@ private:
         AstNodeFTask* taskp = nodep->taskp();
         // We'll deal with mismatching pins later
         if (!taskp) return;
-        for (AstNode* stmtp = taskp->stmtsp(); stmtp && pinp; stmtp=stmtp->nextp()) {
+        for (AstNode* stmtp = taskp->stmtsp(); stmtp && pinp; stmtp = stmtp->nextp()) {
             if (const AstVar* portp = VN_CAST(stmtp, Var)) {
                 if (portp->isIO()) {
                     if (portp->isWritable()) {
@@ -270,10 +294,7 @@ private:
         }
     }
 
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        // Default: Just iterate
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -289,15 +310,13 @@ public:
 // Link class functions
 
 void V3LinkLValue::linkLValue(AstNetlist* nodep) {
-    UINFO(4,__FUNCTION__<<": "<<endl);
-    {
-        LinkLValueVisitor visitor(nodep, false);
-    }  // Destruct before checking
+    UINFO(4, __FUNCTION__ << ": " << endl);
+    { LinkLValueVisitor visitor(nodep, false); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("linklvalue", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 6);
 }
 void V3LinkLValue::linkLValueSet(AstNode* nodep) {
     // Called by later link functions when it is known a node needs
     // to be converted to a lvalue.
-    UINFO(9,__FUNCTION__<<": "<<endl);
+    UINFO(9, __FUNCTION__ << ": " << endl);
     LinkLValueVisitor visitor(nodep, true);
 }
