@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // LinkParse TRANSFORMATIONS:
@@ -31,7 +27,6 @@
 #include "V3Config.h"
 
 #include <algorithm>
-#include <cstdarg>
 #include <map>
 #include <set>
 #include <vector>
@@ -45,24 +40,22 @@ private:
     // Cleared on netlist
     //  AstNode::user1()        -> bool.  True if processed
     //  AstNode::user2()        -> bool.  True if fileline recomputed
-    AstUser1InUse       m_inuser1;
-    AstUser2InUse       m_inuser2;
+    AstUser1InUse m_inuser1;
+    AstUser2InUse m_inuser2;
 
     // TYPES
-    typedef std::map<std::pair<void*,string>,AstTypedef*> ImplTypedefMap;
+    typedef std::map<std::pair<void*, string>, AstTypedef*> ImplTypedefMap;
     typedef std::set<FileLine*> FileLineSet;
 
     // STATE
-    AstVar*             m_varp;         // Variable we're under
-    ImplTypedefMap      m_implTypedef;  // Created typedefs for each <container,name>
-    FileLineSet         m_filelines;    // Filelines that have been seen
-    bool                m_inAlways;     // Inside an always
-    bool                m_inGenerate;   // Inside a generate
-    bool                m_needStart;    // Need start marker on lower AstParse
-    AstNodeModule*      m_valueModp;    // If set, move AstVar->valuep() initial values to this module
-    AstNodeModule*      m_modp;         // Current module
-    AstNodeFTask*       m_ftaskp;       // Current task
-    AstNodeDType*       m_dtypep;       // Current data type
+    AstVar* m_varp;  // Variable we're under
+    ImplTypedefMap m_implTypedef;  // Created typedefs for each <container,name>
+    FileLineSet m_filelines;  // Filelines that have been seen
+    bool m_inAlways;  // Inside an always
+    AstNodeModule* m_valueModp;  // If set, move AstVar->valuep() initial values to this module
+    AstNodeModule* m_modp;  // Current module
+    AstNodeFTask* m_ftaskp;  // Current task
+    AstNodeDType* m_dtypep;  // Current data type
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -88,8 +81,11 @@ private:
             // Create a name for the enum, to aid debug and tracing
             // This name is not guaranteed to be globally unique (due to later parameterization)
             string above;
-            if (m_modp && VN_IS(m_modp, Package)) above = m_modp->name()+"::";
-            else if (m_modp) above = m_modp->name()+".";
+            if (m_modp && VN_IS(m_modp, Package)) {
+                above = m_modp->name() + "::";
+            } else if (m_modp) {
+                above = m_modp->name() + ".";
+            }
             return above + typedefp->name();
         }
         return "";
@@ -119,16 +115,14 @@ private:
     virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         if (!nodep->user1SetOnce()) {  // Process only once.
             cleanFileline(nodep);
-            UINFO(5,"   "<<nodep<<endl);
+            UINFO(5, "   " << nodep << endl);
             AstNodeModule* upperValueModp = m_valueModp;
             m_valueModp = NULL;
             iterateChildren(nodep);
             m_valueModp = upperValueModp;
         }
     }
-    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
-        visitIterateNodeDType(nodep);
-    }
+    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE { visitIterateNodeDType(nodep); }
     virtual void visit(AstEnumDType* nodep) VL_OVERRIDE {
         if (nodep->name() == "") {
             nodep->name(nameFromTypedef(nodep));  // Might still remain ""
@@ -146,7 +140,7 @@ private:
         cleanFileline(nodep);
         iterateChildren(nodep);
         if (nodep->rangep()) {
-            if (!VN_IS(nodep->rangep()->msbp(), Const)
+            if (!VN_IS(nodep->rangep()->msbp(), Const)  //
                 || !VN_IS(nodep->rangep()->lsbp(), Const)) {
                 nodep->v3error("Enum ranges must be integral, per spec");
             }
@@ -155,18 +149,19 @@ private:
             int increment = (msb > lsb) ? -1 : 1;
             int offset_from_init = 0;
             AstNode* addp = NULL;
-            for (int i=msb; i!=(lsb+increment); i+=increment, offset_from_init++) {
+            for (int i = msb; i != (lsb + increment); i += increment, offset_from_init++) {
                 string name = nodep->name() + cvtToStr(i);
                 AstNode* valuep = NULL;
-                if (nodep->valuep()) valuep = new AstAdd
-                                         (nodep->fileline(),
-                                          nodep->valuep()->cloneTree(true),
-                                          new AstConst(nodep->fileline(),
-                                                       AstConst::Unsized32(),
-                                                       offset_from_init));
+                if (nodep->valuep())
+                    valuep = new AstAdd(
+                        nodep->fileline(), nodep->valuep()->cloneTree(true),
+                        new AstConst(nodep->fileline(), AstConst::Unsized32(), offset_from_init));
                 AstNode* newp = new AstEnumItem(nodep->fileline(), name, NULL, valuep);
-                if (addp) addp = addp->addNextNull(newp);
-                else addp = newp;
+                if (addp) {
+                    addp = addp->addNextNull(newp);
+                } else {
+                    addp = newp;
+                }
             }
             nodep->replaceWith(addp);
             VL_DO_DANGLING(nodep->deleteTree(), nodep);
@@ -175,19 +170,23 @@ private:
 
     virtual void visit(AstVar* nodep) VL_OVERRIDE {
         cleanFileline(nodep);
+        if (nodep->isParam() && !nodep->valuep()
+            && nodep->fileline()->language() < V3LangCode::L1800_2009) {
+            nodep->v3error("Parameter requires default value, or use IEEE 1800-2009 or later.");
+        }
         if (VN_IS(nodep->subDTypep(), ParseTypeDType)) {
             // It's a parameter type. Use a different node type for this.
             AstNodeDType* dtypep = VN_CAST(nodep->valuep(), NodeDType);
             if (!dtypep) {
-                nodep->v3error("Parameter type's initial value isn't a type: "
-                               <<nodep->prettyNameQ());
+                nodep->v3error(
+                    "Parameter type's initial value isn't a type: " << nodep->prettyNameQ());
                 nodep->unlinkFrBack();
             } else {
                 dtypep->unlinkFrBack();
-                AstNode* newp = new AstParamTypeDType(nodep->fileline(),
-                                                      nodep->varType(), nodep->name(),
-                                                      VFlagChildDType(), dtypep);
-                nodep->replaceWith(newp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+                AstNode* newp = new AstParamTypeDType(nodep->fileline(), nodep->varType(),
+                                                      nodep->name(), VFlagChildDType(), dtypep);
+                nodep->replaceWith(newp);
+                VL_DO_DANGLING(nodep->deleteTree(), nodep);
             }
             return;
         }
@@ -197,20 +196,17 @@ private:
 
         if (v3Global.opt.publicFlatRW()) {
             switch (nodep->varType()) {
-            case AstVarType::VAR:
-            case AstVarType::PORT:
-            case AstVarType::WIRE:
-                nodep->sigUserRWPublic(true);
-                break;
+            case AstVarType::VAR:  // FALLTHRU
+            case AstVarType::PORT:  // FALLTHRU
+            case AstVarType::WIRE: nodep->sigUserRWPublic(true); break;
             default: break;
             }
         }
 
         // We used modTrace before leveling, and we may now
         // want to turn it off now that we know the levelizations
-        if (v3Global.opt.traceDepth()
-            && m_modp
-            && (m_modp->level()-1) > v3Global.opt.traceDepth()) {
+        if (v3Global.opt.traceDepth() && m_modp
+            && (m_modp->level() - 1) > v3Global.opt.traceDepth()) {
             m_modp->modTrace(false);
             nodep->trace(false);
         }
@@ -223,27 +219,30 @@ private:
         if (nodep->valuep()) {
             // A variable with an = value can be three things:
             FileLine* fl = nodep->valuep()->fileline();
-            // 1. Parameters and function inputs: It's a default to use if not overridden
             if (nodep->isParam() || (m_ftaskp && nodep->isNonOutput())) {
-            }
-            else if (!m_ftaskp && nodep->isNonOutput()) {
-                nodep->v3error("Unsupported: Default value on module input: "
-                               <<nodep->prettyNameQ());
+                // 1. Parameters and function inputs: It's a default to use if not overridden
+            } else if (VN_IS(m_modp, Class)) {
+                // 2. Class member init become initials (as might call functions)
+                // later move into class constructor
+                nodep->addNextHere(
+                    new AstInitial(fl, new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
+                                                     nodep->valuep()->unlinkFrBack())));
+            } else if (!m_ftaskp && nodep->isNonOutput()) {
+                nodep->v3warn(E_UNSUPPORTED, "Unsupported: Default value on module input: "
+                                                 << nodep->prettyNameQ());
                 nodep->valuep()->unlinkFrBack()->deleteTree();
-            }  // 2. Under modules, it's an initial value to be loaded at time 0 via an AstInitial
+            }  // 3. Under modules, it's an initial value to be loaded at time 0 via an AstInitial
             else if (m_valueModp) {
                 // Making an AstAssign (vs AstAssignW) to a wire is an error, suppress it
                 FileLine* newfl = new FileLine(fl);
                 newfl->warnOff(V3ErrorCode::PROCASSWIRE, true);
-                nodep->addNextHere
-                    (new AstInitial
-                     (newfl, new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), true),
-                                           nodep->valuep()->unlinkFrBack())));
-            }  // 3. Under blocks, it's an initial value to be under an assign
+                nodep->addNextHere(new AstInitial(
+                    newfl, new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), true),
+                                         nodep->valuep()->unlinkFrBack())));
+            }  // 4. Under blocks, it's an initial value to be under an assign
             else {
-                nodep->addNextHere
-                    (new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
-                                   nodep->valuep()->unlinkFrBack()));
+                nodep->addNextHere(new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
+                                                 nodep->valuep()->unlinkFrBack()));
             }
         }
         if (nodep->isIfaceRef() && !nodep->isIfaceParent()) {
@@ -251,7 +250,9 @@ private:
             // haven't made additional ones for interconnect yet, so assert is simple
             // What breaks later is we don't have a Scope/Cell representing
             // the interface to attach to
-            if (m_modp->level()<=2) nodep->v3error("Unsupported: Interfaced port on top level module");
+            if (m_modp->level() <= 2) {
+                nodep->v3warn(E_UNSUPPORTED, "Unsupported: Interfaced port on top level module");
+            }
         }
     }
 
@@ -263,59 +264,61 @@ private:
             UASSERT_OBJ(typep, nodep, "Attribute not attached to typedef");
             typep->attrPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCK) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCK) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             nodep->v3warn(DEPRECATED, "sc_clock is deprecated and will be removed");
             m_varp->attrScClocked(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCK_ENABLE) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCK_ENABLE) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClockEn(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
-            m_varp->sigUserRWPublic(true); m_varp->sigModPublic(true);
+            m_varp->sigUserRWPublic(true);
+            m_varp->sigModPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRWPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RD) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RD) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRdPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RW) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RW) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRWPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_ISOLATE_ASSIGNMENTS) {
+        } else if (nodep->attrType() == AstAttrType::VAR_ISOLATE_ASSIGNMENTS) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrIsolateAssign(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_SFORMAT) {
+        } else if (nodep->attrType() == AstAttrType::VAR_SFORMAT) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrSFormat(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_SC_BV) {
+        } else if (nodep->attrType() == AstAttrType::VAR_SPLIT_VAR) {
+            UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
+            if (!VN_IS(m_modp, Module)) {
+                m_varp->v3warn(
+                    SPLITVAR,
+                    m_varp->prettyNameQ()
+                        << " has split_var metacomment, "
+                           "but will not be split because it is not declared in a module.");
+            } else {
+                m_varp->attrSplitVar(true);
+            }
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
+        } else if (nodep->attrType() == AstAttrType::VAR_SC_BV) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrScBv(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCKER) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCKER) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClocker(VVarAttrClocker::CLOCKER_YES);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_NO_CLOCKER) {
+        } else if (nodep->attrType() == AstAttrType::VAR_NO_CLOCKER) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClocker(VVarAttrClocker::CLOCKER_NO);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
@@ -339,36 +342,38 @@ private:
 
     virtual void visit(AstDefImplicitDType* nodep) VL_OVERRIDE {
         cleanFileline(nodep);
-        UINFO(8,"   DEFIMPLICIT "<<nodep<<endl);
+        UINFO(8, "   DEFIMPLICIT " << nodep << endl);
         // Must remember what names we've already created, and combine duplicates
         // so that for "var enum {...} a,b" a & b will share a common typedef
         // Unique name space under each containerp() so that an addition of
         // a new type won't change every verilated module.
         AstTypedef* defp = NULL;
-        ImplTypedefMap::iterator it = m_implTypedef.find(make_pair(nodep->containerp(), nodep->name()));
+        ImplTypedefMap::iterator it
+            = m_implTypedef.find(make_pair(nodep->containerp(), nodep->name()));
         if (it != m_implTypedef.end()) {
             defp = it->second;
         } else {
             // Definition must be inserted right after the variable (etc) that needed it
             // AstVar, AstTypedef, AstNodeFTask are common containers
             AstNode* backp = nodep->backp();
-            for (; backp; backp=backp->backp()) {
-                if (VN_IS(backp, Var)) break;
-                else if (VN_IS(backp, Typedef)) break;
-                else if (VN_IS(backp, NodeFTask)) break;
+            for (; backp; backp = backp->backp()) {
+                if (VN_IS(backp, Var) || VN_IS(backp, Typedef) || VN_IS(backp, NodeFTask)) break;
             }
             UASSERT_OBJ(backp, nodep,
                         "Implicit enum/struct type created under unexpected node type");
-            AstNodeDType* dtypep = nodep->childDTypep(); dtypep->unlinkFrBack();
-            if (VN_IS(backp, Typedef)) {  // A typedef doesn't need us to make yet another level of typedefing
+            AstNodeDType* dtypep = nodep->childDTypep();
+            dtypep->unlinkFrBack();
+            if (VN_IS(backp, Typedef)) {
+                // A typedef doesn't need us to make yet another level of typedefing
                 // For typedefs just remove the AstRefDType level of abstraction
                 nodep->replaceWith(dtypep);
                 VL_DO_DANGLING(nodep->deleteTree(), nodep);
                 return;
             } else {
-                defp = new AstTypedef(nodep->fileline(), nodep->name(), NULL,
-                                      VFlagChildDType(), dtypep);
-                m_implTypedef.insert(make_pair(make_pair(nodep->containerp(), defp->name()), defp));
+                defp = new AstTypedef(nodep->fileline(), nodep->name(), NULL, VFlagChildDType(),
+                                      dtypep);
+                m_implTypedef.insert(
+                    make_pair(make_pair(nodep->containerp(), defp->name()), defp));
                 backp->addNextHere(defp);
             }
         }
@@ -376,29 +381,64 @@ private:
         VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
-    virtual void visit(AstTypedefFwd* nodep) VL_OVERRIDE {
-        // We only needed the forward declaration in order to parse correctly.
-        // We won't even check it was ever really defined, as it might have been in a header
-        // file referring to a module we never needed
-        VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-    }
-
     virtual void visit(AstForeach* nodep) VL_OVERRIDE {
         // FOREACH(array,loopvars,body)
         // -> BEGIN(declare vars, loopa=lowest; WHILE(loopa<=highest, ... body))
-        //nodep->dumpTree(cout, "-foreach-old:");
-        AstNode* newp = nodep->bodysp()->unlinkFrBackWithNext();
-        AstNode* arrayp = nodep->arrayp();
-        int dimension = 1;
+        // nodep->dumpTree(cout, "-foreach-old:");
+        UINFO(9, "FOREACH " << nodep << endl);
+        // nodep->dumpTree(cout, "-foreach-in:");
+        AstNode* newp = nodep->bodysp();
+        if (newp) newp->unlinkFrBackWithNext();
+        // Separate iteration vars from base from variable
+        // Input:
+        //      v--- arrayp
+        //   1. DOT(DOT(first, second), ASTSELLOOPVARS(third, var0..var1))
+        // Separated:
+        //   bracketp = ASTSELLOOPVARS(...)
+        //   arrayp = DOT(DOT(first, second), third)
+        //   firstVarp = var0..var1
+        // Other examples
+        //   2. ASTSELBIT(first, var0))
+        //   3. ASTSELLOOPVARS(first, var0..var1))
+        //   4. DOT(DOT(first, second), ASTSELBIT(third, var0))
+        AstNode* bracketp = nodep->arrayp();
+        AstNode* firstVarsp = NULL;
+        while (AstDot* dotp = VN_CAST(bracketp, Dot)) { bracketp = dotp->rhsp(); }
+        if (AstSelBit* selp = VN_CAST(bracketp, SelBit)) {
+            firstVarsp = selp->rhsp()->unlinkFrBackWithNext();
+            selp->replaceWith(selp->fromp()->unlinkFrBack());
+            VL_DO_DANGLING(selp->deleteTree(), selp);
+        } else if (AstSelLoopVars* selp = VN_CAST(bracketp, SelLoopVars)) {
+            firstVarsp = selp->elementsp()->unlinkFrBackWithNext();
+            selp->replaceWith(selp->fromp()->unlinkFrBack());
+            VL_DO_DANGLING(selp->deleteTree(), selp);
+        } else {
+            nodep->v3error(
+                "Syntax error; foreach missing bracketed index variable (IEEE 1800-2017 12.7.3)");
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
+            return;
+        }
+        AstNode* arrayp = nodep->arrayp();  // Maybe different node since bracketp looked
+        if (!VN_IS(arrayp, ParseRef)) {
+            // Code below needs to use other then attributes to figure out the bounds
+            // Also need to deal with queues, etc
+            arrayp->v3warn(E_UNSUPPORTED, "Unsupported: foreach on non-simple variable reference");
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
+            return;
+        }
+        // Split into for loop
         // Must do innermost (last) variable first
-        AstNode* firstVarsp = nodep->varsp()->unlinkFrBackWithNext();
+        int dimension = 1;
         AstNode* lastVarsp = firstVarsp;
-        while (lastVarsp->nextp()) { lastVarsp = lastVarsp->nextp(); dimension++; }
-        for (AstNode* varsp = lastVarsp; varsp; varsp=varsp->backp()) {
-            UINFO(9,"foreachVar "<<varsp<<endl);
+        while (lastVarsp->nextp()) {
+            lastVarsp = lastVarsp->nextp();
+            dimension++;
+        }
+        for (AstNode* varsp = lastVarsp; varsp; varsp = varsp->backp()) {
+            UINFO(9, "foreachVar " << varsp << endl);
             FileLine* fl = varsp->fileline();
-            AstNode* varp = new AstVar(fl, AstVarType::BLOCKTEMP,
-                                       varsp->name(), nodep->findSigned32DType());
+            AstNode* varp
+                = new AstVar(fl, AstVarType::BLOCKTEMP, varsp->name(), nodep->findSigned32DType());
             // These will be the left and right dimensions and size of the array:
             AstNode* leftp = new AstAttrOf(fl, AstAttrType::DIM_LEFT,
                                            new AstVarRef(fl, arrayp->name(), false),
@@ -411,19 +451,16 @@ private:
                                            new AstConst(fl, dimension));
             AstNode* stmtsp = varp;
             // Assign left-dimension into the loop var:
-            stmtsp->addNext(new AstAssign
-                            (fl, new AstVarRef(fl, varp->name(), true), leftp));
+            stmtsp->addNext(new AstAssign(fl, new AstVarRef(fl, varp->name(), true), leftp));
             // This will turn into a constant bool for static arrays
             AstNode* notemptyp = new AstGt(fl, sizep, new AstConst(fl, 0));
             // This will turn into a bool constant, indicating whether
             // we count the loop variable up or down:
-            AstNode* countupp = new AstLte(fl, leftp->cloneTree(true),
-                                           rightp->cloneTree(true));
+            AstNode* countupp = new AstLte(fl, leftp->cloneTree(true), rightp->cloneTree(true));
             AstNode* comparep = new AstCond(
                 fl, countupp->cloneTree(true),
                 // Left increments up to right
-                new AstLte(fl, new AstVarRef(fl, varp->name(), false),
-                           rightp->cloneTree(true)),
+                new AstLte(fl, new AstVarRef(fl, varp->name(), false), rightp->cloneTree(true)),
                 // Left decrements down to right
                 new AstGte(fl, new AstVarRef(fl, varp->name(), false), rightp));
             // This will reduce to comparep for static arrays
@@ -431,16 +468,15 @@ private:
             AstNode* incp = new AstAssign(
                 fl, new AstVarRef(fl, varp->name(), true),
                 new AstAdd(fl, new AstVarRef(fl, varp->name(), false),
-                           new AstCond(fl, countupp,
-                                       new AstConst(fl, 1),
-                                       new AstConst(fl, -1))));
+                           new AstCond(fl, countupp, new AstConst(fl, 1), new AstConst(fl, -1))));
             stmtsp->addNext(new AstWhile(fl, condp, newp, incp));
-            newp = new AstBegin(nodep->fileline(), "", stmtsp);
+            newp = new AstBegin(nodep->fileline(), "", stmtsp, false, true);
             dimension--;
         }
-        //newp->dumpTree(cout, "-foreach-new:");
+        // newp->dumpTree(cout, "-foreach-new:");
         VL_DO_DANGLING(firstVarsp->deleteTree(), firstVarsp);
-        nodep->replaceWith(newp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+        nodep->replaceWith(newp);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
@@ -467,27 +503,31 @@ private:
         iterateChildren(nodep);
         m_valueModp = upperValueModp;
     }
-    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
-    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
+    virtual void visit(AstNodeProcedure* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         m_inAlways = true;
         visitIterateNoValueMod(nodep);
         m_inAlways = false;
     }
-    virtual void visit(AstCover* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
-    virtual void visit(AstRestrict* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
+    virtual void visit(AstCover* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
+    virtual void visit(AstRestrict* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
 
     virtual void visit(AstBegin* nodep) VL_OVERRIDE {
         V3Config::applyCoverageBlock(m_modp, nodep);
         cleanFileline(nodep);
+        AstNode* backp = nodep->backp();
+        // IEEE says directly nested item is not a new block
+        bool nestedIf = (nodep->implied()  // User didn't provide begin/end
+                         && (VN_IS(nodep->stmtsp(), GenIf)
+                             || VN_IS(nodep->stmtsp(), GenCase))  // Has an if/case
+                         && !nodep->stmtsp()->nextp());  // Has only one item
+        // It's not FOR(BEGIN(...)) but we earlier changed it to BEGIN(FOR(...))
+        if (nodep->genforp() && nodep->name() == "") {
+            nodep->name("genblk");
+        } else if (nodep->generate() && nodep->name() == ""
+                   && (VN_IS(backp, CaseItem) || VN_IS(backp, GenIf)) && !nestedIf) {
+            nodep->name("genblk");
+        }
         iterateChildren(nodep);
     }
     virtual void visit(AstCase* nodep) VL_OVERRIDE {
@@ -495,6 +535,57 @@ private:
         cleanFileline(nodep);
         iterateChildren(nodep);
     }
+    virtual void visit(AstPrintTimeScale* nodep) VL_OVERRIDE {
+        // Inlining may change hierarchy, so just save timescale where needed
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        nodep->name(m_modp->name());
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstSFormatF* nodep) VL_OVERRIDE {
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTime* nodep) VL_OVERRIDE {
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTimeD* nodep) VL_OVERRIDE {
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTimeImport* nodep) VL_OVERRIDE {
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTimingControl* nodep) VL_OVERRIDE {
+        cleanFileline(nodep);
+        iterateChildren(nodep);
+        AstAlways* alwaysp = VN_CAST(nodep->backp(), Always);
+        if (alwaysp && alwaysp->keyword() == VAlwaysKwd::ALWAYS_COMB) {
+            alwaysp->v3error("Timing control statements not legal under always_comb\n"
+                             << nodep->warnMore() << "... Suggest use a normal 'always'");
+        } else if (alwaysp && !alwaysp->sensesp()) {
+            // Verilator is still ony supporting SenTrees under an always,
+            // so allow the parser to handle everything and shim to
+            // historical AST here
+            if (AstSenTree* sensesp = nodep->sensesp()) {
+                sensesp->unlinkFrBackWithNext();
+                alwaysp->sensesp(sensesp);
+            }
+            if (nodep->stmtsp()) alwaysp->addStmtp(nodep->stmtsp()->unlinkFrBackWithNext());
+        } else {
+            nodep->v3warn(E_UNSUPPORTED, "Unsupported: timing control statement in this location\n"
+                                             << nodep->warnMore()
+                                             << "... Suggest have one timing control statement "
+                                             << "per procedure, at the top of the procedure");
+        }
+        VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
+    }
 
     virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // Default: Just iterate
@@ -510,8 +601,6 @@ public:
         m_ftaskp = NULL;
         m_dtypep = NULL;
         m_inAlways = false;
-        m_inGenerate = false;
-        m_needStart = false;
         m_valueModp = NULL;
         iterate(rootp);
     }
@@ -522,9 +611,7 @@ public:
 // Link class functions
 
 void V3LinkParse::linkParse(AstNetlist* rootp) {
-    UINFO(4,__FUNCTION__<<": "<<endl);
-    {
-        LinkParseVisitor visitor(rootp);
-    }  // Destruct before checking
+    UINFO(4, __FUNCTION__ << ": " << endl);
+    { LinkParseVisitor visitor(rootp); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("linkparse", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 6);
 }
