@@ -6,19 +6,14 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
-
 #include "V3Ast.h"  // This must be before V3ParseBison.cpp, as we don't want #defines to conflict
 
 //======================================================================
@@ -31,7 +26,7 @@
 
 int V3ParseImp::bisonParse() {
     // Use --debugi-bison 9 to enable this
-    if (PARSEP->debugBison()>=9) yydebug = 1;
+    if (PARSEP->debugBison() >= 9) yydebug = 1;
     return yyparse();
 }
 
@@ -40,8 +35,8 @@ const char* V3ParseImp::tokenName(int token) {
     static const char** nameTablep = NULL;
     if (!nameTablep) {
         int size;
-        for (size = 0; yytname[size]; ++size) ;
-        nameTablep = new const char* [size];
+        for (size = 0; yytname[size]; ++size) {}
+        nameTablep = new const char*[size];
         // Workaround bug in bison's which have '!' in yytname but not token values
         int iout = 0;
         for (int i = 0; yytname[i]; ++i) {
@@ -50,9 +45,11 @@ const char* V3ParseImp::tokenName(int token) {
         }
     }
     if (token >= 255) {
-        return nameTablep[token-255];
+        return nameTablep[token - 255];
     } else {
-        static char ch[2]; ch[0] = token; ch[1] = '\0';
+        static char ch[2];
+        ch[0] = token;
+        ch[1] = '\0';
         return ch;
     }
 #else
@@ -68,42 +65,49 @@ void V3ParseImp::parserClear() {
 //======================================================================
 // V3ParseGrammar functions requiring bison state
 
-void V3ParseGrammar::argWrapList(AstNodeFTaskRef* nodep) {
+AstNode* V3ParseGrammar::argWrapList(AstNode* nodep) {
     // Convert list of expressions to list of arguments
+    if (!nodep) return NULL;
     AstNode* outp = NULL;
-    while (nodep->pinsp()) {
-        AstNode* exprp = nodep->pinsp()->unlinkFrBack();
+    AstBegin* tempp = new AstBegin(nodep->fileline(), "[EditWrapper]", nodep);
+    while (nodep) {
+        AstNode* nextp = nodep->nextp();
+        AstNode* exprp = nodep->unlinkFrBack();
+        nodep = nextp;
         // addNext can handle nulls:
         outp = AstNode::addNext(outp, new AstArg(exprp->fileline(), "", exprp));
     }
-    if (outp) nodep->addPinsp(outp);
+    VL_DO_DANGLING(tempp->deleteTree(), tempp);
+    return outp;
 }
 
 AstNode* V3ParseGrammar::createSupplyExpr(FileLine* fileline, const string& name, int value) {
-    return new AstAssignW(fileline, new AstVarRef(fileline, name, true),
-                          new AstConst(fileline, AstConst::StringToParse(),
-                                       (value ? "'1" : "'0")));
+    return new AstAssignW(
+        fileline, new AstVarRef(fileline, name, true),
+        new AstConst(fileline, AstConst::StringToParse(), (value ? "'1" : "'0")));
 }
 
 AstRange* V3ParseGrammar::scrubRange(AstNodeRange* nrangep) {
     // Remove any UnsizedRange's from list
-    for (AstNodeRange* nodep = nrangep, *nextp; nodep; nodep = nextp) {
+    for (AstNodeRange *nodep = nrangep, *nextp; nodep; nodep = nextp) {
         nextp = VN_CAST(nodep->nextp(), NodeRange);
         if (!VN_IS(nodep, Range)) {
-            nodep->v3error("Unsupported or syntax error: Unsized range in cell or other declaration");
-            nodep->unlinkFrBack(); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+            nodep->v3error(
+                "Unsupported or syntax error: Unsized range in cell or other declaration");
+            nodep->unlinkFrBack();
+            VL_DO_DANGLING(nodep->deleteTree(), nodep);
         }
     }
     if (nrangep && nrangep->nextp()) {
         // Not supported by at least 2 of big 3
-        nrangep->nextp()->v3error("Unsupported: Multidimensional cells/interfaces.");
+        nrangep->nextp()->v3warn(E_UNSUPPORTED, "Unsupported: Multidimensional cells/interfaces.");
         nrangep->nextp()->unlinkFrBackWithNext()->deleteTree();
     }
     return VN_CAST(nrangep, Range);
 }
 
-AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep,
-                                          AstNodeRange* nrangep, bool isPacked) {
+AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep, AstNodeRange* nrangep,
+                                          bool isPacked) {
     // Split RANGE0-RANGE1-RANGE2
     // into ARRAYDTYPE0(ARRAYDTYPE1(ARRAYDTYPE2(BASICTYPE3), RANGE), RANGE)
     AstNodeDType* arrayp = basep;
@@ -114,26 +118,23 @@ AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep,
             if (prevp) nrangep->unlinkFrBack();
             AstRange* rangep = VN_CAST(nrangep, Range);
             if (rangep && isPacked) {
-                arrayp = new AstPackArrayDType
-                    (rangep->fileline(), VFlagChildDType(), arrayp, rangep);
-            } else if (VN_IS(nrangep, QueueRange)) {
-                arrayp = new AstQueueDType
-                    (nrangep->fileline(), VFlagChildDType(), arrayp, NULL);
-            } else if (rangep && (VN_IS(rangep->leftp(), Unbounded)
-                                  || VN_IS(rangep->rightp(), Unbounded))) {
+                arrayp
+                    = new AstPackArrayDType(rangep->fileline(), VFlagChildDType(), arrayp, rangep);
+            } else if (rangep
+                       && (VN_IS(rangep->leftp(), Unbounded)
+                           || VN_IS(rangep->rightp(), Unbounded))) {
                 arrayp = new AstQueueDType(nrangep->fileline(), VFlagChildDType(), arrayp,
                                            rangep->rightp()->cloneTree(true));
             } else if (rangep) {
-                arrayp = new AstUnpackArrayDType
-                    (rangep->fileline(), VFlagChildDType(), arrayp, rangep);
+                arrayp = new AstUnpackArrayDType(rangep->fileline(), VFlagChildDType(), arrayp,
+                                                 rangep);
             } else if (VN_IS(nrangep, UnsizedRange)) {
-                arrayp = new AstUnsizedArrayDType
-                    (nrangep->fileline(), VFlagChildDType(), arrayp);
-            } else if (VN_IS(nrangep, AssocRange)) {
-                AstAssocRange* arangep = VN_CAST(nrangep, AssocRange);
-                AstNodeDType* keyp = arangep->keyDTypep(); keyp->unlinkFrBack();
-                arrayp = new AstAssocArrayDType
-                    (nrangep->fileline(), VFlagChildDType(), arrayp, keyp);
+                arrayp = new AstUnsizedArrayDType(nrangep->fileline(), VFlagChildDType(), arrayp);
+            } else if (VN_IS(nrangep, BracketRange)) {
+                AstBracketRange* arangep = VN_CAST(nrangep, BracketRange);
+                AstNode* keyp = arangep->elementsp()->unlinkFrBack();
+                arrayp = new AstBracketArrayDType(nrangep->fileline(), VFlagChildDType(), arrayp,
+                                                  keyp);
             } else {
                 UASSERT_OBJ(0, nrangep, "Expected range or unsized range");
             }
@@ -146,12 +147,11 @@ AstNodeDType* V3ParseGrammar::createArray(AstNodeDType* basep,
 AstVar* V3ParseGrammar::createVariable(FileLine* fileline, const string& name,
                                        AstNodeRange* arrayp, AstNode* attrsp) {
     AstNodeDType* dtypep = GRAMMARP->m_varDTypep;
-    UINFO(5,"  creVar "<<name<<"  decl="<<GRAMMARP->m_varDecl
-          <<"  io="<<GRAMMARP->m_varIO<<"  dt="<<(dtypep?"set":"")<<endl);
-    if (GRAMMARP->m_varIO == VDirection::NONE
-        && GRAMMARP->m_varDecl == AstVarType::PORT) {
+    UINFO(5, "  creVar " << name << "  decl=" << GRAMMARP->m_varDecl << "  io="
+                         << GRAMMARP->m_varIO << "  dt=" << (dtypep ? "set" : "") << endl);
+    if (GRAMMARP->m_varIO == VDirection::NONE && GRAMMARP->m_varDecl == AstVarType::PORT) {
         // Just a port list with variable name (not v2k format); AstPort already created
-        if (dtypep) fileline->v3error("Unsupported: Ranges ignored in port-lists");
+        if (dtypep) fileline->v3warn(E_UNSUPPORTED, "Unsupported: Ranges ignored in port-lists");
         return NULL;
     }
     if (GRAMMARP->m_varDecl == AstVarType::WREAL) {
@@ -163,17 +163,18 @@ AstVar* V3ParseGrammar::createVariable(FileLine* fileline, const string& name,
     } else {  // May make new variables with same type, so clone
         dtypep = dtypep->cloneTree(false);
     }
-    //UINFO(0,"CREVAR "<<fileline->ascii()<<" decl="<<GRAMMARP->m_varDecl.ascii()<<" io="<<GRAMMARP->m_varIO.ascii()<<endl);
+    // UINFO(0,"CREVAR "<<fileline->ascii()<<" decl="<<GRAMMARP->m_varDecl.ascii()<<"
+    // io="<<GRAMMARP->m_varIO.ascii()<<endl);
     AstVarType type = GRAMMARP->m_varDecl;
     if (type == AstVarType::UNKNOWN) {
         if (GRAMMARP->m_varIO.isAny()) {
             type = AstVarType::PORT;
         } else {
-            fileline->v3fatalSrc("Unknown signal type declared");
+            fileline->v3fatalSrc("Unknown signal type declared: " << type.ascii());
         }
     }
     if (type == AstVarType::GENVAR) {
-        if (arrayp) fileline->v3error("Genvars may not be arrayed: "<<name);
+        if (arrayp) fileline->v3error("Genvars may not be arrayed: " << name);
     }
 
     // Split RANGE0-RANGE1-RANGE2 into
@@ -184,6 +185,7 @@ AstVar* V3ParseGrammar::createVariable(FileLine* fileline, const string& name,
     nodep->addAttrsp(attrsp);
     nodep->ansi(m_pinAnsi);
     nodep->declTyped(m_varDeclTyped);
+    nodep->lifetime(m_varLifetime);
     if (GRAMMARP->m_varDecl != AstVarType::UNKNOWN) nodep->combineType(GRAMMARP->m_varDecl);
     if (GRAMMARP->m_varIO != VDirection::NONE) {
         nodep->declDirection(GRAMMARP->m_varIO);
@@ -206,9 +208,13 @@ AstVar* V3ParseGrammar::createVariable(FileLine* fileline, const string& name,
     // We need to autosize parameters and integers separately
     //
     // Propagate from current module tracing state
-    if (nodep->isGenVar()) nodep->trace(false);
-    else if (nodep->isParam() && !v3Global.opt.traceParams()) nodep->trace(false);
-    else nodep->trace(allTracingOn(nodep->fileline()));
+    if (nodep->isGenVar()) {
+        nodep->trace(false);
+    } else if (nodep->isParam() && !v3Global.opt.traceParams()) {
+        nodep->trace(false);
+    } else {
+        nodep->trace(allTracingOn(nodep->fileline()));
+    }
 
     // Remember the last variable created, so we can attach attributes to it in later parsing
     GRAMMARP->m_varAttrp = nodep;
@@ -226,7 +232,7 @@ string V3ParseGrammar::deQuote(FileLine* fileline, string text) {
     for (string::const_iterator cp = text.begin(); cp != text.end(); ++cp) {
         if (quoted) {
             if (isdigit(*cp)) {
-                octal_val = octal_val*8 + (*cp-'0');
+                octal_val = octal_val * 8 + (*cp - '0');
                 if (++octal_digits == 3) {
                     octal_digits = 0;
                     quoted = false;
@@ -242,29 +248,33 @@ string V3ParseGrammar::deQuote(FileLine* fileline, string text) {
                     continue;
                 }
                 quoted = false;
-                if (*cp == 'n') newtext += '\n';
-                else if (*cp == 'a') newtext += '\a';  // SystemVerilog 3.1
-                else if (*cp == 'f') newtext += '\f';  // SystemVerilog 3.1
-                else if (*cp == 'r') newtext += '\r';
-                else if (*cp == 't') newtext += '\t';
-                else if (*cp == 'v') newtext += '\v';  // SystemVerilog 3.1
-                else if (*cp == 'x' && isxdigit(cp[1]) && isxdigit(cp[2])) {  // SystemVerilog 3.1
-#define vl_decodexdigit(c) ((isdigit(c)?((c)-'0'):(tolower((c))-'a'+10)))
-                    newtext += (char)(16*vl_decodexdigit(cp[1]) + vl_decodexdigit(cp[2]));
+                if (*cp == 'n') {
+                    newtext += '\n';
+                } else if (*cp == 'a') {
+                    newtext += '\a';  // SystemVerilog 3.1
+                } else if (*cp == 'f') {
+                    newtext += '\f';  // SystemVerilog 3.1
+                } else if (*cp == 'r') {
+                    newtext += '\r';
+                } else if (*cp == 't') {
+                    newtext += '\t';
+                } else if (*cp == 'v') {
+                    newtext += '\v';  // SystemVerilog 3.1
+                } else if (*cp == 'x' && isxdigit(cp[1])
+                           && isxdigit(cp[2])) {  // SystemVerilog 3.1
+#define vl_decodexdigit(c) ((isdigit(c) ? ((c) - '0') : (tolower((c)) - 'a' + 10)))
+                    newtext += (char)(16 * vl_decodexdigit(cp[1]) + vl_decodexdigit(cp[2]));
                     cp += 2;
-                }
-                else if (isalnum(*cp)) {
-                    fileline->v3error("Unknown escape sequence: \\"<<*cp);
+                } else if (isalnum(*cp)) {
+                    fileline->v3error("Unknown escape sequence: \\" << *cp);
                     break;
-                }
-                else newtext += *cp;
+                } else
+                    newtext += *cp;
             }
-        }
-        else if (*cp == '\\') {
+        } else if (*cp == '\\') {
             quoted = true;
             octal_digits = 0;
-        }
-        else if (*cp != '"') {
+        } else if (*cp != '"') {
             newtext += *cp;
         }
     }
