@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -34,7 +30,8 @@
 
 class AbstractMTask : public V3GraphVertex {
 public:
-    AbstractMTask(V3Graph* graphp) : V3GraphVertex(graphp) {}
+    AbstractMTask(V3Graph* graphp)
+        : V3GraphVertex(graphp) {}
     virtual ~AbstractMTask() {}
     virtual uint32_t id() const = 0;
     virtual uint32_t cost() const = 0;
@@ -45,7 +42,8 @@ public:
     // TYPES
     typedef std::list<MTaskMoveVertex*> VxList;
     // CONSTRUCTORS
-    AbstractLogicMTask(V3Graph* graphp) : AbstractMTask(graphp) {}
+    AbstractLogicMTask(V3Graph* graphp)
+        : AbstractMTask(graphp) {}
     virtual ~AbstractLogicMTask() {}
     // METHODS
     // Set of logic vertices in this mtask. Order is not significant.
@@ -56,28 +54,29 @@ public:
 
 class ExecMTask : public AbstractMTask {
 private:
-    AstMTaskBody*       m_bodyp;     // Task body
-    uint32_t            m_id;        // Unique id of this mtask.
-    uint32_t            m_priority;  // Predicted critical path from the start of
+    AstMTaskBody* m_bodyp;  // Task body
+    uint32_t m_id;  // Unique id of this mtask.
+    uint32_t m_priority;  // Predicted critical path from the start of
     // this mtask to the ends of the graph that are reachable from this
     // mtask. In abstract time units.
-    uint32_t            m_cost;      // Predicted runtime of this mtask, in the same
+    uint32_t m_cost;  // Predicted runtime of this mtask, in the same
     // abstract time units as priority().
-    uint32_t            m_thread;    // Thread for static (pack_mtasks) scheduling,
+    uint32_t m_thread;  // Thread for static (pack_mtasks) scheduling,
     // or 0xffffffff if not yet assigned.
-    const ExecMTask*    m_packNextp;  // Next for static (pack_mtasks) scheduling
-    bool                m_threadRoot;  // Is root thread
+    const ExecMTask* m_packNextp;  // Next for static (pack_mtasks) scheduling
+    bool m_threadRoot;  // Is root thread
     VL_UNCOPYABLE(ExecMTask);
+
 public:
     ExecMTask(V3Graph* graphp, AstMTaskBody* bodyp, uint32_t id)
-        : AbstractMTask(graphp),
-          m_bodyp(bodyp),
-          m_id(id),
-          m_priority(0),
-          m_cost(0),
-          m_thread(0xffffffff),
-          m_packNextp(NULL),
-          m_threadRoot(false) {}
+        : AbstractMTask(graphp)
+        , m_bodyp(bodyp)
+        , m_id(id)
+        , m_priority(0)
+        , m_cost(0)
+        , m_thread(0xffffffff)
+        , m_packNextp(NULL)
+        , m_threadRoot(false) {}
     AstMTaskBody* bodyp() const { return m_bodyp; }
     virtual uint32_t id() const { return m_id; }
     uint32_t priority() const { return m_priority; }
@@ -92,18 +91,20 @@ public:
     void threadRoot(bool threadRoot) { m_threadRoot = threadRoot; }
     string cFuncName() const {
         // If this MTask maps to a C function, this should be the name
-        return string("__Vmtask")+"__"+cvtToStr(m_id);
+        return string("__Vmtask") + "__" + cvtToStr(m_id);
     }
-    string name() const { return string("mt")+cvtToStr(id()); }
+    string name() const { return string("mt") + cvtToStr(id()); }
     void dump(std::ostream& str) const {
-        str <<name()<<"."<<cvtToHex(this);
-        if (priority() || cost()) str <<" [pr="<<priority()<<" c="<<cvtToStr(cost())<<"]";
-        if (thread() != 0xffffffff) str <<" th="<<thread();
-        if (threadRoot()) str <<" [ROOT]";
-        if (packNextp()) str <<" nx="<<packNextp()->name();
+        str << name() << "." << cvtToHex(this);
+        if (priority() || cost()) str << " [pr=" << priority() << " c=" << cvtToStr(cost()) << "]";
+        if (thread() != 0xffffffff) str << " th=" << thread();
+        if (threadRoot()) str << " [ROOT]";
+        if (packNextp()) str << " nx=" << packNextp()->name();
     }
 };
 inline std::ostream& operator<<(std::ostream& os, const ExecMTask& rhs) {
-    rhs.dump(os); return os; }
+    rhs.dump(os);
+    return os;
+}
 
 #endif  // Guard
