@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2000-2020 by Wilson Snyder.  This program is free software;
-// you can redistribute it and/or modify it under the terms of either the
-// GNU Lesser General Public License Version 3 or the Perl Artistic License
+// Copyright 2000-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
+// Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -48,13 +44,13 @@ protected:
 public:
     // CONSTANTS
     enum MiscConsts {
-        DEFINE_RECURSION_LEVEL_MAX = 1000,      // How many `def substitutions before an error
-        LINE_TOKEN_MAX = 20000,                 // How many tokens on a line before an error
-        INCLUDE_DEPTH_MAX = 500,                // How many `includes deep before an error
-        STREAM_DEPTH_LEVEL_MAX = 2000,          // How many streams deep (sometimes `def deep) before an error
-        //                                      // Set more than DEFINE_RECURSION_LEVEL_MAX
-        //                                      // or INCLUDE_DEPTH_MAX
-        NEWLINES_VS_TICKLINE = 20               // Use `line in place of this many newlines
+        DEFINE_RECURSION_LEVEL_MAX = 1000,  // How many `def substitutions before an error
+        LINE_TOKEN_MAX = 20000,  // How many tokens on a line before an error
+        INCLUDE_DEPTH_MAX = 500,  // How many `includes deep before an error
+        // Streams deep (sometimes `def deep) before an error.
+        // Set more than DEFINE_RECURSION_LEVEL_MAX or INCLUDE_DEPTH_MAX.
+        STREAM_DEPTH_LEVEL_MAX = 2000,
+        NEWLINES_VS_TICKLINE = 20  // Use `line in place of this many newlines
     };
 
     // ACCESSORS
@@ -84,9 +80,10 @@ public:
     virtual void include(const string& filename) = 0;  // Request a include file be processed
 
     virtual void undef(const string& name) = 0;  // Remove a definition
-    virtual void define(FileLine* fileline, const string& name,
-                        const string& value, const string& params="",
-                        bool cmdline=false) = 0;  // `define without any parameters
+    virtual void define(FileLine* fileline, const string& name, const string& value,
+                        const string& params = "",
+                        bool cmdline = false)
+        = 0;  // `define without any parameters
     virtual void defineCmdLine(FileLine* fileline, const string& name,
                                const string& value) {  // `define without any parameters
         define(fileline, name, value, "", true);
@@ -101,13 +98,12 @@ public:
 
 protected:
     // CONSTRUCTORS
-    V3PreProc() {
-        m_debug = 0;
-    }
+    V3PreProc() { m_debug = 0; }
     void configure(FileLine* fl);
+
 public:
     static V3PreProc* createPreProc(FileLine* fl);
-    virtual ~V3PreProc() {}
+    virtual ~V3PreProc() {}  // LCOV_EXCL_LINE  // Persistent
 };
 
 #endif  // Guard
