@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Scope's Transformations:
@@ -33,8 +29,6 @@
 #include "V3Ast.h"
 
 #include <algorithm>
-#include <cstdarg>
-#include <iomanip>
 #include <map>
 #include VL_INCLUDE_UNORDERED_MAP
 #include VL_INCLUDE_UNORDERED_SET
@@ -47,35 +41,35 @@ private:
     // NODE STATE
     // AstVar::user1p           -> AstVarScope replacement for this variable
     // AstTask::user2p          -> AstTask*.  Replacement task
-    AstUser1InUse       m_inuser1;
-    AstUser2InUse       m_inuser2;
+    AstUser1InUse m_inuser1;
+    AstUser2InUse m_inuser2;
 
     // TYPES
-    typedef vl_unordered_map<AstPackage*, AstScope*> PackageScopeMap;
+    typedef vl_unordered_map<AstNodeModule*, AstScope*> PackageScopeMap;
     // These cannot be unordered unless make a specialized hashing pair (gcc-8)
     typedef std::map<std::pair<AstVar*, AstScope*>, AstVarScope*> VarScopeMap;
     typedef std::set<std::pair<AstVarRef*, AstScope*> > VarRefScopeSet;
 
     // STATE, inside processing a single module
-    AstNodeModule* m_modp;      // Current module
-    AstScope*   m_scopep;       // Current scope we are building
+    AstNodeModule* m_modp;  // Current module
+    AstScope* m_scopep;  // Current scope we are building
     // STATE, for passing down one level of hierarchy (may need save/restore)
-    AstCell*    m_aboveCellp;   // Cell that instantiates this module
-    AstScope*   m_aboveScopep;  // Scope that instantiates this scope
+    AstCell* m_aboveCellp;  // Cell that instantiates this module
+    AstScope* m_aboveScopep;  // Scope that instantiates this scope
 
-    PackageScopeMap     m_packageScopes;        // Scopes for each package
-    VarScopeMap         m_varScopes;            // Varscopes created for each scope and var
-    VarRefScopeSet      m_varRefScopes;         // Varrefs-in-scopes needing fixup when done
+    PackageScopeMap m_packageScopes;  // Scopes for each package
+    VarScopeMap m_varScopes;  // Varscopes created for each scope and var
+    VarRefScopeSet m_varRefScopes;  // Varrefs-in-scopes needing fixup when done
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     void cleanupVarRefs() {
-        for (VarRefScopeSet::iterator it = m_varRefScopes.begin();
-             it!=m_varRefScopes.end(); ++it) {
+        for (VarRefScopeSet::iterator it = m_varRefScopes.begin(); it != m_varRefScopes.end();
+             ++it) {
             AstVarRef* nodep = it->first;
             AstScope* scopep = it->second;
-            if (nodep->packagep()) {
+            if (nodep->packagep() && !nodep->varp()->isClassMember()) {
                 PackageScopeMap::iterator it2 = m_packageScopes.find(nodep->packagep());
                 UASSERT_OBJ(it2 != m_packageScopes.end(), nodep, "Can't locate package scope");
                 scopep = it2->second;
@@ -90,7 +84,10 @@ private:
     // VISITORS
     virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         AstNodeModule* modp = nodep->topModulep();
-        if (!modp) { nodep->v3error("No top level module found"); return; }
+        if (!modp) {
+            nodep->v3error("No top level module found");
+            return;
+        }
         // Operate starting at the top of the hierarchy
         m_aboveCellp = NULL;
         m_aboveScopep = NULL;
@@ -100,22 +97,25 @@ private:
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         // Create required blocks and add to module
         string scopename;
-        if (!m_aboveScopep) scopename = "TOP";
-        else scopename = m_aboveScopep->name()+"."+m_aboveCellp->name();
+        if (!m_aboveScopep) {
+            scopename = "TOP";
+        } else {
+            scopename = m_aboveScopep->name() + "." + m_aboveCellp->name();
+        }
 
-        UINFO(4," MOD AT "<<scopename<<"  "<<nodep<<endl);
+        UINFO(4, " MOD AT " << scopename << "  " << nodep << endl);
         AstNode::user1ClearTree();
 
-        m_scopep = new AstScope((m_aboveCellp ? static_cast<AstNode*>(m_aboveCellp)
-                                 : static_cast<AstNode*>(nodep))
-                                ->fileline(),
-                                nodep, scopename, m_aboveScopep, m_aboveCellp);
+        m_scopep = new AstScope(
+            (m_aboveCellp ? static_cast<AstNode*>(m_aboveCellp) : static_cast<AstNode*>(nodep))
+                ->fileline(),
+            nodep, scopename, m_aboveScopep, m_aboveCellp);
         if (VN_IS(nodep, Package)) {
             m_packageScopes.insert(make_pair(VN_CAST(nodep, Package), m_scopep));
         }
 
         // Now for each child cell, iterate the module this cell points to
-        for (AstNode* cellnextp = nodep->stmtsp(); cellnextp; cellnextp=cellnextp->nextp()) {
+        for (AstNode* cellnextp = nodep->stmtsp(); cellnextp; cellnextp = cellnextp->nextp()) {
             if (AstCell* cellp = VN_CAST(cellnextp, Cell)) {
                 AstScope* oldScopep = m_scopep;
                 AstCell* oldAbCellp = m_aboveCellp;
@@ -135,7 +135,7 @@ private:
         }
 
         // Create scope for the current usage of this module
-        UINFO(4," back AT "<<scopename<<"  "<<nodep<<endl);
+        UINFO(4, " back AT " << scopename << "  " << nodep << endl);
         AstNode::user1ClearTree();
         m_modp = nodep;
         if (m_modp->isTop()) {
@@ -151,31 +151,56 @@ private:
 
         // ***Note m_scopep is passed back to the caller of the routine (above)
     }
-    virtual void visit(AstCellInline* nodep) VL_OVERRIDE {
+    virtual void visit(AstClass* nodep) VL_OVERRIDE {
+        // Create required blocks and add to module
+        AstScope* oldScopep = m_scopep;
+        AstCell* oldAbCellp = m_aboveCellp;
+        AstScope* oldAbScopep = m_aboveScopep;
+        {
+            m_aboveScopep = m_scopep;
+
+            string scopename;
+            if (!m_aboveScopep) {
+                scopename = "TOP";
+            } else {
+                scopename = m_aboveScopep->name() + "." + nodep->name();
+            }
+
+            UINFO(4, " CLASS AT " << scopename << "  " << nodep << endl);
+            AstNode::user1ClearTree();
+
+            AstNode* abovep = (m_aboveCellp ? static_cast<AstNode*>(m_aboveCellp)
+                                            : static_cast<AstNode*>(nodep));
+            m_scopep
+                = new AstScope(abovep->fileline(), m_modp, scopename, m_aboveScopep, m_aboveCellp);
+            // Create scope for the current usage of this cell
+            AstNode::user1ClearTree();
+            nodep->addMembersp(m_scopep);
+
+            iterateChildren(nodep);
+        }
+        // Done, restore vars
+        m_scopep = oldScopep;
+        m_aboveCellp = oldAbCellp;
+        m_aboveScopep = oldAbScopep;
+    }
+    virtual void visit(AstCellInline* nodep) VL_OVERRIDE {  //
         nodep->scopep(m_scopep);
     }
-    virtual void visit(AstActive* nodep) VL_OVERRIDE {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {  // LCOV_EXCL_LINE
         nodep->v3fatalSrc("Actives now made after scoping");
     }
-    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
+    virtual void visit(AstNodeProcedure* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
-        AstInitial* clonep = nodep->cloneTree(false);
-        nodep->user2p(clonep);
-        m_scopep->addActivep(clonep);
-        iterateChildren(clonep);  // We iterate under the *clone*
-    }
-    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
-        // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
-        AstFinal* clonep = nodep->cloneTree(false);
+        UINFO(4, "    Move " << nodep << endl);
+        AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
         iterateChildren(clonep);  // We iterate under the *clone*
     }
     virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
+        UINFO(4, "    Move " << nodep << endl);
         AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -183,7 +208,7 @@ private:
     }
     virtual void visit(AstAssignVarScope* nodep) VL_OVERRIDE {
         // Copy under the scope but don't recurse
-        UINFO(4,"    Move "<<nodep<<endl);
+        UINFO(4, "    Move " << nodep << endl);
         AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -191,15 +216,7 @@ private:
     }
     virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
-        AstNode* clonep = nodep->cloneTree(false);
-        nodep->user2p(clonep);
-        m_scopep->addActivep(clonep);
-        iterateChildren(clonep);  // We iterate under the *clone*
-    }
-    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
-        // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
+        UINFO(4, "    Move " << nodep << endl);
         AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -207,7 +224,7 @@ private:
     }
     virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
+        UINFO(4, "    Move " << nodep << endl);
         AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -215,7 +232,7 @@ private:
     }
     virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    Move "<<nodep<<endl);
+        UINFO(4, "    Move " << nodep << endl);
         AstNode* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -223,7 +240,7 @@ private:
     }
     virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    CFUNC "<<nodep<<endl);
+        UINFO(4, "    CFUNC " << nodep << endl);
         AstCFunc* clonep = nodep->cloneTree(false);
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
@@ -233,8 +250,15 @@ private:
     }
     virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         // Add to list of blocks under this scope
-        UINFO(4,"    FTASK "<<nodep<<endl);
-        AstNodeFTask* clonep = nodep->cloneTree(false);
+        UINFO(4, "    FTASK " << nodep << endl);
+        AstNodeFTask* clonep;
+        if (nodep->classMethod()) {
+            // Only one scope will be created, so avoid pointless cloning
+            nodep->unlinkFrBack();
+            clonep = nodep;
+        } else {
+            clonep = nodep->cloneTree(false);
+        }
         nodep->user2p(clonep);
         m_scopep->addActivep(clonep);
         // We iterate under the *clone*
@@ -242,10 +266,9 @@ private:
     }
     virtual void visit(AstVar* nodep) VL_OVERRIDE {
         // Make new scope variable
-        // This is called cross-module by AstVar, so we cannot trust any m_ variables
         if (!nodep->user1p()) {
             AstVarScope* varscp = new AstVarScope(nodep->fileline(), m_scopep, nodep);
-            UINFO(6,"   New scope "<<varscp<<endl);
+            UINFO(6, "   New scope " << varscp << endl);
             if (m_aboveCellp && !m_aboveCellp->isTrace()) varscp->trace(false);
             nodep->user1p(varscp);
             if (v3Global.opt.isClocker(varscp->prettyName())) {
@@ -271,10 +294,10 @@ private:
             // So push to a list and post-correct
             m_varRefScopes.insert(make_pair(nodep, m_scopep));
         }
-   }
+    }
     virtual void visit(AstScopeName* nodep) VL_OVERRIDE {
         // If there's a %m in the display text, we add a special node that will contain the name()
-        string prefix = string("__DOT__")+m_scopep->name();
+        string prefix = string("__DOT__") + m_scopep->name();
         // TOP and above will be the user's name().
         // Note 'TOP.' is stripped by scopePrettyName
         // To keep correct visual order, must add before other Text's
@@ -293,10 +316,8 @@ private:
         // Want to ignore blocks under it, so just do nothing
     }
     //--------------------
-    // Default
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     explicit ScopeVisitor(AstNetlist* nodep) {
@@ -341,36 +362,14 @@ private:
         }
     }
 
-    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstAssignVarScope* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
-    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
-        movedDeleteOrIterate(nodep);
-    }
+    virtual void visit(AstNodeProcedure* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstAssignVarScope* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstAssignW* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE { movedDeleteOrIterate(nodep); }
 
     virtual void visit(AstVarXRef* nodep) VL_OVERRIDE {
         // The crossrefs are dealt with in V3LinkDot
@@ -378,17 +377,17 @@ private:
     }
     virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         // The crossrefs are dealt with in V3LinkDot
-        UINFO(9,"   Old pkg-taskref "<<nodep<<endl);
+        UINFO(9, "   Old pkg-taskref " << nodep << endl);
         if (nodep->packagep()) {
             // Point to the clone
             UASSERT_OBJ(nodep->taskp(), nodep, "Unlinked");
             AstNodeFTask* newp = VN_CAST(nodep->taskp()->user2p(), NodeFTask);
             UASSERT_OBJ(newp, nodep, "No clone for package function");
             nodep->taskp(newp);
-            UINFO(9,"   New pkg-taskref "<<nodep<<endl);
-        } else {
+            UINFO(9, "   New pkg-taskref " << nodep << endl);
+        } else if (!VN_IS(nodep, MethodCall)) {
             nodep->taskp(NULL);
-            UINFO(9,"   New pkg-taskref "<<nodep<<endl);
+            UINFO(9, "   New pkg-taskref " << nodep << endl);
         }
         iterateChildren(nodep);
     }
@@ -399,10 +398,8 @@ private:
     }
 
     //--------------------
-    // Default
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     explicit ScopeCleanupVisitor(AstNetlist* nodep) {
@@ -416,10 +413,10 @@ public:
 // Scope class functions
 
 void V3Scope::scopeAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
+    UINFO(2, __FUNCTION__ << ": " << endl);
     {
-        ScopeVisitor visitor (nodep);
-        ScopeCleanupVisitor cleanVisitor (nodep);
+        ScopeVisitor visitor(nodep);
+        ScopeCleanupVisitor cleanVisitor(nodep);
     }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("scope", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
