@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3SplitAs's Transformations:
@@ -33,10 +29,7 @@
 #include "V3Stats.h"
 #include "V3Ast.h"
 
-#include <algorithm>
-#include <cstdarg>
 #include <map>
-#include <vector>
 
 //######################################################################
 
@@ -56,14 +49,12 @@ private:
 
     // METHODS
     virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
-        if (nodep->lvalue() && !m_splitVscp
-            && nodep->varp()->attrIsolateAssign()) {
+        if (nodep->lvalue() && !m_splitVscp && nodep->varp()->attrIsolateAssign()) {
             m_splitVscp = nodep->varScopep();
         }
     }
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     explicit SplitAsFindVisitor(AstAlways* nodep) {
@@ -81,16 +72,16 @@ public:
 class SplitAsCleanVisitor : public SplitAsBaseVisitor {
 private:
     // STATE
-    AstVarScope* m_splitVscp;   // Variable we want to split
-    bool         m_modeMatch;   // Remove matching Vscp, else non-matching
-    bool         m_keepStmt;    // Current Statement must be preserved
-    bool         m_matches;     // Statement below has matching lvalue reference
+    AstVarScope* m_splitVscp;  // Variable we want to split
+    bool m_modeMatch;  // Remove matching Vscp, else non-matching
+    bool m_keepStmt;  // Current Statement must be preserved
+    bool m_matches;  // Statement below has matching lvalue reference
 
     // METHODS
     virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->lvalue()) {
-            if (nodep->varScopep()==m_splitVscp) {
-                UINFO(6,"       CL VAR "<<nodep<<endl);
+            if (nodep->varScopep() == m_splitVscp) {
+                UINFO(6, "       CL VAR " << nodep << endl);
                 m_matches = true;
             }
         }
@@ -100,7 +91,7 @@ private:
             iterateChildren(nodep);
             return;
         }
-        UINFO(6,"     CL STMT "<<nodep<<endl);
+        UINFO(6, "     CL STMT " << nodep << endl);
         bool oldKeep = m_keepStmt;
         {
             m_matches = false;
@@ -108,28 +99,27 @@ private:
 
             iterateChildren(nodep);
 
-            if (m_keepStmt
-                || (m_modeMatch ? m_matches : !m_matches)) {
-                UINFO(6,"     Keep   STMT "<<nodep<<endl);
+            if (m_keepStmt || (m_modeMatch ? m_matches : !m_matches)) {
+                UINFO(6, "     Keep   STMT " << nodep << endl);
                 m_keepStmt = true;
             } else {
-                UINFO(6,"     Delete STMT "<<nodep<<endl);
-                nodep->unlinkFrBack(); pushDeletep(nodep);
+                UINFO(6, "     Delete STMT " << nodep << endl);
+                nodep->unlinkFrBack();
+                pushDeletep(nodep);
             }
         }
         // If something below matches, the upper statement remains too.
         m_keepStmt = oldKeep || m_keepStmt;
-        UINFO(9,"     upKeep="<<m_keepStmt<<" STMT "<<nodep<<endl);
-    }
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
+        UINFO(9, "     upKeep=" << m_keepStmt << " STMT " << nodep << endl);
     }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     SplitAsCleanVisitor(AstAlways* nodep, AstVarScope* vscp, bool modeMatch) {
         m_splitVscp = vscp;
         m_modeMatch = modeMatch;
-        m_keepStmt =  false;
+        m_keepStmt = false;
         m_matches = false;
         iterate(nodep);
     }
@@ -143,7 +133,7 @@ class SplitAsVisitor : public SplitAsBaseVisitor {
 private:
     // NODE STATE
     //  AstAlways::user()       -> bool.  True if already processed
-    AstUser1InUse       m_inuser1;
+    AstUser1InUse m_inuser1;
 
     // STATE
     VDouble0 m_statSplits;  // Statistic tracking
@@ -151,20 +141,20 @@ private:
 
     // METHODS
     void splitAlways(AstAlways* nodep) {
-        UINFO(3,"Split  "<<nodep<<endl);
-        UINFO(3,"   For "<<m_splitVscp<<endl);
-        if (debug()>=9) nodep->dumpTree(cout, "-in  : ");
+        UINFO(3, "Split  " << nodep << endl);
+        UINFO(3, "   For " << m_splitVscp << endl);
+        if (debug() >= 9) nodep->dumpTree(cout, "-in  : ");
         // Duplicate it and link in
         AstAlways* newp = nodep->cloneTree(false);
         newp->user1(true);  // So we don't clone it again
         nodep->addNextHere(newp);
-        {   // Delete stuff we don't want in old
-            SplitAsCleanVisitor visitor (nodep, m_splitVscp, false);
-            if (debug()>=9) nodep->dumpTree(cout, "-out0: ");
+        {  // Delete stuff we don't want in old
+            SplitAsCleanVisitor visitor(nodep, m_splitVscp, false);
+            if (debug() >= 9) nodep->dumpTree(cout, "-out0: ");
         }
-        {   // Delete stuff we don't want in new
-            SplitAsCleanVisitor visitor (newp, m_splitVscp, true);
-            if (debug()>=9) newp->dumpTree(cout, "-out1: ");
+        {  // Delete stuff we don't want in new
+            SplitAsCleanVisitor visitor(newp, m_splitVscp, true);
+            if (debug() >= 9) newp->dumpTree(cout, "-out1: ");
         }
     }
 
@@ -174,13 +164,12 @@ private:
         AstVarScope* lastSplitVscp = NULL;
         while (!nodep->user1()) {
             // Find any splittable variables
-            SplitAsFindVisitor visitor (nodep);
+            SplitAsFindVisitor visitor(nodep);
             m_splitVscp = visitor.splitVscp();
             if (m_splitVscp && m_splitVscp == lastSplitVscp) {
                 // We did this last time!  Something's stuck!
                 nodep->v3fatalSrc("Infinite loop in isolate_assignments removal for: "
-                                  <<m_splitVscp->prettyNameQ())
-                m_splitVscp = NULL;
+                                  << m_splitVscp->prettyNameQ());
             }
             lastSplitVscp = m_splitVscp;
             // Now isolate the always
@@ -194,11 +183,8 @@ private:
     }
 
     // Speedup; no always under math
-    virtual void visit(AstNodeMath* nodep) VL_OVERRIDE {}
-
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -216,9 +202,7 @@ public:
 // SplitAs class functions
 
 void V3SplitAs::splitAsAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        SplitAsVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { SplitAsVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("splitas", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
