@@ -6,20 +6,16 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
-#ifndef _V3LINKSYMTABLE_H_
-#define _V3LINKSYMTABLE_H_ 1
+#ifndef _V3SYMTABLE_H_
+#define _V3SYMTABLE_H_ 1
 
 #include "config_build.h"
 #include "verilatedos.h"
@@ -40,22 +36,20 @@ class VSymEnt;
 //######################################################################
 // Symbol table
 
-typedef std::set<VSymEnt*> VSymMap;
 typedef std::set<const VSymEnt*> VSymConstMap;
 
 class VSymEnt {
     // Symbol table that can have a "superior" table for resolving upper references
-private:
     // MEMBERS
-    typedef std::multimap<string,VSymEnt*> IdNameMap;
-    IdNameMap   m_idNameMap;    // Hash of variables by name
-    AstNode*    m_nodep;        // Node that entry belongs to
-    VSymEnt*    m_fallbackp;    // Table "above" this one in name scope, for fallback resolution
-    VSymEnt*    m_parentp;      // Table that created this table, dot notation needed to resolve into it
-    AstPackage* m_packagep;     // Package node is in (for V3LinkDot, unused here)
-    string      m_symPrefix;    // String to prefix symbols with (for V3LinkDot, unused here)
-    bool        m_exported;     // Allow importing
-    bool        m_imported;     // Was imported
+    typedef std::multimap<string, VSymEnt*> IdNameMap;
+    IdNameMap m_idNameMap;  // Hash of variables by name
+    AstNode* m_nodep;  // Node that entry belongs to
+    VSymEnt* m_fallbackp;  // Table "above" this one in name scope, for fallback resolution
+    VSymEnt* m_parentp;  // Table that created this table, dot notation needed to resolve into it
+    AstNodeModule* m_packagep;  // Package node is in (for V3LinkDot, unused here)
+    string m_symPrefix;  // String to prefix symbols with (for V3LinkDot, unused here)
+    bool m_exported;  // Allow importing
+    bool m_imported;  // Was imported
 #ifdef VL_DEBUG
     static int debug() {
         static int level = -1;
@@ -66,27 +60,33 @@ private:
     static inline int debug() { return 0; }  // NOT runtime, too hot of a function
 #endif
 public:
+    typedef IdNameMap::const_iterator const_iterator;
+    const_iterator begin() const { return m_idNameMap.begin(); }
+    const_iterator end() const { return m_idNameMap.end(); }
+
     void dumpIterate(std::ostream& os, VSymConstMap& doneSymsr, const string& indent,
                      int numLevels, const string& searchName) const {
-        os<<indent<<"+ "<<std::left<<std::setw(30)
-          <<(searchName==""?"\"\"":searchName)<<std::setw(0)<<std::right;
-        os<<"  se"<<cvtToHex(this)<<std::setw(0);
-        os<<"  fallb=se"<<cvtToHex(m_fallbackp);
-        if (m_symPrefix!="") os<<"  symPrefix="<<m_symPrefix;
-        os<<"  n="<<nodep();
-        os<<endl;
-        if (doneSymsr.find(this) != doneSymsr.end()) {
-            os<<indent<<"| ^ duplicate, so no children printed\n";
+        os << indent << "+ " << std::left << std::setw(30)
+           << (searchName == "" ? "\"\"" : searchName) << std::setw(0) << std::right;
+        os << "  se" << cvtToHex(this) << std::setw(0);
+        os << "  fallb=se" << cvtToHex(m_fallbackp);
+        if (m_symPrefix != "") os << "  symPrefix=" << m_symPrefix;
+        os << "  n=" << nodep();
+        os << endl;
+        if (VL_UNCOVERABLE(doneSymsr.find(this) != doneSymsr.end())) {
+            os << indent << "| ^ duplicate, so no children printed\n";  // LCOV_EXCL_LINE
         } else {
             doneSymsr.insert(this);
-            for (IdNameMap::const_iterator it=m_idNameMap.begin(); it!=m_idNameMap.end(); ++it) {
+            for (IdNameMap::const_iterator it = m_idNameMap.begin(); it != m_idNameMap.end();
+                 ++it) {
                 if (numLevels >= 1) {
-                    it->second->dumpIterate(os, doneSymsr, indent+"| ", numLevels-1, it->first);
+                    it->second->dumpIterate(os, doneSymsr, indent + "| ", numLevels - 1,
+                                            it->first);
                 }
             }
         }
     }
-    void dump(std::ostream& os, const string& indent="", int numLevels=1) const {
+    void dump(std::ostream& os, const string& indent = "", int numLevels = 1) const {
         VSymConstMap doneSyms;
         dumpIterate(os, doneSyms, indent, numLevels, "TOP");
     }
@@ -97,10 +97,10 @@ public:
     ~VSymEnt() {
         // Change links so we coredump if used
 #ifdef VL_DEBUG
-        m_nodep = (AstNode*)1;
-        m_fallbackp = (VSymEnt*)1;
-        m_parentp = (VSymEnt*)1;
-        m_packagep = (AstPackage*)1;
+        m_nodep = reinterpret_cast<AstNode*>(1);
+        m_fallbackp = reinterpret_cast<VSymEnt*>(1);
+        m_parentp = reinterpret_cast<VSymEnt*>(1);
+        m_packagep = reinterpret_cast<AstNodeModule*>(1);
 #endif
     }
 #if defined(VL_DEBUG) && !defined(VL_LEAK_CHECKS)
@@ -110,8 +110,8 @@ public:
     void fallbackp(VSymEnt* entp) { m_fallbackp = entp; }
     void parentp(VSymEnt* entp) { m_parentp = entp; }
     VSymEnt* parentp() const { return m_parentp; }
-    void packagep(AstPackage* entp) { m_packagep = entp; }
-    AstPackage* packagep() const { return m_packagep; }
+    void packagep(AstNodeModule* entp) { m_packagep = entp; }
+    AstNodeModule* packagep() const { return m_packagep; }
     AstNode* nodep() const { return m_nodep; }
     string symPrefix() const { return m_symPrefix; }
     void symPrefix(const string& name) { m_symPrefix = name; }
@@ -120,12 +120,13 @@ public:
     bool imported() const { return m_imported; }
     void imported(bool flag) { m_imported = flag; }
     void insert(const string& name, VSymEnt* entp) {
-        UINFO(9, "     SymInsert se"<<cvtToHex(this)
-              <<" '"<<name<<"' se"<<cvtToHex(entp)<<"  "<<entp->nodep()<<endl);
+        UINFO(9, "     SymInsert se" << cvtToHex(this) << " '" << name << "' se" << cvtToHex(entp)
+                                     << "  " << entp->nodep() << endl);
         if (name != "" && m_idNameMap.find(name) != m_idNameMap.end()) {
             if (!V3Error::errorCount()) {  // Else may have just reported warning
-                if (debug()>=9 || V3Error::debugDefault()) dump(cout,"- err-dump: ", 1);
-                entp->nodep()->v3fatalSrc("Inserting two symbols with same name: "<<name<<endl);
+                if (debug() >= 9 || V3Error::debugDefault()) dump(cout, "- err-dump: ", 1);
+                entp->nodep()->v3fatalSrc("Inserting two symbols with same name: " << name
+                                                                                   << endl);
             }
         } else {
             m_idNameMap.insert(make_pair(name, entp));
@@ -133,9 +134,9 @@ public:
     }
     void reinsert(const string& name, VSymEnt* entp) {
         IdNameMap::iterator it = m_idNameMap.find(name);
-        if (name!="" && it != m_idNameMap.end()) {
-            UINFO(9, "     SymReinsert se"<<cvtToHex(this)
-                  <<" '"<<name<<"' se"<<cvtToHex(entp)<<"  "<<entp->nodep()<<endl);
+        if (name != "" && it != m_idNameMap.end()) {
+            UINFO(9, "     SymReinsert se" << cvtToHex(this) << " '" << name << "' se"
+                                           << cvtToHex(entp) << "  " << entp->nodep() << endl);
             it->second = entp;  // Replace
         } else {
             insert(name, entp);
@@ -145,9 +146,12 @@ public:
         // Find identifier without looking upward through symbol hierarchy
         // First, scan this begin/end block or module for the name
         IdNameMap::const_iterator it = m_idNameMap.find(name);
-        UINFO(9, "     SymFind   se"<<cvtToHex(this)<<" '"<<name
-              <<"' -> "<<(it == m_idNameMap.end() ? "NONE"
-                          : "se"+cvtToHex(it->second)+" n="+cvtToHex(it->second->nodep()))<<endl);
+        UINFO(9, "     SymFind   se"
+                     << cvtToHex(this) << " '" << name << "' -> "
+                     << (it == m_idNameMap.end()
+                             ? "NONE"
+                             : "se" + cvtToHex(it->second) + " n=" + cvtToHex(it->second->nodep()))
+                     << endl);
         if (it != m_idNameMap.end()) return (it->second);
         return NULL;
     }
@@ -161,8 +165,7 @@ public:
     }
     void candidateIdFlat(VSpellCheck* spellerp, const VNodeMatcher* matcherp) const {
         // Suggest alternative symbol candidates without looking upward through symbol hierarchy
-        for (IdNameMap::const_iterator it = m_idNameMap.begin();
-             it != m_idNameMap.end(); ++it) {
+        for (IdNameMap::const_iterator it = m_idNameMap.begin(); it != m_idNameMap.end(); ++it) {
             const AstNode* itemp = it->second->nodep();
             if (itemp && (!matcherp || matcherp->nodeMatch(itemp))) {
                 spellerp->pushCandidate(itemp->prettyName());
@@ -176,9 +179,11 @@ public:
         // Then suggest the upper begin/end block or module
         if (m_fallbackp) m_fallbackp->candidateIdFallback(spellerp, matcherp);
     }
+
 private:
-    void importOneSymbol(VSymGraph* graphp, const string& name, const VSymEnt* srcp) {
-        if (srcp->exported()
+    void importOneSymbol(VSymGraph* graphp, const string& name, const VSymEnt* srcp,
+                         bool honorExport) {
+        if ((!honorExport || srcp->exported())
             && !findIdFlat(name)) {  // Don't insert over existing entry
             VSymEnt* symp = new VSymEnt(graphp, srcp);
             symp->exported(false);  // Can't reimport an import without an export
@@ -186,25 +191,34 @@ private:
             reinsert(name, symp);
         }
     }
-    void exportOneSymbol(VSymGraph* graphp, const string& name, const VSymEnt* srcp) {
+    void exportOneSymbol(VSymGraph* graphp, const string& name, const VSymEnt* srcp) const {
         if (srcp->exported()) {
             if (VSymEnt* symp = findIdFlat(name)) {  // Should already exist in current table
                 if (!symp->exported()) symp->exported(true);
             }
         }
     }
+
 public:
+    void importFromClass(VSymGraph* graphp, const VSymEnt* srcp) {
+        // Import tokens from source symbol table into this symbol table
+        // Used for classes in early parsing only to handle "extends"
+        for (IdNameMap::const_iterator it = srcp->m_idNameMap.begin();
+             it != srcp->m_idNameMap.end(); ++it) {
+            importOneSymbol(graphp, it->first, it->second, false);
+        }
+    }
     void importFromPackage(VSymGraph* graphp, const VSymEnt* srcp, const string& id_or_star) {
         // Import tokens from source symbol table into this symbol table
         if (id_or_star != "*") {
             IdNameMap::const_iterator it = srcp->m_idNameMap.find(id_or_star);
             if (it != srcp->m_idNameMap.end()) {
-                importOneSymbol(graphp, it->first, it->second);
+                importOneSymbol(graphp, it->first, it->second, true);
             }
         } else {
             for (IdNameMap::const_iterator it = srcp->m_idNameMap.begin();
                  it != srcp->m_idNameMap.end(); ++it) {
-                importOneSymbol(graphp, it->first, it->second);
+                importOneSymbol(graphp, it->first, it->second, true);
             }
         }
     }
@@ -212,9 +226,7 @@ public:
         // Export tokens from source symbol table into this symbol table
         if (id_or_star != "*") {
             IdNameMap::const_iterator it = srcp->m_idNameMap.find(id_or_star);
-            if (it != srcp->m_idNameMap.end()) {
-                exportOneSymbol(graphp, it->first, it->second);
-            }
+            if (it != srcp->m_idNameMap.end()) exportOneSymbol(graphp, it->first, it->second);
         } else {
             for (IdNameMap::const_iterator it = srcp->m_idNameMap.begin();
                  it != srcp->m_idNameMap.end(); ++it) {
@@ -224,14 +236,14 @@ public:
     }
     void exportStarStar(VSymGraph* graphp) {
         // Export *:*: Export all tokens from imported packages
-        for (IdNameMap::const_iterator it=m_idNameMap.begin(); it!=m_idNameMap.end(); ++it) {
+        for (IdNameMap::const_iterator it = m_idNameMap.begin(); it != m_idNameMap.end(); ++it) {
             VSymEnt* symp = it->second;
             if (!symp->exported()) symp->exported(true);
         }
     }
     void importFromIface(VSymGraph* graphp, const VSymEnt* srcp, bool onlyUnmodportable = false) {
         // Import interface tokens from source symbol table into this symbol table, recursively
-        UINFO(9, "     importIf  se"<<cvtToHex(this)<<" from se"<<cvtToHex(srcp)<<endl);
+        UINFO(9, "     importIf  se" << cvtToHex(this) << " from se" << cvtToHex(srcp) << endl);
         for (IdNameMap::const_iterator it = srcp->m_idNameMap.begin();
              it != srcp->m_idNameMap.end(); ++it) {
             const string& name = it->first;
@@ -245,20 +257,19 @@ public:
             }
         }
     }
-    void cellErrorScopes(AstNode* lookp, string prettyName="") {
-        if (prettyName=="") prettyName = lookp->prettyName();
+    void cellErrorScopes(AstNode* lookp, string prettyName = "") {
+        if (prettyName == "") prettyName = lookp->prettyName();
         string scopes;
-        for (IdNameMap::iterator it = m_idNameMap.begin(); it!=m_idNameMap.end(); ++it) {
+        for (IdNameMap::iterator it = m_idNameMap.begin(); it != m_idNameMap.end(); ++it) {
             AstNode* itemp = it->second->nodep();
-            if (VN_IS(itemp, Cell)
-                || (VN_IS(itemp, Module) && VN_CAST(itemp, Module)->isTop())) {
+            if (VN_IS(itemp, Cell) || (VN_IS(itemp, Module) && VN_CAST(itemp, Module)->isTop())) {
                 if (scopes != "") scopes += ", ";
                 scopes += AstNode::prettyName(it->first);
             }
         }
-        if (scopes=="") scopes="<no cells found>";
-        std::cerr<<V3Error::warnMore()<<"... Known scopes under '"<<prettyName<<"': "
-                 <<scopes<<endl;
+        if (scopes == "") scopes = "<no cells found>";
+        std::cerr << V3Error::warnMore() << "... Known scopes under '" << prettyName
+                  << "': " << scopes << endl;
         if (debug()) dump(std::cerr, "       KnownScope: ", 1);
     }
 };
@@ -272,43 +283,42 @@ class VSymGraph {
     typedef std::vector<VSymEnt*> SymStack;
 
     // MEMBERS
-    VSymEnt*    m_symRootp;             // Root symbol table
-    SymStack    m_symsp;                // All symbol tables, to cleanup
+    VSymEnt* m_symRootp;  // Root symbol table
+    SymStack m_symsp;  // All symbol tables, to cleanup
 
     // CONSTRUCTORS
     VL_UNCOPYABLE(VSymGraph);
-public:
-    explicit VSymGraph(AstNetlist* nodep) {
-        m_symRootp = new VSymEnt(this, nodep);
-    }
-    ~VSymGraph() {
-        for (SymStack::iterator it = m_symsp.begin(); it != m_symsp.end(); ++it) {
-            delete (*it);
-        }
-    }
 
 public:
+    explicit VSymGraph(AstNetlist* nodep) { m_symRootp = new VSymEnt(this, nodep); }
+    ~VSymGraph() {
+        for (SymStack::iterator it = m_symsp.begin(); it != m_symsp.end(); ++it) delete (*it);
+    }
+
     // METHODS
     VSymEnt* rootp() const { return m_symRootp; }
     // Debug
-    void dump(std::ostream& os, const string& indent="") {
+    void dump(std::ostream& os, const string& indent = "") {
         VSymConstMap doneSyms;
-        os<<"SymEnt Dump:\n";
+        os << "SymEnt Dump:\n";
         m_symRootp->dumpIterate(os, doneSyms, indent, 9999, "$root");
         bool first = true;
         for (SymStack::iterator it = m_symsp.begin(); it != m_symsp.end(); ++it) {
             if (doneSyms.find(*it) == doneSyms.end()) {
-                if (first) { first=false; os<<"%%Warning: SymEnt Orphans:\n"; }
+                if (first) {
+                    first = false;
+                    os << "%%Warning: SymEnt Orphans:\n";
+                }
                 (*it)->dumpIterate(os, doneSyms, indent, 9999, "Orphan");
             }
         }
     }
     void dumpFilePrefixed(const string& nameComment) {
         if (v3Global.opt.dumpTree()) {
-            string filename = v3Global.debugFilename(nameComment)+".txt";
-            UINFO(2,"Dumping "<<filename<<endl);
-            const vl_unique_ptr<std::ofstream> logp (V3File::new_ofstream(filename));
-            if (logp->fail()) v3fatal("Can't write "<<filename);
+            string filename = v3Global.debugFilename(nameComment) + ".txt";
+            UINFO(2, "Dumping " << filename << endl);
+            const vl_unique_ptr<std::ofstream> logp(V3File::new_ofstream(filename));
+            if (logp->fail()) v3fatal("Can't write " << filename);
             dump(*logp, "");
         }
     }
@@ -336,7 +346,7 @@ inline VSymEnt::VSymEnt(VSymGraph* graphp, AstNode* nodep)
 inline VSymEnt::VSymEnt(VSymGraph* graphp, const VSymEnt* symp)
     : m_nodep(symp->m_nodep) {
     m_fallbackp = symp->m_fallbackp;
-    m_parentp  = symp->m_parentp;
+    m_parentp = symp->m_parentp;
     m_packagep = symp->m_packagep;
     m_exported = symp->m_exported;
     m_imported = symp->m_imported;
