@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -27,9 +23,11 @@
 #include "V3Error.h"
 #include "V3Ast.h"
 
+// clang-format off
 #ifndef _V3WIDTH_CPP_
 # error "V3WidthCommit for V3Width internal use only"
 #endif
+// clang-format on
 
 //######################################################################
 
@@ -38,6 +36,14 @@
 
 class WidthRemoveVisitor : public AstNVisitor {
 private:
+    // METHODS
+    void replaceWithSignedVersion(AstNode* nodep, AstNode* newp) {
+        UINFO(6, " Replace " << nodep << " w/ " << newp << endl);
+        nodep->replaceWith(newp);
+        newp->dtypeFrom(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
+    }
+
     // VISITORS
     virtual void visit(AstSigned* nodep) VL_OVERRIDE {
         VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
@@ -45,22 +51,13 @@ private:
     virtual void visit(AstUnsigned* nodep) VL_OVERRIDE {
         VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
     }
-    virtual void visit(AstNode* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
-    void replaceWithSignedVersion(AstNode* nodep, AstNode* newp) {
-        UINFO(6," Replace "<<nodep<<" w/ "<<newp<<endl);
-        nodep->replaceWith(newp);
-        newp->dtypeFrom(nodep);
-        VL_DO_DANGLING(pushDeletep(nodep), nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     WidthRemoveVisitor() {}
     virtual ~WidthRemoveVisitor() {}
-    AstNode* mainAcceptEdit(AstNode* nodep) {
-        return iterateSubtreeReturnEdits(nodep);
-    }
+    AstNode* mainAcceptEdit(AstNode* nodep) { return iterateSubtreeReturnEdits(nodep); }
 };
 
 //######################################################################
@@ -70,15 +67,14 @@ public:
 class WidthCommitVisitor : public AstNVisitor {
     // NODE STATE
     // AstVar::user1p           -> bool, processed
-    AstUser1InUse       m_inuser1;
+    AstUser1InUse m_inuser1;
 
 public:
     // METHODS
     static AstConst* newIfConstCommitSize(AstConst* nodep) {
-        if (((nodep->dtypep()->width() != nodep->num().width())
-             || !nodep->num().sized())
+        if (((nodep->dtypep()->width() != nodep->num().width()) || !nodep->num().sized())
             && !nodep->num().isString()) {  // Need to force the number from unsized to sized
-            V3Number num (nodep, nodep->dtypep()->width());
+            V3Number num(nodep, nodep->dtypep()->width());
             num.opAssign(nodep->num());
             num.isSigned(nodep->isSigned());
             AstConst* newp = new AstConst(nodep->fileline(), num);
@@ -105,9 +101,12 @@ private:
         // Look for duplicate
         if (AstBasicDType* bdtypep = VN_CAST(nodep, BasicDType)) {
             AstBasicDType* newp = nodep->findInsertSameDType(bdtypep);
-            if (newp != bdtypep && debug()>=9) {
-                UINFO(9,"dtype replacement "); nodep->dumpSmall(cout);
-                cout<<"  ---->  "; newp->dumpSmall(cout); cout<<endl;
+            if (newp != bdtypep && debug() >= 9) {
+                UINFO(9, "dtype replacement ");
+                nodep->dumpSmall(cout);
+                cout << "  ---->  ";
+                newp->dumpSmall(cout);
+                cout << endl;
             }
             return newp;
         }
@@ -119,14 +118,15 @@ private:
         iterate(nodep->dtypep());  // Do datatype first
         if (AstConst* newp = newIfConstCommitSize(nodep)) {
             nodep->replaceWith(newp);
-            AstNode* oldp = nodep; nodep = newp;
-            //if (debug()>4) oldp->dumpTree(cout, "  fixConstSize_old: ");
-            //if (debug()>4) newp->dumpTree(cout, "              _new: ");
+            AstNode* oldp = nodep;
+            nodep = newp;
+            // if (debug() > 4) oldp->dumpTree(cout, "  fixConstSize_old: ");
+            // if (debug() > 4) newp->dumpTree(cout, "              _new: ");
             VL_DO_DANGLING(pushDeletep(oldp), oldp);
         }
         editDType(nodep);
     }
-    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
+    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {  //
         visitIterateNodeDType(nodep);
     }
     virtual void visit(AstNodeUOrStructDType* nodep) VL_OVERRIDE {
@@ -148,7 +148,7 @@ private:
         if (nodep->user1SetOnce()) return;  // Process once
         nodep->widthMinFromWidth();
         // Too late to any unspecified sign to be anything but unsigned
-        if (nodep->numeric().isNosign()) nodep->numeric(AstNumeric::UNSIGNED);
+        if (nodep->numeric().isNosign()) nodep->numeric(VSigning::UNSIGNED);
         iterateChildren(nodep);
         nodep->virtRefDTypep(editOneDType(nodep->virtRefDTypep()));
         nodep->virtRefDType2p(editOneDType(nodep->virtRefDType2p()));
@@ -161,6 +161,7 @@ private:
         iterateChildren(nodep);
         editDType(nodep);
     }
+
 public:
     // CONSTRUCTORS
     explicit WidthCommitVisitor(AstNetlist* nodep) {
