@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -25,16 +21,15 @@
 
 #include <algorithm>
 #include <fstream>
-#include <sys/stat.h>
 
 //######################################################################
 
 void VlcTop::readCoverage(const string& filename, bool nonfatal) {
-    UINFO(2,"readCoverage "<<filename<<endl);
+    UINFO(2, "readCoverage " << filename << endl);
 
     std::ifstream is(filename.c_str());
     if (!is) {
-        if (!nonfatal) v3fatal("Can't read "<<filename);
+        if (!nonfatal) v3fatal("Can't read " << filename);
         return;
     }
 
@@ -43,15 +38,15 @@ void VlcTop::readCoverage(const string& filename, bool nonfatal) {
 
     while (!is.eof()) {
         string line = V3Os::getline(is);
-        //UINFO(9," got "<<line<<endl);
+        // UINFO(9," got "<<line<<endl);
         if (line[0] == 'C') {
             string::size_type secspace = 3;
-            for (; secspace<line.length(); secspace++) {
-                if (line[secspace]=='\'' && line[secspace+1]==' ') break;
+            for (; secspace < line.length(); secspace++) {
+                if (line[secspace] == '\'' && line[secspace + 1] == ' ') break;
             }
-            string point = line.substr(3, secspace-3);
-            vluint64_t hits = atoll(line.c_str()+secspace+1);
-            //UINFO(9,"   point '"<<point<<"'"<<" "<<hits<<endl);
+            string point = line.substr(3, secspace - 3);
+            vluint64_t hits = atoll(line.c_str() + secspace + 1);
+            // UINFO(9,"   point '"<<point<<"'"<<" "<<hits<<endl);
 
             vluint64_t pointnum = points().findAddPoint(point, hits);
             if (pointnum) {}  // Prevent unused
@@ -66,25 +61,80 @@ void VlcTop::readCoverage(const string& filename, bool nonfatal) {
 }
 
 void VlcTop::writeCoverage(const string& filename) {
-    UINFO(2,"writeCoverage "<<filename<<endl);
+    UINFO(2, "writeCoverage " << filename << endl);
 
     std::ofstream os(filename.c_str());
     if (!os) {
-        v3fatal("Can't write "<<filename);
+        v3fatal("Can't write " << filename);
         return;
     }
 
     os << "# SystemC::Coverage-3" << endl;
-    for (VlcPoints::ByName::iterator it=m_points.begin(); it!=m_points.end(); ++it) {
+    for (VlcPoints::ByName::const_iterator it = m_points.begin(); it != m_points.end(); ++it) {
         const VlcPoint& point = m_points.pointNumber(it->second);
-        os <<"C '"<<point.name()<<"' " << point.count()<<endl;
+        os << "C '" << point.name() << "' " << point.count() << endl;
+    }
+}
+
+void VlcTop::writeInfo(const string& filename) {
+    UINFO(2, "writeInfo " << filename << endl);
+
+    std::ofstream os(filename.c_str());
+    if (!os) {
+        v3fatal("Can't write " << filename);
+        return;
+    }
+
+    annotateCalc();
+
+    // See 'man lcov' for format details
+    // TN:<trace_file_name>
+    // Source file:
+    //   SF:<absolute_path_to_source_file>
+    //   FN:<line_number_of_function_start>,<function_name>
+    //   FNDA:<execution_count>,<function_name>
+    //   FNF:<number_functions_found>
+    //   FNH:<number_functions_hit>
+    // Branches:
+    //   BRDA:<line_number>,<block_number>,<branch_number>,<taken_count_or_-_for_zero>
+    //   BRF:<number_of_branches_found>
+    //   BRH:<number_of_branches_hit>
+    // Line counts:
+    //   DA:<line_number>,<execution_count>
+    //   LF:<number_of_lines_found>
+    //   LH:<number_of_lines_hit>
+    // Section ending:
+    //   end_of_record
+
+    os << "TN:verilator_coverage\n";
+    for (VlcSources::NameMap::iterator sit = m_sources.begin(); sit != m_sources.end(); ++sit) {
+        VlcSource& source = sit->second;
+        os << "SF:" << source.name() << endl;
+        VlcSource::LinenoMap& lines = source.lines();
+        for (VlcSource::LinenoMap::iterator lit = lines.begin(); lit != lines.end(); ++lit) {
+            int lineno = lit->first;
+            VlcSource::ColumnMap& cmap = lit->second;
+            bool first = true;
+            vluint64_t min_count = 0;  // Minimum across all columns on line
+            for (VlcSource::ColumnMap::iterator cit = cmap.begin(); cit != cmap.end(); ++cit) {
+                VlcSourceCount& col = cit->second;
+                if (first) {
+                    min_count = col.count();
+                    first = false;
+                } else {
+                    min_count = std::min(min_count, col.count());
+                }
+            }
+            os << "DA:" << lineno << "," << min_count << "\n";
+        }
+        os << "end_of_record\n";
     }
 }
 
 //********************************************************************
 
 struct CmpComputrons {
-    inline bool operator() (const VlcTest* lhsp, const VlcTest* rhsp) const {
+    inline bool operator()(const VlcTest* lhsp, const VlcTest* rhsp) const {
         if (lhsp->computrons() != rhsp->computrons()) {
             return lhsp->computrons() < rhsp->computrons();
         }
@@ -93,12 +143,12 @@ struct CmpComputrons {
 };
 
 void VlcTop::rank() {
-    UINFO(2,"rank...\n");
+    UINFO(2, "rank...\n");
     vluint64_t nextrank = 1;
 
     // Sort by computrons, so fast tests get selected first
     std::vector<VlcTest*> bytime;
-    for (VlcTests::ByName::iterator it=m_tests.begin(); it!=m_tests.end(); ++it) {
+    for (VlcTests::ByName::const_iterator it = m_tests.begin(); it != m_tests.end(); ++it) {
         VlcTest* testp = *it;
         if (testp->bucketsCovered()) {  // else no points, so can't help us
             bytime.push_back(*it);
@@ -107,21 +157,24 @@ void VlcTop::rank() {
     sort(bytime.begin(), bytime.end(), CmpComputrons());  // Sort the vector
 
     VlcBuckets remaining;
-    for (VlcPoints::ByName::iterator it=m_points.begin(); it!=m_points.end(); ++it) {
+    for (VlcPoints::ByName::const_iterator it = m_points.begin(); it != m_points.end(); ++it) {
         VlcPoint* pointp = &points().pointNumber(it->second);
         // If any tests hit this point, then we'll need to cover it.
-        if (pointp->testsCovering()) { remaining.addData(pointp->pointNum(), 1); }
+        if (pointp->testsCovering()) remaining.addData(pointp->pointNum(), 1);
     }
 
     // Additional Greedy algorithm
     // O(n^2) Ouch.  Probably the thing to do is randomize the order of data
     // then hierarchically solve a small subset of tests, and take resulting
     // solution and move up to larger subset of tests.  (Aka quick sort.)
-    while (1) {
-        if (debug()) { UINFO(9,"Left on iter"<<nextrank<<": "); remaining.dump(); }
+    while (true) {
+        if (debug()) {
+            UINFO(9, "Left on iter" << nextrank << ": ");  // LCOV_EXCL_LINE
+            remaining.dump();  // LCOV_EXCL_LINE
+        }
         VlcTest* bestTestp = NULL;
         vluint64_t bestRemain = 0;
-        for (std::vector<VlcTest*>::iterator it=bytime.begin(); it!=bytime.end(); ++it) {
+        for (std::vector<VlcTest*>::iterator it = bytime.begin(); it != bytime.end(); ++it) {
             VlcTest* testp = *it;
             if (!testp->rank()) {
                 vluint64_t remain = testp->buckets().dataPopCount(remaining);
@@ -145,18 +198,43 @@ void VlcTop::rank() {
 
 void VlcTop::annotateCalc() {
     // Calculate per-line information into filedata structure
-    for (VlcPoints::ByName::iterator it=m_points.begin(); it!=m_points.end(); ++it) {
+    for (VlcPoints::ByName::const_iterator it = m_points.begin(); it != m_points.end(); ++it) {
         const VlcPoint& point = m_points.pointNumber(it->second);
         string filename = point.filename();
         int lineno = point.lineno();
-        if (!filename.empty() && lineno!=0) {
-            int column = point.column();
+        if (!filename.empty() && lineno != 0) {
             VlcSource& source = sources().findNewSource(filename);
             string threshStr = point.thresh();
             unsigned thresh = (!threshStr.empty()) ? atoi(threshStr.c_str()) : opt.annotateMin();
             bool ok = (point.count() >= thresh);
-            UINFO(9, "AnnoCalc count "<<filename<<" "<<lineno<<" "<<point.count()<<endl);
-            source.incCount(lineno, column, point.count(), ok);
+            UINFO(9, "AnnoCalc count " << filename << ":" << lineno << ":" << point.column() << " "
+                                       << point.count() << " " << point.linescov() << endl);
+            // Base coverage
+            source.incCount(lineno, point.column(), point.count(), ok);
+            // Additional lines covered by this statement
+            bool range = false;
+            int start = 0;
+            int end = 0;
+            string linescov = point.linescov();
+            for (const char* covp = linescov.c_str(); true; ++covp) {
+                if (!*covp || *covp == ',') {  // Ending
+                    for (int lni = start; start && lni <= end; ++lni) {
+                        source.incCount(lni, point.column(), point.count(), ok);
+                    }
+                    if (!*covp) { break; }
+                    start = 0;  // Prep for next
+                    end = 0;
+                    range = false;
+                } else if (*covp == '-') {
+                    range = true;
+                } else if (isdigit(*covp)) {
+                    const char* digitsp = covp;
+                    while (isdigit(*covp)) ++covp;
+                    --covp;  // Will inc in for loop
+                    if (!range) start = atoi(digitsp);
+                    end = atoi(digitsp);
+                }
+            }
         }
     }
 }
@@ -166,16 +244,16 @@ void VlcTop::annotateCalcNeeded() {
     // coverage in all categories
     int totCases = 0;
     int totOk = 0;
-    for (VlcSources::NameMap::iterator sit=m_sources.begin(); sit!=m_sources.end(); ++sit) {
+    for (VlcSources::NameMap::iterator sit = m_sources.begin(); sit != m_sources.end(); ++sit) {
         VlcSource& source = sit->second;
-        //UINFO(1,"Source "<<source.name()<<endl);
+        // UINFO(1,"Source "<<source.name()<<endl);
         if (opt.annotateAll()) source.needed(true);
         VlcSource::LinenoMap& lines = source.lines();
-        for (VlcSource::LinenoMap::iterator lit=lines.begin(); lit!=lines.end(); ++lit) {
+        for (VlcSource::LinenoMap::iterator lit = lines.begin(); lit != lines.end(); ++lit) {
             VlcSource::ColumnMap& cmap = lit->second;
-            for (VlcSource::ColumnMap::iterator cit=cmap.begin(); cit!=cmap.end(); ++cit) {
+            for (VlcSource::ColumnMap::iterator cit = cmap.begin(); cit != cmap.end(); ++cit) {
                 VlcSourceCount& col = cit->second;
-                //UINFO(0,"Source "<<source.name()<<":"<<col.lineno()<<":"<<col.column()<<endl);
+                // UINFO(0,"Source "<<source.name()<<":"<<col.lineno()<<":"<<col.column()<<endl);
                 ++totCases;
                 if (col.ok()) {
                     ++totOk;
@@ -185,36 +263,36 @@ void VlcTop::annotateCalcNeeded() {
             }
         }
     }
-    float pct = totCases ? (100*totOk / totCases) : 0;
-    cout<<"Total coverage ("<<totOk<<"/"<<totCases<<") "
-        <<std::fixed<<std::setw(3)<<std::setprecision(2)<<pct<<"%"<<endl;
-    if (totOk != totCases) cout<<"See lines with '%00' in "<<opt.annotateOut()<<endl;
+    float pct = totCases ? (100 * totOk / totCases) : 0;
+    cout << "Total coverage (" << totOk << "/" << totCases << ") ";
+    cout << std::fixed << std::setw(3) << std::setprecision(2) << pct << "%" << endl;
+    if (totOk != totCases) cout << "See lines with '%00' in " << opt.annotateOut() << endl;
 }
 
 void VlcTop::annotateOutputFiles(const string& dirname) {
     // Create if uncreated, ignore errors
     V3Os::createDir(dirname);
-    for (VlcSources::NameMap::iterator sit=m_sources.begin(); sit!=m_sources.end(); ++sit) {
+    for (VlcSources::NameMap::iterator sit = m_sources.begin(); sit != m_sources.end(); ++sit) {
         VlcSource& source = sit->second;
         if (!source.needed()) continue;
         string filename = source.name();
-        string outfilename = dirname+"/"+V3Os::filenameNonDir(filename);
+        string outfilename = dirname + "/" + V3Os::filenameNonDir(filename);
 
-        UINFO(1,"annotateOutputFile "<<filename<<" -> "<<outfilename<<endl);
+        UINFO(1, "annotateOutputFile " << filename << " -> " << outfilename << endl);
 
         std::ifstream is(filename.c_str());
         if (!is) {
-            v3error("Can't read "<<filename);
+            v3error("Can't read " << filename);
             return;
         }
 
         std::ofstream os(outfilename.c_str());
         if (!os) {
-            v3fatal("Can't write "<<outfilename);
+            v3fatal("Can't write " << outfilename);
             return;
         }
 
-        os << "\t// verilator_coverage annotation"<<endl;
+        os << "\t// verilator_coverage annotation" << endl;
 
         int lineno = 0;
         while (!is.eof()) {
@@ -224,21 +302,21 @@ void VlcTop::annotateOutputFiles(const string& dirname) {
             bool first = true;
 
             VlcSource::LinenoMap& lines = source.lines();
-            VlcSource::LinenoMap::iterator lit=lines.find(lineno);
+            VlcSource::LinenoMap::iterator lit = lines.find(lineno);
             if (lit != lines.end()) {
                 VlcSource::ColumnMap& cmap = lit->second;
-                for (VlcSource::ColumnMap::iterator cit=cmap.begin(); cit!=cmap.end(); ++cit) {
+                for (VlcSource::ColumnMap::iterator cit = cmap.begin(); cit != cmap.end(); ++cit) {
                     VlcSourceCount& col = cit->second;
-                    //UINFO(0,"Source "<<source.name()<<":"<<col.lineno()<<":"<<col.column()<<endl);
-                    os<<(col.ok()?" ":"%")
-                      <<std::setfill('0')<<std::setw(6)<<col.count()
-                      <<"\t"<<line<<endl;
+                    // UINFO(0,"Source
+                    // "<<source.name()<<":"<<col.lineno()<<":"<<col.column()<<endl);
+                    os << (col.ok() ? " " : "%") << std::setfill('0') << std::setw(6)
+                       << col.count() << "\t" << line << endl;
                     if (first) {
                         first = false;
                         // Multiple columns on same line; print line just once
                         string indent;
-                        for (string::const_iterator pos=line.begin();
-                             pos!=line.end() && isspace(*pos); ++pos) {
+                        for (string::const_iterator pos = line.begin();
+                             pos != line.end() && isspace(*pos); ++pos) {
                             indent += *pos;
                         }
                         line = indent + "verilator_coverage: (next point on previous line)\n";
@@ -246,9 +324,7 @@ void VlcTop::annotateOutputFiles(const string& dirname) {
                 }
             }
 
-            if (first) {
-                os<<"\t"<<line<<endl;
-            }
+            if (first) os << "\t" << line << endl;
         }
     }
 }
