@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -43,7 +39,6 @@ private:
     VlcSources m_sources;  //< List of all source files to annotate
 
     // METHODS
-    void createDir(const string& dirname);
     void annotateCalc();
     void annotateCalcNeeded();
     void annotateOutputFiles(const string& dirname);
@@ -60,8 +55,9 @@ public:
 
     // METHODS
     void annotate(const string& dirname);
-    void readCoverage(const string& filename, bool nonfatal=false);
+    void readCoverage(const string& filename, bool nonfatal = false);
     void writeCoverage(const string& filename);
+    void writeInfo(const string& filename);
 
     void rank();
 };
