@@ -9,6 +9,8 @@ BEGIN {
     if (!$ENV{VERILATOR_ROOT} && -x "../bin/verilator") {
         $ENV{VERILATOR_ROOT} = Cwd::getcwd()."/..";
     }
+    $ENV{MAKE} ||= "make";
+    $ENV{CXX} ||= "c++";
 }
 
 use Getopt::Long;
@@ -22,12 +24,18 @@ use version;
 use POSIX qw(strftime);
 use lib ".";
 use Time::HiRes qw(usleep);
+use Digest::MD5 qw(md5);
 
 $::Driver = 1;
 $::Have_Forker = 0;
 
-eval "use Parallel::Forker; \$Fork=Parallel::Forker->new(use_sig_child=>1); \$::Have_Forker=1;";
+eval "use Parallel::Forker; \$Fork=Parallel::Forker->new(use_sig_child=>1, poll_interval=>10*1000); \$::Have_Forker=1;";
 $Fork = Forker->new(use_sig_child=>1) if !$Fork;
+my $forker_Min_Version = 1.258;
+if ($::Have_Forker && $Parallel::Forker::VERSION < $forker_Min_Version) {
+    print STDERR "driver.pl: Parallel::Forker is older than $forker_Min_Version, suggest 'cpan install Parallel::Forker'\n";
+    $::Have_Forker = 0;
+}
 $SIG{CHLD} = sub { $Fork->sig_child() if $Fork; };
 $SIG{TERM} = sub { $Fork->kill_tree_all('TERM') if $Fork; die "Quitting...\n"; };
 
@@ -35,16 +43,16 @@ $SIG{TERM} = sub { $Fork->kill_tree_all('TERM') if $Fork; die "Quitting...\n"; }
 
 # Map of all scenarios, with the names used to enable them
 our %All_Scenarios
-    = (dist  => [                       "dist"],
-       atsim => [          "simulator", "atsim"],
-       ghdl  => ["linter", "simulator", "ghdl"],
-       iv    => [          "simulator", "iv"],
-       ms    => ["linter", "simulator", "ms"],
-       nc    => ["linter", "simulator", "nc"],
-       vcs   => ["linter", "simulator", "vcs"],
-       xsim  => ["linter", "simulator", "xsim"],
-       vlt   => ["linter", "simulator", "vlt_all", "vlt"],
-       vltmt => [          "simulator", "vlt_all", "vltmt"],
+    = (dist  => [                                       "dist"],
+       atsim => [          "simulator", "simulator_st", "atsim"],
+       ghdl  => ["linter", "simulator", "simulator_st", "ghdl"],
+       iv    => [          "simulator", "simulator_st", "iv"],
+       ms    => ["linter", "simulator", "simulator_st", "ms"],
+       nc    => ["linter", "simulator", "simulator_st", "nc"],
+       vcs   => ["linter", "simulator", "simulator_st", "vcs"],
+       xsim  => ["linter", "simulator", "simulator_st", "xsim"],
+       vlt   => ["linter", "simulator", "simulator_st", "vlt_all", "vlt"],
+       vltmt => [          "simulator",                 "vlt_all", "vltmt"],
     );
 
 #======================================================================
@@ -66,6 +74,7 @@ my $opt_gdb;
 my $opt_rr;
 my $opt_gdbbt;
 my $opt_gdbsim;
+my $opt_hashset;
 my $opt_jobs = 1;
 my $opt_optimize;
 my $opt_quiet;
@@ -90,6 +99,7 @@ if (! GetOptions(
           "gdbbt!"      => \$opt_gdbbt,
           "gdbsim!"     => \$opt_gdbsim,
           "golden!"     => sub { $ENV{HARNESS_UPDATE_GOLDEN} = 1; },
+          "hashset=s"   => \$opt_hashset,
           "help"        => \&usage,
           "j=i"         => \$opt_jobs,
           "optimize:s"  => \$opt_optimize,
@@ -141,6 +151,8 @@ if ($#opt_tests<0) {  # Run everything
         push @opt_tests, sort(glob("${dir}/t_*.pl"));
     }
 }
+@opt_tests = _calc_hashset(@opt_tests) if $opt_hashset;
+
 if ($#opt_tests>=2 && $opt_jobs>=2) {
     # Without this tests such as t_debug_sigsegv_bt_bad.pl will occasionally
     # block on input and cause a SIGSTOP, then a "fg" was needed to resume testing.
@@ -188,11 +200,7 @@ if ($opt_rerun && $runner->fail_count) {
         skip_cnt => $orig_runner->{skip_cnt},
         unsup_cnt => $orig_runner->{unsup_cnt});
     foreach my $test (@{$orig_runner->{fail_tests}}) {
-        if (0) {  # TBD if this is required - rare that intermediate results are bad
-            # Remove old results to force hard rebuild
-            system("rm", "-rf", "$test->{obj_dir}__fail1");
-            system("mv", "$test->{obj_dir}", "$test->{obj_dir}__fail1");
-        }
+        $test->clean;
         # Reschedule test
         $runner->one_test(pl_filename => $test->{pl_filename},
                           $test->{scenario} => 1);
@@ -261,6 +269,22 @@ sub calc_jobs {
     return $ok + 1;
 }
 
+sub _calc_hashset {
+    my @in = @_;
+    return @in if !$opt_hashset;
+    $opt_hashset =~ m!^(\d+)/(\d+)$!
+        or die "%Error: Need number/number format for --hashset: $opt_hashset\n";
+    my ($set, $nsets) = ($1, $2);
+    my @new;
+    foreach my $t (@opt_tests) {
+        my $checksum = unpack('L', substr(md5($t), 0, 4));
+        if (($set % $nsets) == ($checksum % $nsets)) {
+            push @new, $t;
+        }
+    }
+    return @new;
+}
+
 #######################################################################
 #######################################################################
 #######################################################################
@@ -287,6 +311,8 @@ sub new {
         skip_msgs => [],
         fail_msgs => [],
         fail_tests => [],
+        # Per-task identifiers
+        running_ids => {},
         @_};
     bless $self, $class;
     return $self;
@@ -303,14 +329,24 @@ sub one_test {
     $::Fork->schedule
         (
          test_pl_filename => $params{pl_filename},
+         run_pre_start => sub {
+             my $process = shift;
+             # Running in context of parent, before run_on_start
+             # Make an identifier that is unique across all current running jobs
+             my $i = 1; while (exists $self->{running_ids}{$i}) { ++$i; }
+             $process->{running_id} = $i;
+             $self->{running_ids}{$process->{running_id}} = 1;
+         },
          run_on_start => sub {
+             my $process = shift;
              # Running in context of child, so can't pass data to parent directly
              if ($self->{quiet}) {
                  open(STDOUT, ">/dev/null");
                  open(STDERR, ">&STDOUT");
              }
              print("="x70,"\n");
-             my $test = VTest->new(@params);
+             my $test = VTest->new(@params,
+                                   running_id => $process->{running_id});
              $test->oprint("="x50,"\n");
              unlink $test->{status_filename};
              $test->_prep;
@@ -321,7 +357,9 @@ sub one_test {
          },
          run_on_finish => sub {
              # Running in context of parent
-             my $test = VTest->new(@params);
+             my $process = shift;
+             my $test = VTest->new(@params,
+                                   running_id => $process->{running_id});
              $test->_read_status;
              if ($test->ok) {
                  $self->{ok_cnt}++;
@@ -335,11 +373,13 @@ sub one_test {
              } else {
                  $test->oprint("FAILED: $test->{errors}\n");
                  my $j = ($opt_jobs>1?" -j":"");
-                 my $makecmd = $ENV{VERILATOR_MAKE} || "make$j &&";
+                 my $makecmd = $ENV{VERILATOR_MAKE} || "$ENV{MAKE}$j &&";
+                 my $upperdir = (Cwd::getcwd() =~ /test_regress/
+                                 ? 'test_regress/' : '');
                  push @{$self->{fail_msgs}},
                      ("\t#".$test->soprint("%Error: $test->{errors}\n")
-                      ."\t\t$makecmd test_regress/"
-                      .$test->{pl_filename}
+                      ."\t\t$makecmd "
+                      .$upperdir.$test->{pl_filename}
                       ." ".join(' ', _manual_args())
                       ." --".$test->{scenario}."\n");
                  push @{$self->{fail_tests}}, $test;
@@ -355,6 +395,7 @@ sub one_test {
              }
              $self->{left_cnt}--;
              $self->print_summary;
+             delete $self->{running_ids}{$process->{running_id}} if $process->{running_id};
          },
          )->ready();
 }
@@ -425,7 +466,7 @@ sub sprint_summary {
 
     my $delta = time() - $::Start;
     my $leftmsg = $::Have_Forker ? $self->{left_cnt} : "NO-FORKER";
-    my $pct = int(100*($self->{left_cnt} / $self->{all_cnt}) + 0.999);
+    my $pct = int(100*($self->{left_cnt} / ($self->{all_cnt} + 0.001)) + 0.999);
     my $eta = ($self->{all_cnt}
                * ($delta / (($self->{all_cnt} - $self->{left_cnt})+0.001))) - $delta;
     $eta = 0 if $delta < 10;
@@ -527,6 +568,7 @@ sub new {
         make_top_shell => 1,    # Make a default __top.v file
         make_main => 1,         # Make __main.cpp
         make_pli => 0,          # need to compile pli
+        sc_time_resolution => "SC_PS",  # Keep - PS is SystemC default
         sim_time => 1100,
         benchmark => $opt_benchmark,
         verbose => $opt_verbose,
@@ -565,7 +607,7 @@ sub new {
         ghdl_run_flags => [],
         # IV
         iv => 0,
-        iv_flags => [split(/\s+/,"+define+iverilog -o $self->{obj_dir}/simiv")],
+        iv_flags => [split(/\s+/,"+define+IVERILOG -g2012 -o $self->{obj_dir}/simiv")],
         iv_flags2 => [],  # Overridden in some sim files
         iv_pli => 0,  # need to use pli
         iv_run_flags => [],
@@ -582,7 +624,7 @@ sub new {
         nc_run_flags => [split(/\s+/,"+licqueue -q +assert +sv -R")],
         # ModelSim
         ms => 0,
-        ms_flags => [split(/\s+/,("-sv -work $self->{obj_dir}/work"))],
+        ms_flags => [split(/\s+/, ("-sv -work $self->{obj_dir}/work +define+MS=1 -ccflags \"-DMS=1\""))],
         ms_flags2 => [],  # Overridden in some sim files
         ms_pli => 1,  # need to use pli
         ms_run_flags => [split(/\s+/,"-lib $self->{obj_dir}/work -c -do 'run -all;quit' ")],
@@ -772,6 +814,25 @@ sub _read_status {
 #----------------------------------------------------------------------
 # Methods invoked by tests
 
+sub clean {
+    my $self = (ref $_[0] ? shift : $Self);
+    # Called on a rerun to cleanup files
+    if ($self->{clean_command}) {
+        system($self->{clean_command});
+    }
+    if (1) {
+        # Prevents false-failures when switching compilers
+        # Remove old results to force hard rebuild
+        system("rm", "-rf", "$self->{obj_dir}__fail1");
+        system("mv", "$self->{obj_dir}", "$self->{obj_dir}__fail1");
+    }
+}
+
+sub clean_objs {
+    my $self = (ref $_[0] ? shift : $Self);
+    system("rm", "-rf", glob("$self->{obj_dir}/*"));
+}
+
 sub compile_vlt_cmd {
     my $self = (ref $_[0]? shift : $Self);
     my %param = (%{$self}, @_);  # Default arguments are from $self
@@ -799,8 +860,7 @@ sub compile_vlt_flags {
                           @{$param{verilator_flags3}});
     $self->{sc} = 1 if ($checkflags =~ /-sc\b/);
     $self->{trace} = ($opt_trace || $checkflags =~ /-trace\b/
-                      || $checkflags =~ /-trace-fst\b/
-                      || $checkflags =~ /-trace-fst-thread\b/);
+                      || $checkflags =~ /-trace-fst\b/);
     $self->{trace_format} = (($checkflags =~ /-trace-fst/ && 'fst-c')
                              || ($self->{sc} && 'vcd-sc')
                              || (!$self->{sc} && 'vcd-c'));
@@ -815,7 +875,8 @@ sub compile_vlt_flags {
     unshift @verilator_flags, "--trace" if $opt_trace;
     my $threads = ::calc_threads($Vltmt_threads);
     unshift @verilator_flags, "--threads $threads" if $param{vltmt} && $checkflags !~ /-threads /;
-    unshift @verilator_flags, "--trace-fst-thread" if $param{vltmt} && $checkflags =~ /-trace-fst/;
+    unshift @verilator_flags, "--trace-threads 1" if $param{vltmt} && $checkflags =~ /-trace /;
+    unshift @verilator_flags, "--trace-threads 2" if $param{vltmt} && $checkflags =~ /-trace-fst /;
     unshift @verilator_flags, "--debug-partition" if $param{vltmt};
     unshift @verilator_flags, "--make gmake" if $param{verilator_make_gmake};
     unshift @verilator_flags, "--make cmake" if $param{verilator_make_cmake};
@@ -846,11 +907,16 @@ sub compile_vlt_flags {
                    @{$param{v_flags2}},
                    # Flags from driver cmdline override default flags and
                    # flags from the test itself
-                   @Opt_Driver_Verilator_Flags,
+                   driver_verilator_flags(),
         );
     return @cmdargs;
 }
 
+sub driver_verilator_flags {
+    #my $self = (ref $_[0] ? shift : $Self);
+    return @Opt_Driver_Verilator_Flags
+}
+
 sub lint {
     my $self = (ref $_[0] ? shift : $Self);
     my %param = (#
@@ -1023,6 +1089,7 @@ sub compile {
                         tee => $param{tee},
                         expect => $param{expect},
                         expect_filename => $param{expect_filename},
+                        verilator_run => 1,
                         cmd => \@vlt_cmd) if $::Opt_Verilation;
             return 1 if $self->errors || $self->skips || $self->unsupporteds;
         }
@@ -1038,6 +1105,7 @@ sub compile {
                         tee => $param{tee},
                         expect => $param{expect},
                         expect_filename => $param{expect_filename},
+                        verilator_run => 1,
                         cmd => ["cd \"".$self->{obj_dir}."\" && cmake",
                                 "\"".$self->{t_dir}."/..\"",
                                 "-DTEST_VERILATOR_ROOT=$ENV{VERILATOR_ROOT}",
@@ -1048,7 +1116,8 @@ sub compile {
                                 "-DTEST_VERBOSE=\"".($self->{verbose} ? 1 : 0)."\"",
                                 "-DTEST_SYSTEMC=\"" .($self->sc ? 1 : 0). "\"",
                                 "-DCMAKE_PREFIX_PATH=\"".(($ENV{SYSTEMC_INCLUDE}||$ENV{SYSTEMC}||'')."/..\""),
-                                "-DTEST_OPT_FAST=\"" . ($param{benchmark}?"-O2":"") . "\"",
+                                "-DTEST_OPT_FAST=\"" . ($param{benchmark} ? "-Os" : "-O0") . "\"",
+                                "-DTEST_OPT_GLOBAL=\"" . ($param{benchmark} ? "-Os" : "-O0") . "\"",
                                 "-DTEST_VERILATION=\"" . $::Opt_Verilation . "\"",
                         ]);
             return 1 if $self->errors || $self->skips || $self->unsupporteds;
@@ -1058,7 +1127,7 @@ sub compile {
             $self->oprint("Running make (gmake)\n") if $self->{verbose};
             $self->_run(logfile => "$self->{obj_dir}/vlt_gcc.log",
                         entering => "$self->{obj_dir}",
-                        cmd => ["make",
+                        cmd => [$ENV{MAKE},
                                 "-C ".$self->{obj_dir},
                                 "-f ".$::RealBin."/Makefile_obj",
                                 ($self->{verbose} ? "" : "--no-print-directory"),
@@ -1066,7 +1135,8 @@ sub compile {
                                 "TEST_OBJ_DIR=$self->{obj_dir}",
                                 "CPPFLAGS_DRIVER=-D".uc($self->{name}),
                                 ($self->{verbose} ? "CPPFLAGS_DRIVER2=-DTEST_VERBOSE=1":""),
-                                ($param{benchmark}?"OPT_FAST=-O2":""),
+                                ($param{benchmark} ? "" : "OPT_FAST=-O0"),
+                                ($param{benchmark} ? "" : "OPT_GLOBAL=-O0"),
                                 "$self->{VM_PREFIX}",  # bypass default rule, as we don't need archive
                                 ($param{make_flags}||""),
                         ]);
@@ -1087,7 +1157,7 @@ sub compile {
 
     if ($param{make_pli}) {
         $self->oprint("Compile vpi\n") if $self->{verbose};
-        my @cmd = ('c++', @{$param{pli_flags}}, "-DIS_VPI",
+        my @cmd = ($ENV{CXX}, @{$param{pli_flags}}, "-DIS_VPI",
                    "$self->{t_dir}/$self->{pli_filename}");
 
         $self->_run(logfile=>"$self->{obj_dir}/pli_compile.log",
@@ -1237,6 +1307,14 @@ sub execute {
     }
 }
 
+sub setenv {
+    my $self = (ref $_[0]? shift : $Self);
+    my $var = shift;
+    my $val = shift;
+    print "\texport $var='$val'\n";
+    $ENV{$var} = $val;
+}
+
 sub inline_checks {
     my $self = (ref $_[0]? shift : $Self);
     return 1 if $self->errors || $self->skips || $self->unsupporteds;
@@ -1252,10 +1330,10 @@ sub inline_checks {
     while (defined(my $line = $fh->getline)) {
         if ($line =~ /CHECK/) {
             if ($line =~ /CHECK_COVER *\( *([---0-9]+) *, *"([^"]+)" *, *("([^"]+)" *,|) *(\d+) *\)/) {
-                my $lineno=($. + $1); my $hier=$2; my $comment=$4; my $count=$5;
+                my $lineno = ($. + $1); my $hier=$2; my $comment=$4; my $count=$5;
                 my $regexp = "\001l\002".$lineno;
                 $regexp .= ".*\001o\002".quotemeta($comment) if $comment;
-                $regexp .= ".*\001h\002".quotemeta($hier);
+                $regexp .= ".*\001h\002".quotemeta($hier) if $hier;
                 $regexp .= ".*' ".$count;
                 if ($contents !~ /$regexp/) {
                     $self->error("CHECK_COVER: $covfn: Regexp not found: $regexp\n".
@@ -1263,7 +1341,7 @@ sub inline_checks {
                 }
             }
             elsif ($line =~ /CHECK_COVER_MISSING *\( *([---0-9]+) *\)/) {
-                my $lineno=($. + $1);
+                my $lineno = ($. + $1);
                 my $regexp = "\001l\002".$lineno;
                 if ($contents =~ /$regexp/) {
                     $self->error("CHECK_COVER_MISSING: $covfn: Regexp found: $regexp\n".
@@ -1340,11 +1418,21 @@ sub sc {
 }
 
 sub have_sc {
-    #my $self = shift;
-    return 1 if (defined $ENV{SYSTEMC} || defined $ENV{SYSTEMC_INCLUDE});
+    my $self = (ref $_[0]? shift : $Self);
+    return 1 if (defined $ENV{SYSTEMC} || defined $ENV{SYSTEMC_INCLUDE} || $ENV{CFG_HAVE_SYSTEMC});
+    return 1 if $self->verilator_version =~ /systemc found *= *1/i;
     return 0;
 }
 
+sub make_version {
+    my $ver = `$ENV{MAKE} --version`;
+    if ($ver =~ /make ([0-9]+\.[0-9]+)/i) {
+        return $1;
+    } else {
+        return -1;
+    }
+}
+
 sub have_cmake {
     return cmake_version() >= version->declare("3.8");
 }
@@ -1419,6 +1507,7 @@ sub _run {
     my $self = (ref $_[0]? shift : $Self);
     my %param = (tee => 1,
                  #entering =>  # Print entering directory information
+                 #verilator_run =>  # Move gcov data to parallel area
                  @_);
     my $command = join(' ',@{$param{cmd}});
     $command = "time $command" if $opt_benchmark && $command !~ /^cd /;
@@ -1426,6 +1515,17 @@ sub _run {
     print "   > $param{logfile}" if $param{logfile};
     print "\n";
 
+    if ($param{verilator_run}) {
+        # Gcov fails when parallel jobs write same data file,
+        # so we make sure output dir is unique across all running jobs.
+        # We can't just put each one in obj_dir as it uses too much disk.
+        $ENV{GCOV_PREFIX_STRIP} = 99;
+        $ENV{GCOV_PREFIX} = "$self->{t_dir}/obj_dist/gcov_$self->{running_id}";
+    } else {
+        delete $ENV{GCOV_PREFIX_STRIP};
+        delete $ENV{GCOV_PREFIX};
+    }
+
     # Execute command redirecting output, keeping order between stderr and stdout.
     # Must do low-level IO so GCC interaction works (can't be line-based)
     my $status;
@@ -1580,7 +1680,7 @@ sub _make_main {
     my $fh = IO::File->new(">$filename") or die "%Error: $! $filename,";
 
     print $fh "// Test defines\n";
-    print $fh "#define VL_TIME_MULTIPLIER $self->{vl_time_multiplier}\n" if $self->{vl_time_multiplier};
+    print $fh "#define MAIN_TIME_MULTIPLIER ".($self->{main_time_multiplier} || 1)."\n";
 
     print $fh "// OS header\n";
     print $fh "#include \"verilatedos.h\"\n";
@@ -1599,8 +1699,13 @@ sub _make_main {
 
     print $fh "$VM_PREFIX* topp;\n";
     if (!$self->sc) {
-        print $fh "vluint64_t main_time = false;\n";
-        print $fh "double sc_time_stamp() { return main_time; }\n";
+        if ($self->{vl_time_stamp64}) {
+            print $fh "vluint64_t main_time = 0;\n";
+            print $fh "vluint64_t vl_time_stamp() { return main_time; }\n";
+        } else {
+            print $fh "double main_time = 0;\n";
+            print $fh "double sc_time_stamp() { return main_time; }\n";
+        }
     }
 
     if ($self->{savable}) {
@@ -1630,7 +1735,8 @@ sub _make_main {
         print $fh "int sc_main(int argc, char** argv) {\n";
         print $fh "    sc_signal<bool> fastclk;\n" if $self->{inputs}{fastclk};
         print $fh "    sc_signal<bool> clk;\n"  if $self->{inputs}{clk};
-        print $fh "    sc_time sim_time($self->{sim_time}, SC_NS);\n";
+        print $fh "    sc_set_time_resolution(1, $Self->{sc_time_resolution});\n";
+        print $fh "    sc_time sim_time($self->{sim_time}, $Self->{sc_time_resolution});\n";
     } else {
         print $fh "int main(int argc, char** argv, char** env) {\n";
         print $fh "    double sim_time = $self->{sim_time};\n";
@@ -1686,7 +1792,8 @@ sub _make_main {
     _print_advance_time($self, $fh, 10);
     print $fh "    }\n";
 
-    print $fh "    while (sc_time_stamp() < sim_time && !Verilated::gotFinish()) {\n";
+    print $fh "    while ((sc_time_stamp() < sim_time * MAIN_TIME_MULTIPLIER)\n";
+    print $fh "           && !Verilated::gotFinish()) {\n";
     for (my $i=0; $i<5; $i++) {
         my $action = 0;
         if ($self->{inputs}{fastclk}) {
@@ -1724,7 +1831,7 @@ sub _make_main {
     }
     $fh->print("\n");
 
-    print $fh "    delete topp; topp=NULL;\n";
+    print $fh "    VL_DO_DANGLING(delete topp, topp);\n";
     print $fh "    exit(0L);\n";
     print $fh "}\n";
     $fh->close();
@@ -1742,7 +1849,7 @@ sub _print_advance_time {
 
     if ($self->sc) {
         print $fh "#if (SYSTEMC_VERSION>=20070314)\n";
-        print $fh "        sc_start(${time},SC_NS);\n";
+        print $fh "        sc_start(${time}, $Self->{sc_time_resolution});\n";
         print $fh "#else\n";
         print $fh "        sc_start(${time});\n";
         print $fh "#endif\n";
@@ -1755,7 +1862,7 @@ sub _print_advance_time {
                 $fh->print("#endif  // VM_TRACE\n");
             }
         }
-        print $fh "        main_time += ${time};\n";
+        print $fh "        main_time += ${time} * MAIN_TIME_MULTIPLIER;\n";
     }
 }
 
@@ -1775,7 +1882,8 @@ sub _make_top_v {
 
     $self->_read_inputs_v();
 
-    my $fh = IO::File->new(">$self->{top_shell_filename}") or die "%Error: $! $self->{top_shell_filename},";
+    my $fh = IO::File->new(">$self->{top_shell_filename}")
+        or die "%Error: $! $self->{top_shell_filename},";
     print $fh "module top;\n";
     foreach my $inp (sort (keys %{$self->{inputs}})) {
         print $fh "    reg ${inp};\n";
@@ -1928,8 +2036,9 @@ sub _read_inputs_vhdl {
 
 our $_Verilator_Version;
 sub verilator_version {
+    # Returns verbose version, line 1 contains actual version
     if (!defined $_Verilator_Version) {
-        my @args = ("perl", "$ENV{VERILATOR_ROOT}/bin/verilator", "--version");
+        my @args = ("perl", "$ENV{VERILATOR_ROOT}/bin/verilator", "-V");
         my $args = join(' ',@args);
         $_Verilator_Version = `$args`;
         $_Verilator_Version or die "can't fork: $! ".join(' ',@args);
@@ -1973,6 +2082,7 @@ sub files_identical {
                     && !/^- [a-z.0-9]+:\d+:[^\n]+\n/
                     && !/^-node:/
                     && !/^dot [^\n]+\n/
+                    && !/^In file: .*\/sc_.*:\d+/
             } @l1;
             @l1 = map {
                 s/(Internal Error: [^\n]+\.cpp):[0-9]+:/$1:#:/;
@@ -1984,6 +2094,7 @@ sub files_identical {
                 $l1[$l] =~ s/\r/<#013>/mig;
                 $l1[$l] =~ s/Command Failed[^\n]+/Command Failed/mig;
                 $l1[$l] =~ s/Version: Verilator[^\n]+/Version: Verilator ###/mig;
+                $l1[$l] =~ s/CPU Time: +[0-9.]+ seconds[^\n]+/CPU Time: ###/mig;
                 if ($l1[$l] =~ s/Exiting due to.*/Exiting due to/mig) {
                     splice @l1, $l+1;  # Trunc rest
                     last;
@@ -2011,6 +2122,20 @@ sub files_identical {
     }
 }
 
+sub files_identical_sorted {
+    my $self = (ref $_[0]? shift : $Self);
+    my $fn1 = shift;
+    my $fn2 = shift;
+    my $fn1_is_logfile = shift;
+    return 1 if $self->errors || $self->skips || $self->unsupporteds;
+    # Set LC_ALL as suggested in the sort manpage to avoid sort order
+    # changes from the locale.
+    setenv('LC_ALL', "C");
+    my $fn1sort = "$fn1.sort";
+    run(cmd => ["sort", "$fn1", "> $fn1sort"]);
+    return $self->files_identical($fn1sort, $fn2, $fn1_is_logfile);
+}
+
 sub copy_if_golden {
     my $self = (ref $_[0]? shift : $Self);
     my $fn1 = shift;
@@ -2069,17 +2194,27 @@ sub fst2vcd {
     my $fn1 = shift;
     my $fn2 = shift;
     if (!-r $fn1) { $self->error("File does not exist $fn1\n"); return 0; }
-    my $cmd = qq{fst2vcd --help};
+    my $cmd = qq{fst2vcd -h};
     print "\t$cmd\n" if $::Debug;
     my $out = `$cmd`;
     if (!$out || $out !~ /Usage:/) { $self->skip("No fst2vcd installed\n"); return 1; }
 
-    $cmd = qq{fst2vcd -e "$fn1" -o "$fn2"};
-    print "\t$cmd\n" if $::Debug;
+    $cmd = qq{fst2vcd -e -f "$fn1" -o "$fn2"};
+    print "\t$cmd\n";  # Always print to help debug race cases
     $out = `$cmd`;
     return 1;
 }
 
+sub fst_identical {
+    my $self = (ref $_[0]? shift : $Self);
+    my $fn1 = shift;
+    my $fn2 = shift;
+    return 0 if $self->errors || $self->skips || $self->unsupporteds;
+    my $tmp = $fn1.".vcd";
+    fst2vcd($fn1, $tmp);
+    return vcd_identical($tmp, $fn2);
+}
+
 sub _vcd_read {
     my $self = (ref $_[0]? shift : $Self);
     my $filename = shift;
@@ -2111,13 +2246,13 @@ sub _vcd_read {
 
 our $_Cxx_Version;
 sub cxx_version {
-    $_Cxx_Version ||= `make -C $ENV{VERILATOR_ROOT}/test_regress -f Makefile print-cxx-version`;
+    $_Cxx_Version ||= `$ENV{MAKE} -C $ENV{VERILATOR_ROOT}/test_regress -f Makefile print-cxx-version`;
     return $_Cxx_Version;
 }
 
 our $_Cfg_With_Threaded;
 sub cfg_with_threaded {
-    $_Cfg_With_Threaded ||= `make -C $ENV{VERILATOR_ROOT} -f Makefile print-cfg-with-threaded`;
+    $_Cfg_With_Threaded ||= `$ENV{MAKE} -C $ENV{VERILATOR_ROOT} -f Makefile print-cfg-with-threaded`;
     return ($_Cfg_With_Threaded =~ /yes/i) ? 1:0;
 }
 
@@ -2213,6 +2348,7 @@ sub schedule {
     my $self = shift;
     my %params = (@_);
 
+    $params{run_pre_start}->($self);
     if (my $pid = fork()) {  # Parent
         waitpid($pid, 0);
     } else {  # Child
@@ -2494,6 +2630,11 @@ Run Verilator generated executable under the debugger.
 
 Update golden files, equivalent to setting HARNESS_UPDATE_GOLDEN=1.
 
+=item --hashset I<set>/I<numsets>
+
+Split tests based on a hash of the test names into I<numsets> and run only
+tests in set number I<set> (0..I<numsets>-1).
+
 =item --help
 
 Displays this message and program version and exits.
@@ -2654,9 +2795,12 @@ Command to use to invoke XSim xvlog
 
 The latest version is available from L<https://verilator.org>.
 
-Copyright 2003-2020 by Wilson Snyder.  Verilator is free software; you can
-redistribute it and/or modify it under the terms of either the GNU Lesser
-General Public License Version 3 or the Perl Artistic License Version 2.0.
+Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License Version 3 or the Perl Artistic License
+Version 2.0.
+
+SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 =head1 AUTHORS
 
