@@ -3,13 +3,9 @@
 //
 // Copyright 2013-2017 by Wilson Snyder. This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
-// Lesser General Public License Version 3 or the Perl Artistic License.
+// Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -71,8 +67,8 @@ public:
     }
     // return absolute scope of obj
     static const char* rooted(const char* obj) {
-        static string buf;
-        ostringstream os;
+        static std::string buf;
+        std::ostringstream os;
         os<<top()<<"."<<obj;
         buf = os.str();
         return buf.c_str();
