@@ -1,16 +1,15 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003-2009 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003-2009 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(simulator => 1);
 
-$Self->{golden_out} ||= "t/$Self->{name}.out";
-
 compile(
     verilator_flags2 => ["--stats --O3 -x-assign fast"],
     );
@@ -19,5 +18,7 @@ execute(
     check_finished => 1,
     );
 
-ok(files_identical("$Self->{obj_dir}/$Self->{name}_logger.log", $Self->{golden_out}));
+files_identical("$Self->{obj_dir}/$Self->{name}_logger.log", $Self->{golden_filename});
+
+ok(1);
 1;
