@@ -2,13 +2,14 @@
 //
 // DESCRIPTION: Verilator: Verilog Test module
 //
-// This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2010 by Wilson Snyder.
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2010 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
 
 #include <verilated.h>
 #include VM_PREFIX_INCLUDE
 
-unsigned int main_time = false;
+unsigned int main_time = 0;
 
 double sc_time_stamp() { return main_time; }
 
