@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 use File::Spec;
 
@@ -28,7 +29,7 @@ mkdir $child_dir;
 
     run(logfile => "${child_dir}/vlt_gcc.log",
         cmd => ["cd ${child_dir} && ",
-                "make", "-f".getcwd()."/Makefile_obj",
+                $ENV{MAKE}, "-f".getcwd()."/Makefile_obj",
                 "CPPFLAGS_DRIVER=-D".uc($self->{name}),
                 ($opt_verbose ? "CPPFLAGS_DRIVER2=-DTEST_VERBOSE=1":""),
                 "VM_PREFIX=$self->{VM_PREFIX}_child",
