@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(vlt_all => 1);
 
@@ -27,17 +28,17 @@ while (1) {
     # properly build
     run(logfile => "$Self->{obj_dir}/vlt_gcc.log",
         tee => $self->{verbose},
-        cmd=>["make",
+        cmd=>[$ENV{MAKE},
               "-C ".$Self->{obj_dir},
               "-f $Self->{VM_PREFIX}.mk",
               "-j 4",
-              "VM_PARALLEL_BUILDS=1",  # Important to this test
               "VM_PREFIX=$Self->{VM_PREFIX}",
               "TEST_OBJ_DIR=$Self->{obj_dir}",
               "CPPFLAGS_DRIVER=-D".uc($Self->{name}),
               ($opt_verbose ? "CPPFLAGS_DRIVER2=-DTEST_VERBOSE=1":""),
               "OPT_FAST=-O2",
               "OPT_SLOW=-O0",
+              "OPT_GLOBAL=-Os",
               ($param{make_flags}||""),
         ]);
 
@@ -45,7 +46,10 @@ while (1) {
         check_finished => 1,
         );
 
+    # Splitting should set VM_PARALLEL_BUILDS to 1 by default
+    file_grep("$Self->{obj_dir}/$Self->{VM_PREFIX}_classes.mk", qr/VM_PARALLEL_BUILDS\s*=\s*1/);
     check_splits();
+    check_no_all_file();
     check_gcc_flags("$Self->{obj_dir}/vlt_gcc.log");
 
     ok(1);
@@ -53,15 +57,6 @@ while (1) {
 }
 1;
 
-sub make_version {
-    my $ver = `make --version`;
-    if ($ver =~ /make ([0-9]+\.[0-9]+)/i) {
-        return $1;
-    } else {
-        return -1;
-    }
-}
-
 sub check_splits {
     my $got1;
     my $gotSyms1;
@@ -77,6 +72,14 @@ sub check_splits {
     $gotSyms1 or error("No Syms__1 split file found");
 }
 
+sub check_no_all_file {
+    foreach my $file (glob("$Self->{obj_dir}/*.cpp")) {
+        if ($file =~ qr/__ALL.cpp/) {
+            error("__ALL.cpp file found: $file");
+        }
+    }
+}
+
 sub check_cpp {
     my $filename = shift;
     my $size = -s $filename;
@@ -109,13 +112,15 @@ sub check_gcc_flags {
     while (defined (my $line = $fh->getline)) {
         chomp $line;
         print ":log: $line\n" if $Self->{verbose};
-        if ($line =~ /\.cpp/) {
-            my $filetype = ($line =~ /Slow/) ? "slow":"fast";
+        if ($line =~ /$Self->{VM_PREFIX}\S*\.cpp/) {
+            my $filetype = ($line =~ /Slow|Syms/) ? "slow":"fast";
             my $opt = ($line !~ /-O2/) ? "slow":"fast";
             print "$filetype, $opt, $line\n" if $Self->{verbose};
             if ($filetype ne $opt) {
                 error("${filetype} file compiled as if was ${opt}: $line");
             }
+        } elsif ($line =~ /\.cpp/ and $line !~ /-Os/) {
+            error("library file not compiled with OPT_GLOBAL: $line");
         }
     }
 }
