@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003-2009 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003-2009 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(dist => 1);
 
@@ -23,6 +24,7 @@ foreach my $prog (
         tee => $self->{verbose},
         logfile => "$Self->{obj_dir}/t_help.log",
         expect => qr/^Verilator/,
+        verilator_run => 1,
         );
 
     run(fails => 0,
@@ -31,6 +33,7 @@ foreach my $prog (
         tee => $self->{verbose},
         logfile => "$Self->{obj_dir}/t_help.log",
         expect => qr/^Verilator/,
+        verilator_run => 1,
         );
 
     run(fails => 0,
@@ -38,6 +41,7 @@ foreach my $prog (
                 "-V"],
         logfile => "$Self->{obj_dir}/t_help.log",
         expect => qr/^Verilator/,
+        verilator_run => 1,
         );
 }
 
