@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 use IO::File;
 
@@ -39,7 +40,9 @@ execute(
 run(cmd => ["$ENV{VERILATOR_ROOT}/bin/verilator_gantt",
             "$Self->{obj_dir}/profile_threads.dat",
             "--vcd $Self->{obj_dir}/profile_threads.vcd",
-            "> $Self->{obj_dir}/gantt.log"]);
+            "> $Self->{obj_dir}/gantt.log"],
+    verilator_run => 1,
+    );
 
 # We should have three lines of gantt chart, each with
 # an even number of mtask-bars (eg "[123--]")
