@@ -2,8 +2,9 @@
 //
 // DESCRIPTION: Verilator: Verilog Test module
 //
-// This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2010 by Wilson Snyder.
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2010 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
 
 #include <verilated.h>
 #include "Vt_order_quad.h"
@@ -31,11 +32,11 @@ int main(int argc, char* argv[]) {
 
     topp->a0 = 0;
     topp->eval();
-    check(topp->y, VL_ULL(0x0));
+    check(topp->y, 0x0ULL);
 
     topp->a0 = 15;
     topp->eval();
-    check(topp->y, VL_ULL(0x3c00000000));
+    check(topp->y, 0x3c00000000ULL);
 
     topp->final();
     if (!fail) {
