@@ -2,8 +2,9 @@
 //
 // DESCRIPTION: Verilator: Verilog Test module
 //
-// This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2008 by Wilson Snyder.
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2008 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
 
 #include <verilated.h>
 #include <verilated_syms.h>
@@ -13,8 +14,6 @@
 
 #include "Vt_scope_map.h"
 
-using namespace std;
-
 unsigned long long main_time = 0;
 double sc_time_stamp() { return (double)main_time; }
 
