@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003-2009 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003-2009 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(simulator => 1);
 
@@ -20,10 +21,7 @@ compile(
 
 execute(
     fails => $Self->{vlt_all},
-    expect =>
-'.*%Error: t_uniqueif.v:\d+: Assertion failed in top.t: \'unique if\' statement violated
-%Error: t/t_uniqueif.v:\d+: Verilog \$stop
-.*',
+    expect_filename => $Self->{golden_filename},
     );
 
 ok(1);
