@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2007 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2007 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(simulator => 1);
 
@@ -13,7 +14,7 @@ top_filename("t/t_unopt_converge.v");
 #$Self->{verilated_debug} = 1;
 
 compile(
-    v_flags2 => ['+define+ALLOW_UNOPT'],
+    v_flags2 => ['+define+ALLOW_UNOPT --output-split 0'],
     make_flags => 'CPPFLAGS_ADD=-DVL_DEBUG',
     );
 
