@@ -1,11 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003-2009 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003-2009 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 scenarios(dist => 1);
 
@@ -19,7 +20,10 @@ foreach my $basename ("t_vlcov_data_a.dat",
                 "--write", "$Self->{obj_dir}/${basename}"
         ],
         tee => 0,
+        verilator_run => 1,
         );
-    ok(files_identical("$Self->{obj_dir}/${basename}", "t/${basename}"));
+    files_identical("$Self->{obj_dir}/${basename}", "t/${basename}");
 }
+
+ok(1);
 1;
